@@ -27,7 +27,7 @@
 #include <kiconloader.h>
 #include <tdeglobal.h>
 #include <tdeaction.h>
-#include <kinstance.h>
+#include <tdeinstance.h>
 #include <tdelocale.h>
 #include <tdemessagebox.h>
 #include <tdepopupmenu.h>
@@ -176,7 +176,7 @@ KPluginFactory::~KPluginFactory()
 
 extern "C"
 {
-    KDE_EXPORT void* init_tdehtml_kget()
+    TDE_EXPORT void* init_tdehtml_kget()
     {
         TDEGlobal::locale()->insertCatalogue("kget");
         return new KPluginFactory;
