@@ -120,25 +120,25 @@ Transfer::init(const uint _id)
 
     status = ST_STOPPED;
 
-    connect(this, TQT_SIGNAL(statusChanged(Transfer *, int)), tdemain, TQT_SLOT(slotStatusChanged(Transfer *, int)));
-    connect(this, TQT_SIGNAL(statusChanged(Transfer *, int)), this, TQT_SLOT(slotUpdateActions()));
+    connect(this, TQ_SIGNAL(statusChanged(Transfer *, int)), tdemain, TQ_SLOT(slotStatusChanged(Transfer *, int)));
+    connect(this, TQ_SIGNAL(statusChanged(Transfer *, int)), this, TQ_SLOT(slotUpdateActions()));
 
-    connect(this, TQT_SIGNAL(log(uint, const TQString &, const TQString &)), tdemain->logwin(), TQT_SLOT(logTransfer(uint, const TQString &, const TQString &)));
+    connect(this, TQ_SIGNAL(log(uint, const TQString &, const TQString &)), tdemain->logwin(), TQ_SLOT(logTransfer(uint, const TQString &, const TQString &)));
 
     // setup actions
-    m_paResume = new TDEAction(i18n("&Resume"), "tool_resume", 0, this, TQT_SLOT(slotResume()), this, "resume");
+    m_paResume = new TDEAction(i18n("&Resume"), "tool_resume", 0, this, TQ_SLOT(slotResume()), this, "resume");
 
-    m_paPause = new TDEAction(i18n("&Pause"), "tool_pause", 0, this, TQT_SLOT(slotRequestPause()), this, "pause");
+    m_paPause = new TDEAction(i18n("&Pause"), "tool_pause", 0, this, TQ_SLOT(slotRequestPause()), this, "pause");
 
-    m_paDelete = new TDEAction(i18n("&Delete"), "edit-delete", 0, this, TQT_SLOT(slotRequestRemove()), this, "delete");
+    m_paDelete = new TDEAction(i18n("&Delete"), "edit-delete", 0, this, TQ_SLOT(slotRequestRemove()), this, "delete");
 
-    m_paRestart = new TDEAction(i18n("Re&start"), "tool_restart", 0, this, TQT_SLOT(slotRequestRestart()), this, "restart");
+    m_paRestart = new TDEAction(i18n("Re&start"), "tool_restart", 0, this, TQ_SLOT(slotRequestRestart()), this, "restart");
 
-    m_paQueue = new TDERadioAction(i18n("&Queue"), "tool_queue", 0, this, TQT_SLOT(slotQueue()), this, "queue");
+    m_paQueue = new TDERadioAction(i18n("&Queue"), "tool_queue", 0, this, TQ_SLOT(slotQueue()), this, "queue");
 
-    m_paTimer = new TDERadioAction(i18n("&Timer"), "tool_timer", 0, this, TQT_SLOT(slotRequestSchedule()), this, "timer");
+    m_paTimer = new TDERadioAction(i18n("&Timer"), "tool_timer", 0, this, TQ_SLOT(slotRequestSchedule()), this, "timer");
 
-    m_paDelay = new TDERadioAction(i18n("De&lay"), "tool_delay", 0, this, TQT_SLOT(slotRequestDelay()), this, "delay");
+    m_paDelay = new TDERadioAction(i18n("De&lay"), "tool_delay", 0, this, TQ_SLOT(slotRequestDelay()), this, "delay");
 
     m_paQueue->setExclusiveGroup("TransferMode");
     m_paTimer->setExclusiveGroup("TransferMode");
@@ -146,7 +146,7 @@ Transfer::init(const uint _id)
 
     // Actions
 
-    // m_paDock = new TDEAction(i18n("&Dock"),"tool_dock", 0, this,TQT_SLOT(slotRequestDelay()), this, "dockIndividual");
+    // m_paDock = new TDEAction(i18n("&Dock"),"tool_dock", 0, this,TQ_SLOT(slotRequestDelay()), this, "dockIndividual");
 
     // setup individual transfer dialog
 
