@@ -231,40 +231,40 @@ ChatMessagePart::ChatMessagePart( Kopete::ChatSession *mgr, TQWidget *parent, co
 	// Write the template to TDEHTMLPart
 	writeTemplate();
 
-	view()->setFocusPolicy( TQ_NoFocus );
+	view()->setFocusPolicy( TQWidget::NoFocus );
 
 	d->tt=new ToolTip( this );
 
 	// It is not possible to drag and drop on our widget
 	view()->setAcceptDrops(false);
 
-	connect( KopetePrefs::prefs(), TQT_SIGNAL(messageAppearanceChanged()),
-	         this, TQT_SLOT( slotAppearanceChanged() ) );
-	connect( KopetePrefs::prefs(), TQT_SIGNAL(windowAppearanceChanged()),
-	         this, TQT_SLOT( slotRefreshView() ) );
-	connect( KopetePrefs::prefs(), TQT_SIGNAL(styleChanged(const TQString &)),
-			 this, TQT_SLOT( setStyle(const TQString &) ) );
-	connect( KopetePrefs::prefs(), TQT_SIGNAL(styleVariantChanged(const TQString &)),
-			 this, TQT_SLOT( setStyleVariant(const TQString &) ) );
+	connect( KopetePrefs::prefs(), TQ_SIGNAL(messageAppearanceChanged()),
+	         this, TQ_SLOT( slotAppearanceChanged() ) );
+	connect( KopetePrefs::prefs(), TQ_SIGNAL(windowAppearanceChanged()),
+	         this, TQ_SLOT( slotRefreshView() ) );
+	connect( KopetePrefs::prefs(), TQ_SIGNAL(styleChanged(const TQString &)),
+			 this, TQ_SLOT( setStyle(const TQString &) ) );
+	connect( KopetePrefs::prefs(), TQ_SIGNAL(styleVariantChanged(const TQString &)),
+			 this, TQ_SLOT( setStyleVariant(const TQString &) ) );
 	// Refresh the style if the display name change.
-	connect( d->manager, TQT_SIGNAL(displayNameChanged()), this, TQT_SLOT(slotUpdateHeaderDisplayName()) );
-	connect( d->manager, TQT_SIGNAL(photoChanged()), this, TQT_SLOT(slotUpdateHeaderPhoto()) );
+	connect( d->manager, TQ_SIGNAL(displayNameChanged()), this, TQ_SLOT(slotUpdateHeaderDisplayName()) );
+	connect( d->manager, TQ_SIGNAL(photoChanged()), this, TQ_SLOT(slotUpdateHeaderPhoto()) );
 
-	connect ( browserExtension(), TQT_SIGNAL( openURLRequestDelayed( const KURL &, const KParts::URLArgs & ) ),
-	          this, TQT_SLOT( slotOpenURLRequest( const KURL &, const KParts::URLArgs & ) ) );
+	connect ( browserExtension(), TQ_SIGNAL( openURLRequestDelayed( const KURL &, const KParts::URLArgs & ) ),
+	          this, TQ_SLOT( slotOpenURLRequest( const KURL &, const KParts::URLArgs & ) ) );
 
-	connect( this, TQT_SIGNAL(popupMenu(const TQString &, const TQPoint &)),
-	         this, TQT_SLOT(slotRightClick(const TQString &, const TQPoint &)) );
-	connect( view(), TQT_SIGNAL(contentsMoving(int,int)),
-	         this, TQT_SLOT(slotScrollingTo(int,int)) );
+	connect( this, TQ_SIGNAL(popupMenu(const TQString &, const TQPoint &)),
+	         this, TQ_SLOT(slotRightClick(const TQString &, const TQPoint &)) );
+	connect( view(), TQ_SIGNAL(contentsMoving(int,int)),
+	         this, TQ_SLOT(slotScrollingTo(int,int)) );
 
 	//initActions
-	d->copyAction = KStdAction::copy( this, TQT_SLOT(copy()), actionCollection() );
-	d->saveAction = KStdAction::saveAs( this, TQT_SLOT(save()), actionCollection() );
-	d->printAction = KStdAction::print( this, TQT_SLOT(print()),actionCollection() );
-	d->closeAction = KStdAction::close( this, TQT_SLOT(slotCloseView()),actionCollection() );
-        d->importEmoticon = new TDEAction( i18n( "Import Emoticon"), TQString::fromLatin1( "importemot" ), 0, this, TQT_SLOT( slotImportEmoticon() ), actionCollection() );
-	d->copyURLAction = new TDEAction( i18n( "Copy Link Address" ), TQString::fromLatin1( "edit-copy" ), 0, this, TQT_SLOT( slotCopyURL() ), actionCollection() );
+	d->copyAction = KStdAction::copy( this, TQ_SLOT(copy()), actionCollection() );
+	d->saveAction = KStdAction::saveAs( this, TQ_SLOT(save()), actionCollection() );
+	d->printAction = KStdAction::print( this, TQ_SLOT(print()),actionCollection() );
+	d->closeAction = KStdAction::close( this, TQ_SLOT(slotCloseView()),actionCollection() );
+        d->importEmoticon = new TDEAction( i18n( "Import Emoticon"), TQString::fromLatin1( "importemot" ), 0, this, TQ_SLOT( slotImportEmoticon() ), actionCollection() );
+	d->copyURLAction = new TDEAction( i18n( "Copy Link Address" ), TQString::fromLatin1( "edit-copy" ), 0, this, TQ_SLOT( slotCopyURL() ), actionCollection() );
 
 	// read formatting override flags
 	readOverrides();
@@ -330,7 +330,7 @@ void ChatMessagePart::slotImportEmoticon()
     TQTextStream emoStream(fp);
     emoStream << themeXml.toString(4);
     fp->close();
-    TQTimer::singleShot( 1500, Kopete::Emoticons::self(), TQT_SLOT( reload() ) );
+    TQTimer::singleShot( 1500, Kopete::Emoticons::self(), TQ_SLOT( reload() ) );
 }
 
 void ChatMessagePart::save()
@@ -420,7 +420,7 @@ void ChatMessagePart::setStyle( const TQString &stylePath )
 
 	// Do the actual style switch
 	// Wait for the event loop before switching the style
-	TQTimer::singleShot( 0, this, TQT_SLOT(changeStyle()) );
+	TQTimer::singleShot( 0, this, TQ_SLOT(changeStyle()) );
 }
 
 void ChatMessagePart::setStyle( ChatWindowStyle *style )
@@ -430,7 +430,7 @@ void ChatMessagePart::setStyle( ChatWindowStyle *style )
 
 	// Do the actual style switch
 	// Wait for the event loop before switching the style
-	TQTimer::singleShot( 0, this, TQT_SLOT(changeStyle()) );
+	TQTimer::singleShot( 0, this, TQ_SLOT(changeStyle()) );
 }
 
 void ChatMessagePart::setStyleVariant( const TQString &variantPath )
@@ -593,7 +593,7 @@ void ChatMessagePart::appendMessage( Kopete::Message &message, bool restoring )
 	}
 
 	if ( !d->scrollPressed )
-		TQTimer::singleShot( 1, this, TQT_SLOT( slotScrollView() ) );
+		TQTimer::singleShot( 1, this, TQ_SLOT( slotScrollView() ) );
 
 #ifdef STYLE_TIMETEST
 	kdDebug(14000) << "Message time: " << beforeMessage.msecsTo( TQTime::currentTime()) << endl;
@@ -613,7 +613,7 @@ void ChatMessagePart::slotRefreshView()
 void ChatMessagePart::keepScrolledDown()
 {
 	if ( !d->scrollPressed )
-		TQTimer::singleShot( 1, this, TQT_SLOT( slotScrollView() ) );
+		TQTimer::singleShot( 1, this, TQ_SLOT( slotScrollView() ) );
 }
 
 const TQString ChatMessagePart::styleHTML() const
@@ -715,7 +715,7 @@ void ChatMessagePart::slotRightClick( const TQString &, const TQPoint &point )
 	if ( Kopete::Contact *contact = contactFromNode( d->activeElement ) )
 	{
 		chatWindowPopup = contact->popupMenu( d->manager );
-		connect( chatWindowPopup, TQT_SIGNAL( aboutToHide() ), chatWindowPopup , TQT_SLOT( deleteLater() ) );
+		connect( chatWindowPopup, TQ_SIGNAL( aboutToHide() ), chatWindowPopup , TQ_SLOT( deleteLater() ) );
 	}
 	else
 	{
@@ -741,7 +741,7 @@ void ChatMessagePart::slotRightClick( const TQString &, const TQPoint &point )
 		chatWindowPopup->insertSeparator();
 		d->closeAction->plug( chatWindowPopup );
 
-		connect( chatWindowPopup, TQT_SIGNAL( aboutToHide() ), chatWindowPopup, TQT_SLOT( deleteLater() ) );
+		connect( chatWindowPopup, TQ_SIGNAL( aboutToHide() ), chatWindowPopup, TQ_SLOT( deleteLater() ) );
 		chatWindowPopup->popup( point );
 	}
 
@@ -941,7 +941,7 @@ void ChatMessagePart::copy(bool justselection /* default false */)
 
 	if(text.isEmpty()) return;
 
-	disconnect( kapp->clipboard(), TQT_SIGNAL( selectionChanged()), this, TQT_SLOT( slotClearSelection()));
+	disconnect( kapp->clipboard(), TQ_SIGNAL( selectionChanged()), this, TQ_SLOT( slotClearSelection()));
 
 #ifndef TQT_NO_MIMECLIPBOARD
 	if(!justselection)
@@ -963,7 +963,7 @@ void ChatMessagePart::copy(bool justselection /* default false */)
     	TQApplication::clipboard()->setText( text, TQClipboard::Clipboard );
 	TQApplication::clipboard()->setText( text, TQClipboard::Selection );
 #endif
-	connect( kapp->clipboard(), TQT_SIGNAL( selectionChanged()), TQT_SLOT( slotClearSelection()));
+	connect( kapp->clipboard(), TQ_SIGNAL( selectionChanged()), TQ_SLOT( slotClearSelection()));
 
 }
 
@@ -1291,7 +1291,7 @@ void ChatMessagePart::slotUpdateHeaderPhoto()
 {
 	// Do the actual style switch
 	// Wait for the event loop before switching the style
-	TQTimer::singleShot( 0, this, TQT_SLOT(changeStyle()) );
+	TQTimer::singleShot( 0, this, TQ_SLOT(changeStyle()) );
 }
 
 void ChatMessagePart::changeStyle()
@@ -1376,6 +1376,3 @@ void ChatMessagePart::writeTemplate()
 }
 
 #include "chatmessagepart.moc"
-
-// vim: set noet ts=4 sts=4 sw=4:
-
