@@ -46,7 +46,7 @@ public:
 		emoticonSelector = new EmoticonSelector( m_popup, "KopeteEmoticonActionPrivate::emoticonSelector");
 		m_popup->insertItem( emoticonSelector );
 		// TODO: Maybe connect to kopeteprefs and redo list only on config changes
-		connect( m_popup, TQT_SIGNAL( aboutToShow() ), emoticonSelector, TQT_SLOT( prepareList() ) );
+		connect( m_popup, TQ_SIGNAL( aboutToShow() ), emoticonSelector, TQ_SLOT( prepareList() ) );
 	}
 
 	~KopeteEmoticonActionPrivate()
@@ -86,8 +86,8 @@ KopeteEmoticonAction::KopeteEmoticonAction( TQObject* parent, const char* name )
 		setIconSet( TQIconSet( icon ) );
 
 	setShortcutConfigurable( false );
-	connect( d->emoticonSelector, TQT_SIGNAL( ItemSelected( const TQString & ) ),
-		this, TQT_SIGNAL( activated( const TQString & ) ) );
+	connect( d->emoticonSelector, TQ_SIGNAL( ItemSelected( const TQString & ) ),
+		this, TQ_SIGNAL( activated( const TQString & ) ) );
 }
 
 KopeteEmoticonAction::~KopeteEmoticonAction()
@@ -136,7 +136,7 @@ int KopeteEmoticonAction::plug( TQWidget* widget, int index )
 //	kdDebug(14010) << "KopeteEmoticonAction::plug( " << widget << ", " << index << " )" << endl;
 
 	// KDE4/TQt TODO: Use qobject_cast instead.
-	if ( widget->inherits(TQPOPUPMENU_OBJECT_NAME_STRING) )
+	if ( widget->inherits("TQPopupMenu") )
 	{
 		TQPopupMenu* menu = static_cast<TQPopupMenu*>( widget );
 		int id;
@@ -149,7 +149,7 @@ int KopeteEmoticonAction::plug( TQWidget* widget, int index )
 			menu->setItemEnabled( id, false );
 
 		addContainer( menu, id );
-		connect( menu, TQT_SIGNAL( destroyed() ), this, TQT_SLOT( slotDestroyed() ) );
+		connect( menu, TQ_SIGNAL( destroyed() ), this, TQ_SLOT( slotDestroyed() ) );
 
 		if ( m_parentCollection )
 			m_parentCollection->connectHighlight( menu, this );
@@ -166,8 +166,8 @@ int KopeteEmoticonAction::plug( TQWidget* widget, int index )
 		if ( icon().isEmpty() && !iconSet(TDEIcon::Small).isNull() )
 		{
 			bar->insertButton(
-				iconSet(TDEIcon::Small).pixmap(), id_, TQT_SIGNAL(clicked()), this,
-				TQT_SLOT(slotActivated()), isEnabled(), plainText(),
+				iconSet(TDEIcon::Small).pixmap(), id_, TQ_SIGNAL(clicked()), this,
+				TQ_SLOT(slotActivated()), isEnabled(), plainText(),
 				index );
 		}
 		else
@@ -179,8 +179,8 @@ int KopeteEmoticonAction::plug( TQWidget* widget, int index )
 			else
 			instance = TDEGlobal::instance();
 
-			bar->insertButton( icon(), id_, TQT_SIGNAL( clicked() ), this,
-									TQT_SLOT( slotActivated() ), isEnabled(), plainText(),
+			bar->insertButton( icon(), id_, TQ_SIGNAL( clicked() ), this,
+									TQ_SLOT( slotActivated() ), isEnabled(), plainText(),
 									index, instance );
 		}
 
@@ -189,7 +189,7 @@ int KopeteEmoticonAction::plug( TQWidget* widget, int index )
 		if (!whatsThis().isEmpty())
 			TQWhatsThis::add( bar->getButton(id_), whatsThis() );
 
-		connect( bar, TQT_SIGNAL( destroyed() ), this, TQT_SLOT( slotDestroyed() ) );
+		connect( bar, TQ_SIGNAL( destroyed() ), this, TQ_SLOT( slotDestroyed() ) );
 
 		if (delayed())
 			bar->setDelayedPopup(id_, popupMenu(), stickyMenu());
@@ -202,7 +202,7 @@ int KopeteEmoticonAction::plug( TQWidget* widget, int index )
 		return containerCount() - 1;
 	}
 	// KDE4/TQt TODO: Use qobject_cast instead.
-	else if ( widget->inherits( TQMENUBAR_OBJECT_NAME_STRING ) )
+	else if ( widget->inherits( "TQMenuBar" ) )
 	{
 		TQMenuBar *bar = static_cast<TQMenuBar *>( widget );
 
@@ -214,7 +214,7 @@ int KopeteEmoticonAction::plug( TQWidget* widget, int index )
 			bar->setItemEnabled( id, false );
 
 		addContainer( bar, id );
-		connect( bar, TQT_SIGNAL( destroyed() ), this, TQT_SLOT( slotDestroyed() ) );
+		connect( bar, TQ_SIGNAL( destroyed() ), this, TQ_SLOT( slotDestroyed() ) );
 
 		return containerCount() - 1;
 	}
