@@ -79,7 +79,11 @@ class ContactListViewStrategy;
 class KopeteContactListViewPrivate
 {
 public:
-	std::auto_ptr<ContactListViewStrategy> viewStrategy;
+	KopeteContactListViewPrivate() {}
+	KopeteContactListViewPrivate(KopeteContactListViewPrivate const &) = delete;
+	KopeteContactListViewPrivate& operator=(KopeteContactListViewPrivate const &) = delete;
+
+	std::unique_ptr<ContactListViewStrategy> viewStrategy;
 
 	void updateViewStrategy( TDEListView *view );
 };
@@ -365,7 +369,7 @@ void KopeteContactListViewPrivate::updateViewStrategy( TDEListView *view )
 	if ( !viewStrategy.get() || KopetePrefs::prefs()->sortByGroup() != bSortByGroup )
 	{
 		// delete old strategy first...
-		viewStrategy.reset( 0 );
+		viewStrategy.reset();
 		// then create and store a new one
 		if ( KopetePrefs::prefs()->sortByGroup() )
 			viewStrategy.reset( new ArrangeByGroupsViewStrategy(view) );
@@ -411,38 +415,38 @@ KopeteContactListView::KopeteContactListView( TQWidget *parent, const char *name
 
 	setFullWidth( true );
 
-	connect( this, TQT_SIGNAL( contextMenu( TDEListView *, TQListViewItem *, const TQPoint & ) ),
-	         TQT_SLOT( slotContextMenu( TDEListView *, TQListViewItem *, const TQPoint & ) ) );
-	connect( this, TQT_SIGNAL( expanded( TQListViewItem * ) ),
-	         TQT_SLOT( slotExpanded( TQListViewItem * ) ) );
-	connect( this, TQT_SIGNAL( collapsed( TQListViewItem * ) ),
-	         TQT_SLOT( slotCollapsed( TQListViewItem * ) ) );
-	connect( this, TQT_SIGNAL( executed( TQListViewItem *, const TQPoint &, int ) ),
-	         TQT_SLOT( slotExecuted( TQListViewItem *, const TQPoint &, int ) ) );
-	connect( this, TQT_SIGNAL( selectionChanged() ), TQT_SLOT( slotViewSelectionChanged() ) );
-	connect( this, TQT_SIGNAL( itemRenamed( TQListViewItem * ) ),
-	         TQT_SLOT( slotItemRenamed( TQListViewItem * ) ) );
+	connect( this, TQ_SIGNAL( contextMenu( TDEListView *, TQListViewItem *, const TQPoint & ) ),
+	         TQ_SLOT( slotContextMenu( TDEListView *, TQListViewItem *, const TQPoint & ) ) );
+	connect( this, TQ_SIGNAL( expanded( TQListViewItem * ) ),
+	         TQ_SLOT( slotExpanded( TQListViewItem * ) ) );
+	connect( this, TQ_SIGNAL( collapsed( TQListViewItem * ) ),
+	         TQ_SLOT( slotCollapsed( TQListViewItem * ) ) );
+	connect( this, TQ_SIGNAL( executed( TQListViewItem *, const TQPoint &, int ) ),
+	         TQ_SLOT( slotExecuted( TQListViewItem *, const TQPoint &, int ) ) );
+	connect( this, TQ_SIGNAL( selectionChanged() ), TQ_SLOT( slotViewSelectionChanged() ) );
+	connect( this, TQ_SIGNAL( itemRenamed( TQListViewItem * ) ),
+	         TQ_SLOT( slotItemRenamed( TQListViewItem * ) ) );
 
-	connect( KopetePrefs::prefs(), TQT_SIGNAL( saved() ), TQT_SLOT( slotSettingsChanged() ) );
+	connect( KopetePrefs::prefs(), TQ_SIGNAL( saved() ), TQ_SLOT( slotSettingsChanged() ) );
 
-	connect( Kopete::ContactList::self(), TQT_SIGNAL( selectionChanged() ),
-	         TQT_SLOT( slotListSelectionChanged() ) );
+	connect( Kopete::ContactList::self(), TQ_SIGNAL( selectionChanged() ),
+	         TQ_SLOT( slotListSelectionChanged() ) );
 	connect( Kopete::ContactList::self(),
-	         TQT_SIGNAL( metaContactAdded( Kopete::MetaContact * ) ),
-	         TQT_SLOT( slotMetaContactAdded( Kopete::MetaContact * ) ) );
+	         TQ_SIGNAL( metaContactAdded( Kopete::MetaContact * ) ),
+	         TQ_SLOT( slotMetaContactAdded( Kopete::MetaContact * ) ) );
 	connect( Kopete::ContactList::self(),
-	         TQT_SIGNAL( metaContactRemoved( Kopete::MetaContact * ) ),
-	         TQT_SLOT( slotMetaContactDeleted( Kopete::MetaContact * ) ) );
-	connect( Kopete::ContactList::self(), TQT_SIGNAL( groupAdded( Kopete::Group * ) ),
-	         TQT_SLOT( slotGroupAdded( Kopete::Group * ) ) );
+	         TQ_SIGNAL( metaContactRemoved( Kopete::MetaContact * ) ),
+	         TQ_SLOT( slotMetaContactDeleted( Kopete::MetaContact * ) ) );
+	connect( Kopete::ContactList::self(), TQ_SIGNAL( groupAdded( Kopete::Group * ) ),
+	         TQ_SLOT( slotGroupAdded( Kopete::Group * ) ) );
 
-	connect( Kopete::ChatSessionManager::self(), TQT_SIGNAL( newEvent( Kopete::MessageEvent * ) ),
-	         this, TQT_SLOT( slotNewMessageEvent( Kopete::MessageEvent * ) ) );
+	connect( Kopete::ChatSessionManager::self(), TQ_SIGNAL( newEvent( Kopete::MessageEvent * ) ),
+	         this, TQ_SLOT( slotNewMessageEvent( Kopete::MessageEvent * ) ) );
 
-	connect( this, TQT_SIGNAL( dropped( TQDropEvent *, TQListViewItem *, TQListViewItem * ) ),
-	         this, TQT_SLOT( slotDropped( TQDropEvent *, TQListViewItem *, TQListViewItem * ) ) );
+	connect( this, TQ_SIGNAL( dropped( TQDropEvent *, TQListViewItem *, TQListViewItem * ) ),
+	         this, TQ_SLOT( slotDropped( TQDropEvent *, TQListViewItem *, TQListViewItem * ) ) );
 
-	connect( &undoTimer, TQT_SIGNAL(timeout()) , this, TQT_SLOT (slotTimeout() ) );
+	connect( &undoTimer, TQ_SIGNAL(timeout()) , this, TQ_SLOT (slotTimeout() ) );
 
 	addColumn( i18n( "Contacts" ), 0 );  //add an unique colums to add every contact
 	header()->hide(); // and hide the ugly header which show the single word  "Contacts"
@@ -461,33 +465,33 @@ KopeteContactListView::KopeteContactListView( TQWidget *parent, const char *name
 
 void KopeteContactListView::initActions( TDEActionCollection *ac )
 {
-	actionUndo = KStdAction::undo( TQT_TQOBJECT(this) , TQT_SLOT( slotUndo() ) , ac );
-	actionRedo = KStdAction::redo( TQT_TQOBJECT(this) , TQT_SLOT( slotRedo() ) , ac );
+	actionUndo = KStdAction::undo( this , TQ_SLOT( slotUndo() ) , ac );
+	actionRedo = KStdAction::redo( this , TQ_SLOT( slotRedo() ) , ac );
 	actionUndo->setEnabled(false);
 	actionRedo->setEnabled(false);
 
 
-	new TDEAction( i18n( "Create New Group..." ), 0, 0, TQT_TQOBJECT(this), TQT_SLOT( addGroup() ),
+	new TDEAction( i18n( "Create New Group..." ), 0, 0, this, TQ_SLOT( addGroup() ),
 		ac, "AddGroup" );
 
 	actionSendMessage = KopeteStdAction::sendMessage(
-		TQT_TQOBJECT(this), TQT_SLOT( slotSendMessage() ), ac, "contactSendMessage" );
-	actionStartChat = KopeteStdAction::chat( TQT_TQOBJECT(this), TQT_SLOT( slotStartChat() ),
+		this, TQ_SLOT( slotSendMessage() ), ac, "contactSendMessage" );
+	actionStartChat = KopeteStdAction::chat( this, TQ_SLOT( slotStartChat() ),
 		ac, "contactStartChat" );
 
 	actionMove = new KopeteGroupListAction( i18n( "&Move To" ), TQString::fromLatin1( "edit-cut" ),
-														  0, TQT_TQOBJECT(this), TQT_SLOT( slotMoveToGroup() ), ac, "contactMove" );
+														  0, this, TQ_SLOT( slotMoveToGroup() ), ac, "contactMove" );
 	actionCopy = new KopeteGroupListAction( i18n( "&Copy To" ), TQString::fromLatin1( "edit-copy" ), 0,
-														 TQT_TQOBJECT(this), TQT_SLOT( slotCopyToGroup() ), ac, "contactCopy" );
+														 this, TQ_SLOT( slotCopyToGroup() ), ac, "contactCopy" );
 
-	actionRemove = KopeteStdAction::deleteContact( TQT_TQOBJECT(this), TQT_SLOT( slotRemove() ),
+	actionRemove = KopeteStdAction::deleteContact( this, TQ_SLOT( slotRemove() ),
 		ac, "contactRemove" );
 	actionSendEmail = new TDEAction( i18n( "Send Email..." ), TQString::fromLatin1( "mail_generic" ),
-		0, TQT_TQOBJECT(this), TQT_SLOT(  slotSendEmail() ), ac, "contactSendEmail" );
+		0, this, TQ_SLOT(  slotSendEmail() ), ac, "contactSendEmail" );
 	/* this actionRename is buggy, and useless with properties, removed in kopeteui.rc*/
 	actionRename = new TDEAction( i18n( "Rename" ), "document-save-as", 0,
-		TQT_TQOBJECT(this), TQT_SLOT( slotRename() ), ac, "contactRename" );
-	actionSendFile = KopeteStdAction::sendFile( TQT_TQOBJECT(this), TQT_SLOT( slotSendFile() ),
+		this, TQ_SLOT( slotRename() ), ac, "contactRename" );
+	actionSendFile = KopeteStdAction::sendFile( this, TQ_SLOT( slotSendFile() ),
 		ac, "contactSendFile" );
 
 	actionAddContact = new TDEActionMenu( i18n( "&Add Contact" ),
@@ -495,15 +499,15 @@ void KopeteContactListView::initActions( TDEActionCollection *ac )
 	actionAddContact->popupMenu()->insertTitle( i18n("Select Account") );
 
 	actionAddTemporaryContact = new TDEAction( i18n( "Add to Your Contact List" ), "add_user", 0,
-		TQT_TQOBJECT(this), TQT_SLOT( slotAddTemporaryContact() ), ac, "contactAddTemporaryContact" );
+		this, TQ_SLOT( slotAddTemporaryContact() ), ac, "contactAddTemporaryContact" );
 
-	connect( Kopete::ContactList::self(), TQT_SIGNAL( metaContactSelected( bool ) ), this, TQT_SLOT( slotMetaContactSelected( bool ) ) );
+	connect( Kopete::ContactList::self(), TQ_SIGNAL( metaContactSelected( bool ) ), this, TQ_SLOT( slotMetaContactSelected( bool ) ) );
 
-	connect( Kopete::AccountManager::self(), TQT_SIGNAL(accountRegistered( Kopete::Account* )), TQT_SLOT(slotAddSubContactActionNewAccount(Kopete::Account*)));
-	connect( Kopete::AccountManager::self(), TQT_SIGNAL(accountUnregistered( const Kopete::Account* )), TQT_SLOT(slotAddSubContactActionAccountDeleted(const Kopete::Account *)));
+	connect( Kopete::AccountManager::self(), TQ_SIGNAL(accountRegistered( Kopete::Account* )), TQ_SLOT(slotAddSubContactActionNewAccount(Kopete::Account*)));
+	connect( Kopete::AccountManager::self(), TQ_SIGNAL(accountUnregistered( const Kopete::Account* )), TQ_SLOT(slotAddSubContactActionAccountDeleted(const Kopete::Account *)));
 
 	actionProperties = new TDEAction( i18n( "&Properties" ), "edit_user", TQt::Key_Alt + TQt::Key_Return,
-		TQT_TQOBJECT(this), TQT_SLOT( slotProperties() ), ac, "contactProperties" );
+		this, TQ_SLOT( slotProperties() ), ac, "contactProperties" );
 
 	// Update enabled/disabled actions
 	slotViewSelectionChanged();
@@ -516,7 +520,7 @@ KopeteContactListView::~KopeteContactListView()
 
 void KopeteContactListView::slotAddSubContactActionNewAccount(Kopete::Account* account)
 {
-	TDEAction *action = new TDEAction( account->accountLabel(), account->accountIcon(), 0 , TQT_TQOBJECT(this), TQT_SLOT(slotAddContact()), account);
+	TDEAction *action = new TDEAction( account->accountLabel(), account->accountIcon(), 0 , this, TQ_SLOT(slotAddContact()), account);
 	m_accountAddContactMap.insert( account, action);
 	actionAddContact->insert( action );
 }
@@ -536,14 +540,14 @@ void KopeteContactListView::slotMetaContactAdded( Kopete::MetaContact *mc )
 {
 	d->viewStrategy->addMetaContact( mc );
 
-	connect( mc, TQT_SIGNAL( addedToGroup( Kopete::MetaContact *, Kopete::Group * ) ),
-		TQT_SLOT( slotAddedToGroup( Kopete::MetaContact *, Kopete::Group * ) ) );
-	connect( mc, TQT_SIGNAL( removedFromGroup( Kopete::MetaContact *, Kopete::Group * ) ),
-		TQT_SLOT( slotRemovedFromGroup( Kopete::MetaContact *, Kopete::Group * ) ) );
-	connect( mc, TQT_SIGNAL( movedToGroup( Kopete::MetaContact *, Kopete::Group *, Kopete::Group * ) ),
-		TQT_SLOT( slotMovedToGroup( Kopete::MetaContact *, Kopete::Group *, Kopete::Group * ) ) );
-	connect( mc, TQT_SIGNAL( onlineStatusChanged( Kopete::MetaContact *, Kopete::OnlineStatus::StatusType ) ),
-		TQT_SLOT( slotContactStatusChanged( Kopete::MetaContact * ) ) );
+	connect( mc, TQ_SIGNAL( addedToGroup( Kopete::MetaContact *, Kopete::Group * ) ),
+		TQ_SLOT( slotAddedToGroup( Kopete::MetaContact *, Kopete::Group * ) ) );
+	connect( mc, TQ_SIGNAL( removedFromGroup( Kopete::MetaContact *, Kopete::Group * ) ),
+		TQ_SLOT( slotRemovedFromGroup( Kopete::MetaContact *, Kopete::Group * ) ) );
+	connect( mc, TQ_SIGNAL( movedToGroup( Kopete::MetaContact *, Kopete::Group *, Kopete::Group * ) ),
+		TQ_SLOT( slotMovedToGroup( Kopete::MetaContact *, Kopete::Group *, Kopete::Group * ) ) );
+	connect( mc, TQ_SIGNAL( onlineStatusChanged( Kopete::MetaContact *, Kopete::OnlineStatus::StatusType ) ),
+		TQ_SLOT( slotContactStatusChanged( Kopete::MetaContact * ) ) );
 }
 
 void KopeteContactListView::slotMetaContactDeleted( Kopete::MetaContact *mc )
@@ -678,7 +682,7 @@ void KopeteContactListView::slotContextMenu( TDEListView * /*listview*/,
 		if ( c )
 		{
 			TDEPopupMenu *p = c->popupMenu();
-			connect( p, TQT_SIGNAL( aboutToHide() ), p, TQT_SLOT( deleteLater() ) );
+			connect( p, TQ_SIGNAL( aboutToHide() ), p, TQ_SLOT( deleteLater() ) );
 			p->popup( point );
 		}
 		else
@@ -710,7 +714,7 @@ void KopeteContactListView::slotContextMenu( TDEListView * /*listview*/,
 					}
 
 					TDEPopupMenu *contactMenu = it.current()->popupMenu();
-					connect( popup, TQT_SIGNAL( aboutToHide() ), contactMenu, TQT_SLOT( deleteLater() ) );
+					connect( popup, TQ_SIGNAL( aboutToHide() ), contactMenu, TQ_SLOT( deleteLater() ) );
 					TQString nick=c->property(Kopete::Global::Properties::self()->nickName()).value().toString();
 					TQString text= nick.isEmpty() ?  c->contactId() : i18n( "Translators: format: '<displayName> (<id>)'", "%2 <%1>" ). arg( c->contactId(), nick );
 					text=text.replace("&","&&"); // cf BUG 115449
@@ -1205,7 +1209,7 @@ void KopeteContactListView::findDrop(const TQPoint &pos, TQListViewItem *&parent
 void KopeteContactListView::contentsMousePressEvent( TQMouseEvent *e )
 {
 	TDEListView::contentsMousePressEvent( e );
-	if (e->button() == Qt::LeftButton )
+	if (e->button() == TQt::LeftButton )
 	{
 		TQPoint p=contentsToViewport(e->pos());
 		TQListViewItem *i=itemAt( p );
