@@ -92,13 +92,13 @@ KopeteGVIProps::KopeteGVIProps(KopeteGroupViewItem *gvi, TQWidget *parent, const
 	mainWidget->icnbOpen->setIcon( openName );
 	mainWidget->icnbClosed->setIcon( closeName );
 
-	connect( this, TQT_SIGNAL(okClicked()), this, TQT_SLOT( slotOkClicked() ) );
-	connect( mainWidget->chkUseCustomIcons, TQT_SIGNAL( toggled( bool ) ),
-		this, TQT_SLOT( slotUseCustomIconsToggled( bool ) ) );
-	connect( mainWidget->icnbOpen, TQT_SIGNAL( iconChanged( TQString ) ),
-		TQT_SLOT( slotIconChanged() ) );
-	connect( mainWidget->icnbClosed, TQT_SIGNAL( iconChanged( TQString ) ),
-		TQT_SLOT( slotIconChanged() ) );
+	connect( this, TQ_SIGNAL(okClicked()), this, TQ_SLOT( slotOkClicked() ) );
+	connect( mainWidget->chkUseCustomIcons, TQ_SIGNAL( toggled( bool ) ),
+		this, TQ_SLOT( slotUseCustomIconsToggled( bool ) ) );
+	connect( mainWidget->icnbOpen, TQ_SIGNAL( iconChanged( TQString ) ),
+		TQ_SLOT( slotIconChanged() ) );
+	connect( mainWidget->icnbClosed, TQ_SIGNAL( iconChanged( TQString ) ),
+		TQ_SLOT( slotIconChanged() ) );
 	slotUseCustomIconsToggled( mainWidget->chkUseCustomIcons->isChecked() );
 }
 
@@ -170,19 +170,19 @@ KopeteMetaLVIProps::KopeteMetaLVIProps(KopeteMetaContactLVI *lvi, TQWidget *pare
 	setMainWidget( mainWidget );
 	item = lvi;
 
-	connect( mainWidget->radioNameKABC, TQT_SIGNAL(toggled(bool)), TQT_SLOT(slotEnableAndDisableWidgets()));
-	connect( mainWidget->radioNameContact, TQT_SIGNAL(toggled(bool)), TQT_SLOT(slotEnableAndDisableWidgets()));
-	connect( mainWidget->radioNameCustom, TQT_SIGNAL(toggled(bool)), TQT_SLOT(slotEnableAndDisableWidgets()));
-	connect( mainWidget->radioPhotoKABC, TQT_SIGNAL(toggled(bool)), TQT_SLOT(slotEnableAndDisableWidgets()));
-	connect( mainWidget->radioPhotoContact, TQT_SIGNAL(toggled(bool)), TQT_SLOT(slotEnableAndDisableWidgets()));
-	connect( mainWidget->radioPhotoCustom, TQT_SIGNAL(toggled(bool)), TQT_SLOT(slotEnableAndDisableWidgets()));
-	connect( mainWidget->cmbPhotoUrl, TQT_SIGNAL(urlSelected(const TQString &)), TQT_SLOT(slotEnableAndDisableWidgets()));
-	connect( mainWidget->cmbAccountPhoto, TQT_SIGNAL(activated ( int )), TQT_SLOT(slotEnableAndDisableWidgets()));
+	connect( mainWidget->radioNameKABC, TQ_SIGNAL(toggled(bool)), TQ_SLOT(slotEnableAndDisableWidgets()));
+	connect( mainWidget->radioNameContact, TQ_SIGNAL(toggled(bool)), TQ_SLOT(slotEnableAndDisableWidgets()));
+	connect( mainWidget->radioNameCustom, TQ_SIGNAL(toggled(bool)), TQ_SLOT(slotEnableAndDisableWidgets()));
+	connect( mainWidget->radioPhotoKABC, TQ_SIGNAL(toggled(bool)), TQ_SLOT(slotEnableAndDisableWidgets()));
+	connect( mainWidget->radioPhotoContact, TQ_SIGNAL(toggled(bool)), TQ_SLOT(slotEnableAndDisableWidgets()));
+	connect( mainWidget->radioPhotoCustom, TQ_SIGNAL(toggled(bool)), TQ_SLOT(slotEnableAndDisableWidgets()));
+	connect( mainWidget->cmbPhotoUrl, TQ_SIGNAL(urlSelected(const TQString &)), TQ_SLOT(slotEnableAndDisableWidgets()));
+	connect( mainWidget->cmbAccountPhoto, TQ_SIGNAL(activated ( int )), TQ_SLOT(slotEnableAndDisableWidgets()));
 	
 
 	mainWidget->btnClearPhoto->setIconSet( SmallIconSet( TQApplication::reverseLayout() ? "locationbar_erase" : "clear_left" ) );
-	connect( mainWidget->btnClearPhoto, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slotClearPhotoClicked() ) );
-	connect( mainWidget->widAddresseeLink, TQT_SIGNAL( addresseeChanged( const TDEABC::Addressee & ) ), TQT_SLOT( slotAddresseeChanged( const TDEABC::Addressee & ) ) );
+	connect( mainWidget->btnClearPhoto, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotClearPhotoClicked() ) );
+	connect( mainWidget->widAddresseeLink, TQ_SIGNAL( addresseeChanged( const TDEABC::Addressee & ) ), TQ_SLOT( slotAddresseeChanged( const TDEABC::Addressee & ) ) );
 	mainWidget->chkUseCustomIcons->setChecked( item->metaContact()->useCustomIcon() );
 
 	TQString offlineName = item->metaContact()->icon( Kopete::ContactListElement::Offline );
@@ -232,17 +232,17 @@ KopeteMetaLVIProps::KopeteMetaLVIProps(KopeteMetaContactLVI *lvi, TQWidget *pare
 	slotLoadNameSources();
 	slotLoadPhotoSources();
 
-	connect( this, TQT_SIGNAL(okClicked()), this, TQT_SLOT( slotOkClicked() ) );
-	connect( mainWidget->chkUseCustomIcons, TQT_SIGNAL( toggled( bool ) ),
-		this, TQT_SLOT( slotUseCustomIconsToggled( bool ) ) );
-	connect( mainWidget->btnImportKABC, TQT_SIGNAL( clicked() ),
-		this, TQT_SLOT( slotImportClicked() ) );
-	connect( mainWidget->btnExportKABC, TQT_SIGNAL( clicked() ),
-					 this, TQT_SLOT( slotExportClicked() ) );
-	connect( mFromKABC, TQT_SIGNAL( clicked() ),
-		this, TQT_SLOT( slotFromKABCClicked() ) );
-	connect( mNotificationProps->widget()->customSound, TQT_SIGNAL( openFileDialog( KURLRequester * )),
-             TQT_SLOT( slotOpenSoundDialog( KURLRequester * )));
+	connect( this, TQ_SIGNAL(okClicked()), this, TQ_SLOT( slotOkClicked() ) );
+	connect( mainWidget->chkUseCustomIcons, TQ_SIGNAL( toggled( bool ) ),
+		this, TQ_SLOT( slotUseCustomIconsToggled( bool ) ) );
+	connect( mainWidget->btnImportKABC, TQ_SIGNAL( clicked() ),
+		this, TQ_SLOT( slotImportClicked() ) );
+	connect( mainWidget->btnExportKABC, TQ_SIGNAL( clicked() ),
+					 this, TQ_SLOT( slotExportClicked() ) );
+	connect( mFromKABC, TQ_SIGNAL( clicked() ),
+		this, TQ_SLOT( slotFromKABCClicked() ) );
+	connect( mNotificationProps->widget()->customSound, TQ_SIGNAL( openFileDialog( KURLRequester * )),
+             TQ_SLOT( slotOpenSoundDialog( KURLRequester * )));
 
 	slotUseCustomIconsToggled( mainWidget->chkUseCustomIcons->isChecked() );
 	slotEnableAndDisableWidgets();
@@ -523,8 +523,8 @@ void KopeteMetaLVIProps::slotOpenSoundDialog( KURLRequester *requester )
 {
 	// taken from tdelibs/tdeio/tdefile/knotifydialog.cpp
 	// only need to init this once
-	requester->disconnect( TQT_SIGNAL( openFileDialog( KURLRequester * )),
-						this, TQT_SLOT( slotOpenSoundDialog( KURLRequester * )));
+	requester->disconnect( TQ_SIGNAL( openFileDialog( KURLRequester * )),
+						this, TQ_SLOT( slotOpenSoundDialog( KURLRequester * )));
 
 	KFileDialog *fileDialog = requester->fileDialog();
 	//fileDialog->setCaption( i18n("Select Sound File") );
