@@ -88,7 +88,7 @@ GlobalStatusMessageIconLabel::GlobalStatusMessageIconLabel(TQWidget *parent, con
 
 void GlobalStatusMessageIconLabel::mouseReleaseEvent( TQMouseEvent *event )
 {
-      if( event->button() == Qt::LeftButton || event->button() == Qt::RightButton )
+      if( event->button() == TQt::LeftButton || event->button() == TQt::RightButton )
       {
               emit iconClicked( event->globalPos() );
               event->accept();
@@ -140,8 +140,8 @@ KopeteWindow::KopeteWindow( TQWidget *parent, const char *name )
 	GlobalStatusMessageIconLabel *label = new GlobalStatusMessageIconLabel( statusBarMessage, "statusmsglabel" );
 	label->setFixedSize( 16, 16 );
 	label->setPixmap( SmallIcon( "kopetestatusmessage" ) );
-	connect(label, TQT_SIGNAL(iconClicked( const TQPoint& )),
-		this, TQT_SLOT(slotGlobalStatusMessageIconClicked( const TQPoint& )));
+	connect(label, TQ_SIGNAL(iconClicked( const TQPoint& )),
+		this, TQ_SLOT(slotGlobalStatusMessageIconClicked( const TQPoint& )));
 	TQToolTip::add( label, i18n( "Global status message" ) );
 	m_globalStatusMessage = new KSqueezedTextLabel( statusBarMessage );
 	statusBar()->addWidget(statusBarMessage, 1, false );
@@ -157,22 +157,22 @@ KopeteWindow::KopeteWindow( TQWidget *parent, const char *name )
 	// --------------------------------------------------------------------------------
 
 	// Trap all loaded plugins, so we can add their status bar icons accordingly , also used to add XMLGUIClient
-	connect( Kopete::PluginManager::self(), TQT_SIGNAL( pluginLoaded( Kopete::Plugin * ) ),
-		this, TQT_SLOT( slotPluginLoaded( Kopete::Plugin * ) ) );
-	connect( Kopete::PluginManager::self(), TQT_SIGNAL( allPluginsLoaded() ),
-		this, TQT_SLOT( slotAllPluginsLoaded() ));
+	connect( Kopete::PluginManager::self(), TQ_SIGNAL( pluginLoaded( Kopete::Plugin * ) ),
+		this, TQ_SLOT( slotPluginLoaded( Kopete::Plugin * ) ) );
+	connect( Kopete::PluginManager::self(), TQ_SIGNAL( allPluginsLoaded() ),
+		this, TQ_SLOT( slotAllPluginsLoaded() ));
 	//Connect the appropriate account signals
 	/* Please note that I tried to put this in the slotAllPluginsLoaded() function
 	 * but it seemed to break the account icons in the statusbar --Matt */
 
-	connect( Kopete::AccountManager::self(), TQT_SIGNAL(accountRegistered(Kopete::Account*)),
-		this, TQT_SLOT(slotAccountRegistered(Kopete::Account*)));
-	connect( Kopete::AccountManager::self(), TQT_SIGNAL(accountUnregistered(const Kopete::Account*)),
-		this, TQT_SLOT(slotAccountUnregistered(const Kopete::Account*)));
+	connect( Kopete::AccountManager::self(), TQ_SIGNAL(accountRegistered(Kopete::Account*)),
+		this, TQ_SLOT(slotAccountRegistered(Kopete::Account*)));
+	connect( Kopete::AccountManager::self(), TQ_SIGNAL(accountUnregistered(const Kopete::Account*)),
+		this, TQ_SLOT(slotAccountUnregistered(const Kopete::Account*)));
 
-	connect( m_autoHideTimer, TQT_SIGNAL( timeout() ), this, TQT_SLOT( slotAutoHide() ) );
-	connect( KopetePrefs::prefs(), TQT_SIGNAL( contactListAppearanceChanged() ),
-		this, TQT_SLOT( slotContactListAppearanceChanged() ) );
+	connect( m_autoHideTimer, TQ_SIGNAL( timeout() ), this, TQ_SLOT( slotAutoHide() ) );
+	connect( KopetePrefs::prefs(), TQ_SIGNAL( contactListAppearanceChanged() ),
+		this, TQ_SLOT( slotContactListAppearanceChanged() ) );
 
 	createGUI ( "kopeteui.rc", false );
 
@@ -209,22 +209,22 @@ void KopeteWindow::initActions()
 		actionCollection(), "AddContact" );
 	actionAddContact->setDelayed( false );
 	// this signal mapper is needed to call slotAddContact with the correct arguments
-	addContactMapper = new TQSignalMapper( TQT_TQOBJECT(this) );
-	connect( addContactMapper, TQT_SIGNAL( mapped( const TQString & ) ),
-		 this, TQT_SLOT( slotAddContactDialogInternal( const TQString & ) ) );
+	addContactMapper = new TQSignalMapper( this );
+	connect( addContactMapper, TQ_SIGNAL( mapped( const TQString & ) ),
+		 this, TQ_SLOT( slotAddContactDialogInternal( const TQString & ) ) );
 
 	/* ConnectAll is now obsolete.  "Go online" has replaced it.
 	actionConnect = new TDEAction( i18n( "&Connect Accounts" ), "connect_creating",
-		0, Kopete::AccountManager::self(), TQT_SLOT( connectAll() ),
+		0, Kopete::AccountManager::self(), TQ_SLOT( connectAll() ),
 		actionCollection(), "ConnectAll" );
 	*/
 
 	actionDisconnect = new TDEAction( i18n( "O&ffline" ), "connect_no",
-		0, TQT_TQOBJECT(this), TQT_SLOT( slotDisconnectAll() ),
+		0, this, TQ_SLOT( slotDisconnectAll() ),
 		actionCollection(), "DisconnectAll" );
 
-	actionExportContacts = new TDEAction( i18n( "&Export Contacts..." ), "", 0, TQT_TQOBJECT(this),
-		TQT_SLOT( showExportDialog() ),actionCollection(), "ExportContacts" );
+	actionExportContacts = new TDEAction( i18n( "&Export Contacts..." ), "", 0, this,
+		TQ_SLOT( showExportDialog() ),actionCollection(), "ExportContacts" );
 
 	/* the connection menu has been replaced by the set status menu
 	actionConnectionMenu = new TDEActionMenu( i18n("Connection"),"connect_established",
@@ -238,28 +238,28 @@ void KopeteWindow::initActions()
 	actionDisconnect->setEnabled(false);
 
 	selectAway = new TDEAction( i18n("&Away"), SmallIcon("kopeteaway"), 0,
-		TQT_TQOBJECT(this), TQT_SLOT( slotGlobalAway() ), actionCollection(),
+		this, TQ_SLOT( slotGlobalAway() ), actionCollection(),
 		"SetAwayAll" );
 
 	selectBusy = new TDEAction( i18n("&Busy"), SmallIcon("kopeteaway"), 0,
-					 TQT_TQOBJECT(this), TQT_SLOT( slotGlobalBusy() ), actionCollection(),
+					 this, TQ_SLOT( slotGlobalBusy() ), actionCollection(),
 					 "SetBusyAll" );
 
 
 	actionSetInvisible = new TDEAction( i18n( "&Invisible" ), "kopeteavailable", 0 ,
-		  TQT_TQOBJECT(this), TQT_SLOT( slotSetInvisibleAll() ), actionCollection(),
+		  this, TQ_SLOT( slotSetInvisibleAll() ), actionCollection(),
 		  "SetInvisibleAll" );
 
 
 
 	/*actionSetAvailable = new TDEAction( i18n( "&Online" ),
 		"kopeteavailable", 0 , Kopete::AccountManager::self(),
-		TQT_SLOT( setAvailableAll() ), actionCollection(),
+		TQ_SLOT( setAvailableAll() ), actionCollection(),
 		"SetAvailableAll" );*/
 
 	actionSetAvailable = new TDEAction( i18n("&Online"),
-		SmallIcon("kopeteavailable"), 0, TQT_TQOBJECT(this),
-		TQT_SLOT( slotGlobalAvailable() ), actionCollection(),
+		SmallIcon("kopeteavailable"), 0, this,
+		TQ_SLOT( slotGlobalAvailable() ), actionCollection(),
 		"SetAvailableAll" );
 
 	actionAwayMenu = new TDEActionMenu( i18n("&Set Status"), "kopeteavailable",
@@ -273,25 +273,25 @@ void KopeteWindow::initActions()
 
 	actionPrefs = KopeteStdAction::preferences( actionCollection(), "settings_prefs" );
 
-	KStdAction::quit(TQT_TQOBJECT(this), TQT_SLOT(slotQuit()), actionCollection());
+	KStdAction::quit(this, TQ_SLOT(slotQuit()), actionCollection());
 
 	setStandardToolBarMenuEnabled(true);
-	menubarAction = KStdAction::showMenubar(TQT_TQOBJECT(this), TQT_SLOT(showMenubar()), actionCollection(), "settings_showmenubar" );
-	statusbarAction = KStdAction::showStatusbar(TQT_TQOBJECT(this), TQT_SLOT(showStatusbar()), actionCollection(), "settings_showstatusbar");
+	menubarAction = KStdAction::showMenubar(this, TQ_SLOT(showMenubar()), actionCollection(), "settings_showmenubar" );
+	statusbarAction = KStdAction::showStatusbar(this, TQ_SLOT(showStatusbar()), actionCollection(), "settings_showstatusbar");
 
-	KStdAction::keyBindings( guiFactory(), TQT_SLOT( configureShortcuts() ), actionCollection(), "settings_keys" );
-	new TDEAction( i18n( "Configure Plugins..." ), "preferences-desktop-peripherals", 0, TQT_TQOBJECT(this),
-		TQT_SLOT( slotConfigurePlugins() ), actionCollection(), "settings_plugins" );
-	new TDEAction( i18n( "Configure &Global Shortcuts..." ), "configure_shortcuts", 0, TQT_TQOBJECT(this),
-		TQT_SLOT( slotConfGlobalKeys() ), actionCollection(), "settings_global" );
+	KStdAction::keyBindings( guiFactory(), TQ_SLOT( configureShortcuts() ), actionCollection(), "settings_keys" );
+	new TDEAction( i18n( "Configure Plugins..." ), "preferences-desktop-peripherals", 0, this,
+		TQ_SLOT( slotConfigurePlugins() ), actionCollection(), "settings_plugins" );
+	new TDEAction( i18n( "Configure &Global Shortcuts..." ), "configure_shortcuts", 0, this,
+		TQ_SLOT( slotConfGlobalKeys() ), actionCollection(), "settings_global" );
 
-	KStdAction::configureToolbars( TQT_TQOBJECT(this), TQT_SLOT(slotConfToolbar()), actionCollection() );
-	KStdAction::configureNotifications(TQT_TQOBJECT(this), TQT_SLOT(slotConfNotifications()), actionCollection(), "settings_notifications" );
+	KStdAction::configureToolbars( this, TQ_SLOT(slotConfToolbar()), actionCollection() );
+	KStdAction::configureNotifications(this, TQ_SLOT(slotConfNotifications()), actionCollection(), "settings_notifications" );
 
 	actionShowOffliners = new TDEToggleAction( i18n( "Show Offline &Users" ), "show_offliners", CTRL + Key_U,
-			TQT_TQOBJECT(this), TQT_SLOT( slotToggleShowOffliners() ), actionCollection(), "settings_show_offliners" );
+			this, TQ_SLOT( slotToggleShowOffliners() ), actionCollection(), "settings_show_offliners" );
 	actionShowEmptyGroups = new TDEToggleAction( i18n( "Show Empty &Groups" ), "folder", CTRL + Key_G,
-			TQT_TQOBJECT(this), TQT_SLOT( slotToggleShowEmptyGroups() ), actionCollection(), "settings_show_empty_groups" );
+			this, TQ_SLOT( slotToggleShowEmptyGroups() ), actionCollection(), "settings_show_empty_groups" );
 
 	actionShowOffliners->setCheckedState(i18n("Hide Offline &Users"));
 	actionShowEmptyGroups->setCheckedState(i18n("Hide Empty &Groups"));
@@ -306,7 +306,7 @@ void KopeteWindow::initActions()
 	// quick search bar - clear button
 	TDEAction *resetQuickSearch = new TDEAction( i18n( "Reset Quick Search" ),
 		TQApplication::reverseLayout() ? "clear_left" : "locationbar_erase",
-		0, TQT_TQOBJECT(searchBar), TQT_SLOT( clear() ), actionCollection(), "quicksearch_reset" );
+		0, searchBar, TQ_SLOT( clear() ), actionCollection(), "quicksearch_reset" );
 	resetQuickSearch->setWhatsThis( i18n( "Reset Quick Search\n"
 		"Resets the quick search so that all contacts and groups are shown again." ) );
 
@@ -319,22 +319,22 @@ void KopeteWindow::initActions()
 	// TDEActionMenu for selecting the global status message(kopeteonlinestatus_0)
 	TDEActionMenu * setStatusMenu = new TDEActionMenu( i18n( "Set Status Message" ), "kopeteeditstatusmessage", actionCollection(), "SetStatusMessage" );
 	setStatusMenu->setDelayed( false );
-	connect( setStatusMenu->popupMenu(), TQT_SIGNAL( aboutToShow() ), TQT_SLOT(slotBuildStatusMessageMenu() ) );
-	connect( setStatusMenu->popupMenu(), TQT_SIGNAL( activated( int ) ), TQT_SLOT(slotStatusMessageSelected( int ) ) );
+	connect( setStatusMenu->popupMenu(), TQ_SIGNAL( aboutToShow() ), TQ_SLOT(slotBuildStatusMessageMenu() ) );
+	connect( setStatusMenu->popupMenu(), TQ_SIGNAL( activated( int ) ), TQ_SLOT(slotStatusMessageSelected( int ) ) );
 
 	// sync actions, config and prefs-dialog
-	connect ( KopetePrefs::prefs(), TQT_SIGNAL(saved()), TQT_TQOBJECT(this), TQT_SLOT(slotConfigChanged()) );
+	connect ( KopetePrefs::prefs(), TQ_SIGNAL(saved()), this, TQ_SLOT(slotConfigChanged()) );
 	slotConfigChanged();
 
-	globalAccel = new TDEGlobalAccel( TQT_TQOBJECT(this) );
+	globalAccel = new TDEGlobalAccel( this );
 	globalAccel->insert( TQString::fromLatin1("Read Message"), i18n("Read Message"), i18n("Read the next pending message"),
-		CTRL+SHIFT+Key_I, KKey::QtWIN+CTRL+Key_I, Kopete::ChatSessionManager::self(), TQT_SLOT(slotReadMessage()) );
+		CTRL+SHIFT+Key_I, KKey::QtWIN+CTRL+Key_I, Kopete::ChatSessionManager::self(), TQ_SLOT(slotReadMessage()) );
 
 	globalAccel->insert( TQString::fromLatin1("Show/Hide Contact List"), i18n("Show/Hide Contact List"), i18n("Show or hide the contact list"),
-		CTRL+SHIFT+Key_S, KKey::QtWIN+CTRL+Key_S, TQT_TQOBJECT(this), TQT_SLOT(slotShowHide()) );
+		CTRL+SHIFT+Key_S, KKey::QtWIN+CTRL+Key_S, this, TQ_SLOT(slotShowHide()) );
 
 	globalAccel->insert( TQString::fromLatin1("Set Away/Back"), i18n("Set Away/Back"), i18n("Sets away from keyboard or sets back"),
-		CTRL+SHIFT+Key_W, KKey::QtWIN+CTRL+SHIFT+Key_W, TQT_TQOBJECT(this), TQT_SLOT(slotToggleAway()) );
+		CTRL+SHIFT+Key_W, KKey::QtWIN+CTRL+SHIFT+Key_W, this, TQ_SLOT(slotToggleAway()) );
 
 	globalAccel->readSettings();
 	globalAccel->updateConnections();
@@ -391,9 +391,9 @@ void KopeteWindow::initSystray()
 	//actionConnectionMenu->plug ( tm, 1 );
 	tm->insertSeparator( 1 );
 
-	TQObject::connect( m_tray, TQT_SIGNAL( aboutToShowMenu( TDEPopupMenu * ) ),
-		this, TQT_SLOT( slotTrayAboutToShowMenu( TDEPopupMenu * ) ) );
-	TQObject::connect( m_tray, TQT_SIGNAL( quitSelected() ), this, TQT_SLOT( slotQuit() ) );
+	TQObject::connect( m_tray, TQ_SIGNAL( aboutToShowMenu( TDEPopupMenu * ) ),
+		this, TQ_SLOT( slotTrayAboutToShowMenu( TDEPopupMenu * ) ) );
+	TQObject::connect( m_tray, TQ_SIGNAL( quitSelected() ), this, TQ_SLOT( slotQuit() ) );
 }
 
 KopeteWindow::~KopeteWindow()
@@ -430,7 +430,7 @@ void KopeteWindow::loadOptions()
 
 	// FIXME: HACK: Is there a way to do that automatic ?
 	editGlobalIdentityWidget->setIconSize(toolBar("editGlobalIdentityBar")->iconSize());
-	connect(toolBar("editGlobalIdentityBar"), TQT_SIGNAL(modechange()), editGlobalIdentityWidget, TQT_SLOT(iconSizeChanged()));
+	connect(toolBar("editGlobalIdentityBar"), TQ_SIGNAL(modechange()), editGlobalIdentityWidget, TQ_SLOT(iconSizeChanged()));
 
 	applyMainWindowSettings( config, "General Options" );
 	config->setGroup("General Options");
@@ -518,9 +518,9 @@ void KopeteWindow::slotToggleShowOffliners()
 	KopetePrefs *p = KopetePrefs::prefs();
 	p->setShowOffline ( actionShowOffliners->isChecked() );
 
-	disconnect ( KopetePrefs::prefs(), TQT_SIGNAL(saved()), this, TQT_SLOT(slotConfigChanged()) );
+	disconnect ( KopetePrefs::prefs(), TQ_SIGNAL(saved()), this, TQ_SLOT(slotConfigChanged()) );
 	p->save();
-	connect ( KopetePrefs::prefs(), TQT_SIGNAL(saved()), this, TQT_SLOT(slotConfigChanged()) );
+	connect ( KopetePrefs::prefs(), TQ_SIGNAL(saved()), this, TQ_SLOT(slotConfigChanged()) );
 }
 
 void KopeteWindow::slotToggleShowEmptyGroups()
@@ -528,9 +528,9 @@ void KopeteWindow::slotToggleShowEmptyGroups()
 	KopetePrefs *p = KopetePrefs::prefs();
 	p->setShowEmptyGroups ( actionShowEmptyGroups->isChecked() );
 
-	disconnect ( KopetePrefs::prefs(), TQT_SIGNAL(saved()), this, TQT_SLOT(slotConfigChanged()) );
+	disconnect ( KopetePrefs::prefs(), TQ_SIGNAL(saved()), this, TQ_SLOT(slotConfigChanged()) );
 	p->save();
-	connect ( KopetePrefs::prefs(), TQT_SIGNAL(saved()), this, TQT_SLOT(slotConfigChanged()) );
+	connect ( KopetePrefs::prefs(), TQ_SIGNAL(saved()), this, TQ_SLOT(slotConfigChanged()) );
 }
 
 void KopeteWindow::slotConfigChanged()
@@ -578,8 +578,8 @@ void KopeteWindow::slotConfToolbar()
 {
 	saveMainWindowSettings(TDEGlobal::config(), "General Options");
 	KEditToolbar *dlg = new KEditToolbar(factory());
-	connect( dlg, TQT_SIGNAL(newToolbarConfig()), this, TQT_SLOT(slotUpdateToolbar()) );
-	connect( dlg, TQT_SIGNAL(finished()) , dlg, TQT_SLOT(deleteLater()));
+	connect( dlg, TQ_SIGNAL(newToolbarConfig()), this, TQ_SLOT(slotUpdateToolbar()) );
+	connect( dlg, TQ_SIGNAL(finished()) , dlg, TQ_SLOT(deleteLater()));
 	dlg->show();
 }
 
@@ -704,31 +704,31 @@ void KopeteWindow::slotAccountRegistered( Kopete::Account *account )
 	actionDisconnect->setEnabled(true);
 
 	connect( account->myself(),
-		TQT_SIGNAL(onlineStatusChanged( Kopete::Contact *, const Kopete::OnlineStatus &, const Kopete::OnlineStatus &) ),
-		this, TQT_SLOT( slotAccountStatusIconChanged( Kopete::Contact * ) ) );
+		TQ_SIGNAL(onlineStatusChanged( Kopete::Contact *, const Kopete::OnlineStatus &, const Kopete::OnlineStatus &) ),
+		this, TQ_SLOT( slotAccountStatusIconChanged( Kopete::Contact * ) ) );
 
-//	connect( account, TQT_SIGNAL( iconAppearanceChanged() ), TQT_SLOT( slotAccountStatusIconChanged() ) );
-	connect( account, TQT_SIGNAL( colorChanged(const TQColor& ) ), TQT_SLOT( slotAccountStatusIconChanged() ) );
+//	connect( account, TQ_SIGNAL( iconAppearanceChanged() ), TQ_SLOT( slotAccountStatusIconChanged() ) );
+	connect( account, TQ_SIGNAL( colorChanged(const TQColor& ) ), TQ_SLOT( slotAccountStatusIconChanged() ) );
 
 	connect( account->myself(),
-		TQT_SIGNAL(propertyChanged( Kopete::Contact *, const TQString &, const TQVariant &, const TQVariant & ) ),
-		this, TQT_SLOT( slotAccountStatusIconChanged( Kopete::Contact* ) ) );
+		TQ_SIGNAL(propertyChanged( Kopete::Contact *, const TQString &, const TQVariant &, const TQVariant & ) ),
+		this, TQ_SLOT( slotAccountStatusIconChanged( Kopete::Contact* ) ) );
 
 	KopeteAccountStatusBarIcon *sbIcon = new KopeteAccountStatusBarIcon( account, m_statusBarWidget );
-	connect( sbIcon, TQT_SIGNAL( rightClicked( Kopete::Account *, const TQPoint & ) ),
-		TQT_SLOT( slotAccountStatusIconRightClicked( Kopete::Account *,
+	connect( sbIcon, TQ_SIGNAL( rightClicked( Kopete::Account *, const TQPoint & ) ),
+		TQ_SLOT( slotAccountStatusIconRightClicked( Kopete::Account *,
 		const TQPoint & ) ) );
-	connect( sbIcon, TQT_SIGNAL( leftClicked( Kopete::Account *, const TQPoint & ) ),
-		TQT_SLOT( slotAccountStatusIconRightClicked( Kopete::Account *,
+	connect( sbIcon, TQ_SIGNAL( leftClicked( Kopete::Account *, const TQPoint & ) ),
+		TQ_SLOT( slotAccountStatusIconRightClicked( Kopete::Account *,
 		const TQPoint & ) ) );
 
-	m_accountStatusBarIcons.insert( account, TQT_TQOBJECT(sbIcon) );
+	m_accountStatusBarIcons.insert( account, sbIcon );
 	slotAccountStatusIconChanged( account->myself() );
 	
 	// add an item for this account to the add contact actionmenu
 	TQString s = "actionAdd%1Contact";
 	s.arg( account->accountId() );
-	TDEAction *action = new TDEAction( account->accountLabel(), account->accountIcon(), 0 , addContactMapper, TQT_SLOT( map() ), account, s.latin1() );
+	TDEAction *action = new TDEAction( account->accountLabel(), account->accountIcon(), 0 , addContactMapper, TQ_SLOT( map() ), account, s.latin1() );
 	addContactMapper->setMapping( action, account->protocol()->pluginId() + TQChar(0xE000) + account->accountId() );
 	actionAddContact->insert( action );
 }
@@ -744,7 +744,7 @@ void KopeteWindow::slotAccountUnregistered( const Kopete::Account *account)
 	}
 
 	// the (void*)  is to remove the const.  i don't know why TQPtrList doesn't accept const ptr as key.
-	KopeteAccountStatusBarIcon *sbIcon = static_cast<KopeteAccountStatusBarIcon *>( TQT_TQWIDGET(m_accountStatusBarIcons[ (void*)account ]) );
+	KopeteAccountStatusBarIcon *sbIcon = static_cast<KopeteAccountStatusBarIcon *>( m_accountStatusBarIcons[ (void*)account ] );
 
 	if( !sbIcon )
 		return;
@@ -816,7 +816,7 @@ void KopeteWindow::slotAccountStatusIconChanged( Kopete::Contact *contact )
 		}
 	}
 	
-	KopeteAccountStatusBarIcon *i = static_cast<KopeteAccountStatusBarIcon *>( TQT_TQWIDGET(m_accountStatusBarIcons[ contact->account() ]) );
+	KopeteAccountStatusBarIcon *i = static_cast<KopeteAccountStatusBarIcon *>( m_accountStatusBarIcons[ contact->account() ] );
 	if( !i )
 		return;
 
@@ -882,7 +882,7 @@ void KopeteWindow::slotAccountStatusIconRightClicked( Kopete::Account *account,
 	if ( !actionMenu )
 		return;
 
-	connect( actionMenu->popupMenu(), TQT_SIGNAL( aboutToHide() ), actionMenu, TQT_SLOT( deleteLater() ) );
+	connect( actionMenu->popupMenu(), TQ_SIGNAL( aboutToHide() ), actionMenu, TQ_SLOT( deleteLater() ) );
 	actionMenu->popupMenu()->popup( p );
 }
 
@@ -895,7 +895,7 @@ void KopeteWindow::slotTrayAboutToShowMenu( TDEPopupMenu * popup )
 		if( menu )
 			menu->plug(popup, 1 );
 
-		connect(popup , TQT_SIGNAL(aboutToHide()) , menu , TQT_SLOT(deleteLater()));
+		connect(popup , TQ_SIGNAL(aboutToHide()) , menu , TQ_SLOT(deleteLater()));
 	}
 
 }
@@ -909,7 +909,7 @@ void KopeteWindow::slotTrayAboutToShowMenu( TDEPopupMenu * popup )
 	{
 		TDEActionMenu *menu = proto->protocolActions();
 
-		connect( menu->popupMenu(), TQT_SIGNAL( aboutToHide() ), menu, TQT_SLOT( deleteLater() ) );
+		connect( menu->popupMenu(), TQ_SIGNAL( aboutToHide() ), menu, TQ_SLOT( deleteLater() ) );
 		menu->popupMenu()->popup( p );
 	}
 }*/
@@ -990,7 +990,7 @@ void KopeteWindow::slotBuildStatusMessageMenu()
 	newMessageLabel->setFocusPolicy( TQWidget::ClickFocus );*/
 	newMessagePix->setFocusProxy( m_newMessageEdit );
 	newMessagePix->setFocusPolicy( TQWidget::ClickFocus );
-	connect( m_newMessageEdit, TQT_SIGNAL( returnPressed() ), TQT_SLOT( slotNewStatusMessageEntered() ) );
+	connect( m_newMessageEdit, TQ_SIGNAL( returnPressed() ), TQ_SLOT( slotNewStatusMessageEntered() ) );
 
 	m_globalStatusMessageMenu->insertItem( newMessageBox );
 
@@ -1004,8 +1004,8 @@ void KopeteWindow::slotBuildStatusMessageMenu()
 	{
 		m_globalStatusMessageMenu->insertItem( KStringHandler::rsqueeze( *it ), i );
 	}
-//	connect( m_globalStatusMessageMenu, TQT_SIGNAL( activated( int ) ), TQT_SLOT( slotStatusMessageSelected( int ) ) );
-//	connect( messageMenu, TQT_SIGNAL( aboutToHide() ), messageMenu, TQT_SLOT( deleteLater() ) );
+//	connect( m_globalStatusMessageMenu, TQ_SIGNAL( activated( int ) ), TQ_SLOT( slotStatusMessageSelected( int ) ) );
+//	connect( messageMenu, TQ_SIGNAL( aboutToHide() ), messageMenu, TQ_SLOT( deleteLater() ) );
 
 	m_newMessageEdit->setFocus();
 
@@ -1033,10 +1033,10 @@ void KopeteWindow::slotNewStatusMessageEntered()
 void KopeteWindow::slotGlobalStatusMessageIconClicked( const TQPoint &position )
 {
 	TDEPopupMenu *statusMessageIconMenu = new TDEPopupMenu(this, "statusMessageIconMenu");
-	connect(statusMessageIconMenu, TQT_SIGNAL( aboutToShow() ),
-		this, TQT_SLOT(slotBuildStatusMessageMenu()));
-	connect( statusMessageIconMenu, TQT_SIGNAL( activated( int ) ),
-				TQT_SLOT( slotStatusMessageSelected( int ) ) );
+	connect(statusMessageIconMenu, TQ_SIGNAL( aboutToShow() ),
+		this, TQ_SLOT(slotBuildStatusMessageMenu()));
+	connect( statusMessageIconMenu, TQ_SIGNAL( activated( int ) ),
+				TQ_SLOT( slotStatusMessageSelected( int ) ) );
 
 	statusMessageIconMenu->popup(position);
 }
