@@ -38,7 +38,7 @@ ChatSessionManager* ChatSessionManager::s_self = 0L;
 ChatSessionManager* ChatSessionManager::self()
 {
 	if( !s_self )
-		s_self = new ChatSessionManager( TQT_TQOBJECT(kapp) );
+		s_self = new ChatSessionManager( kapp );
 
 	return s_self;
 }
@@ -128,15 +128,15 @@ void ChatSessionManager::registerChatSession(ChatSession * result)
 	 * There's no need for a slot here... just add a public remove()
 	 * method and call from KMM's destructor
 	 */
-	connect( result, TQT_SIGNAL( messageAppended( Kopete::Message &, Kopete::ChatSession * ) ),
-		TQT_SIGNAL( aboutToDisplay( Kopete::Message & ) ) );
-	connect( result, TQT_SIGNAL( messageSent( Kopete::Message &, Kopete::ChatSession * ) ),
-		TQT_SIGNAL( aboutToSend(Kopete::Message & ) ) );
-	connect( result, TQT_SIGNAL( messageReceived( Kopete::Message &, Kopete::ChatSession * ) ),
-		TQT_SIGNAL( aboutToReceive(Kopete::Message & ) ) );
+	connect( result, TQ_SIGNAL( messageAppended( Kopete::Message &, Kopete::ChatSession * ) ),
+		TQ_SIGNAL( aboutToDisplay( Kopete::Message & ) ) );
+	connect( result, TQ_SIGNAL( messageSent( Kopete::Message &, Kopete::ChatSession * ) ),
+		TQ_SIGNAL( aboutToSend(Kopete::Message & ) ) );
+	connect( result, TQ_SIGNAL( messageReceived( Kopete::Message &, Kopete::ChatSession * ) ),
+		TQ_SIGNAL( aboutToReceive(Kopete::Message & ) ) );
 
-	connect( result, TQT_SIGNAL(messageAppended( Kopete::Message &, Kopete::ChatSession *) ),
-		TQT_SIGNAL( display( Kopete::Message &, Kopete::ChatSession *) ) );
+	connect( result, TQ_SIGNAL(messageAppended( Kopete::Message &, Kopete::ChatSession *) ),
+		TQ_SIGNAL( display( Kopete::Message &, Kopete::ChatSession *) ) );
 
 	emit chatSessionCreated(result);
 }
@@ -165,10 +165,10 @@ KopeteView * ChatSessionManager::createView( ChatSession *kmm , const TQString &
 	TQObject *viewObject = dynamic_cast<TQObject *>(newView);
 	if(viewObject)
 	{
-		connect(viewObject, TQT_SIGNAL(activated(KopeteView *)),
-			this, TQT_SIGNAL(viewActivated(KopeteView *)));
-		connect(viewObject, TQT_SIGNAL(closing(KopeteView *)),
-			this, TQT_SIGNAL(viewClosing(KopeteView *)));
+		connect(viewObject, TQ_SIGNAL(activated(KopeteView *)),
+			this, TQ_SIGNAL(viewActivated(KopeteView *)));
+		connect(viewObject, TQ_SIGNAL(closing(KopeteView *)),
+			this, TQ_SIGNAL(viewClosing(KopeteView *)));
 	}
 	else
 	{
