@@ -101,18 +101,18 @@ MetaContact::MetaContact()
 {
 	d = new Private;
 
-	connect( this, TQT_SIGNAL( pluginDataChanged() ), TQT_SIGNAL( persistentDataChanged() ) );
-	connect( this, TQT_SIGNAL( iconChanged( Kopete::ContactListElement::IconState, const TQString & ) ), TQT_SIGNAL( persistentDataChanged() ) );
-	connect( this, TQT_SIGNAL( useCustomIconChanged( bool ) ), TQT_SIGNAL( persistentDataChanged() ) );
-	connect( this, TQT_SIGNAL( displayNameChanged( const TQString &, const TQString & ) ), TQT_SIGNAL( persistentDataChanged() ) );
-	connect( this, TQT_SIGNAL( movedToGroup( Kopete::MetaContact *, Kopete::Group *, Kopete::Group * ) ), TQT_SIGNAL( persistentDataChanged() ) );
-	connect( this, TQT_SIGNAL( removedFromGroup( Kopete::MetaContact *, Kopete::Group * ) ), TQT_SIGNAL( persistentDataChanged() ) );
-	connect( this, TQT_SIGNAL( addedToGroup( Kopete::MetaContact *, Kopete::Group * ) ), TQT_SIGNAL( persistentDataChanged() ) );
-	connect( this, TQT_SIGNAL( contactAdded( Kopete::Contact * ) ), TQT_SIGNAL( persistentDataChanged() ) );
-	connect( this, TQT_SIGNAL( contactRemoved( Kopete::Contact * ) ), TQT_SIGNAL( persistentDataChanged() ) );
+	connect( this, TQ_SIGNAL( pluginDataChanged() ), TQ_SIGNAL( persistentDataChanged() ) );
+	connect( this, TQ_SIGNAL( iconChanged( Kopete::ContactListElement::IconState, const TQString & ) ), TQ_SIGNAL( persistentDataChanged() ) );
+	connect( this, TQ_SIGNAL( useCustomIconChanged( bool ) ), TQ_SIGNAL( persistentDataChanged() ) );
+	connect( this, TQ_SIGNAL( displayNameChanged( const TQString &, const TQString & ) ), TQ_SIGNAL( persistentDataChanged() ) );
+	connect( this, TQ_SIGNAL( movedToGroup( Kopete::MetaContact *, Kopete::Group *, Kopete::Group * ) ), TQ_SIGNAL( persistentDataChanged() ) );
+	connect( this, TQ_SIGNAL( removedFromGroup( Kopete::MetaContact *, Kopete::Group * ) ), TQ_SIGNAL( persistentDataChanged() ) );
+	connect( this, TQ_SIGNAL( addedToGroup( Kopete::MetaContact *, Kopete::Group * ) ), TQ_SIGNAL( persistentDataChanged() ) );
+	connect( this, TQ_SIGNAL( contactAdded( Kopete::Contact * ) ), TQ_SIGNAL( persistentDataChanged() ) );
+	connect( this, TQ_SIGNAL( contactRemoved( Kopete::Contact * ) ), TQ_SIGNAL( persistentDataChanged() ) );
 
 	// Update the KABC picture when the KDE Address book change.
-	connect(KABCPersistence::self()->addressBook(), TQT_SIGNAL(addressBookChanged(AddressBook *)), this, TQT_SLOT(slotUpdateAddressBookPicture()));
+	connect(KABCPersistence::self()->addressBook(), TQ_SIGNAL(addressBookChanged(AddressBook *)), this, TQ_SLOT(slotUpdateAddressBookPicture()));
 
 	// make sure MetaContact is at least in one group
 	addToGroup( Group::topLevel() );
@@ -135,17 +135,17 @@ void MetaContact::addContact( Contact *c )
 	{
 		d->contacts.append( c );
 
-		connect( c, TQT_SIGNAL( onlineStatusChanged( Kopete::Contact *, const Kopete::OnlineStatus &, const Kopete::OnlineStatus & ) ),
-			TQT_SLOT( slotContactStatusChanged( Kopete::Contact *, const Kopete::OnlineStatus &, const Kopete::OnlineStatus & ) ) );
+		connect( c, TQ_SIGNAL( onlineStatusChanged( Kopete::Contact *, const Kopete::OnlineStatus &, const Kopete::OnlineStatus & ) ),
+			TQ_SLOT( slotContactStatusChanged( Kopete::Contact *, const Kopete::OnlineStatus &, const Kopete::OnlineStatus & ) ) );
 
-		connect( c, TQT_SIGNAL( propertyChanged( Kopete::Contact *, const TQString &, const TQVariant &, const TQVariant & ) ),
-			this, TQT_SLOT( slotPropertyChanged( Kopete::Contact *, const TQString &, const TQVariant &, const TQVariant & ) ) ) ;
+		connect( c, TQ_SIGNAL( propertyChanged( Kopete::Contact *, const TQString &, const TQVariant &, const TQVariant & ) ),
+			this, TQ_SLOT( slotPropertyChanged( Kopete::Contact *, const TQString &, const TQVariant &, const TQVariant & ) ) ) ;
 
-		connect( c, TQT_SIGNAL( contactDestroyed( Kopete::Contact * ) ),
-			this, TQT_SLOT( slotContactDestroyed( Kopete::Contact * ) ) );
+		connect( c, TQ_SIGNAL( contactDestroyed( Kopete::Contact * ) ),
+			this, TQ_SLOT( slotContactDestroyed( Kopete::Contact * ) ) );
 
-		connect( c, TQT_SIGNAL( idleStateChanged( Kopete::Contact * ) ),
-			this, TQT_SIGNAL( contactIdleStateChanged( Kopete::Contact * ) ) );
+		connect( c, TQ_SIGNAL( idleStateChanged( Kopete::Contact * ) ),
+			this, TQ_SIGNAL( contactIdleStateChanged( Kopete::Contact * ) ) );
 
 		emit contactAdded(c);
 
@@ -258,14 +258,14 @@ void MetaContact::removeContact(Contact *c, bool deleted)
 
 		if(!deleted)
 		{  //If this function is tell by slotContactRemoved, c is maybe just a TQObject
-			disconnect( c, TQT_SIGNAL( onlineStatusChanged( Kopete::Contact *, const Kopete::OnlineStatus &, const Kopete::OnlineStatus & ) ),
-				this, TQT_SLOT( slotContactStatusChanged( Kopete::Contact *, const Kopete::OnlineStatus &, const Kopete::OnlineStatus & ) ) );
-			disconnect( c, TQT_SIGNAL( propertyChanged( Kopete::Contact *, const TQString &, const TQVariant &, const TQVariant & ) ),
-				this, TQT_SLOT( slotPropertyChanged( Kopete::Contact *, const TQString &, const TQVariant &, const TQVariant & ) ) ) ;
-			disconnect( c, TQT_SIGNAL( contactDestroyed( Kopete::Contact * ) ),
-				this, TQT_SLOT( slotContactDestroyed( Kopete::Contact * ) ) );
-			disconnect( c, TQT_SIGNAL( idleStateChanged( Kopete::Contact * ) ),
-				this, TQT_SIGNAL( contactIdleStateChanged( Kopete::Contact *) ) );
+			disconnect( c, TQ_SIGNAL( onlineStatusChanged( Kopete::Contact *, const Kopete::OnlineStatus &, const Kopete::OnlineStatus & ) ),
+				this, TQ_SLOT( slotContactStatusChanged( Kopete::Contact *, const Kopete::OnlineStatus &, const Kopete::OnlineStatus & ) ) );
+			disconnect( c, TQ_SIGNAL( propertyChanged( Kopete::Contact *, const TQString &, const TQVariant &, const TQVariant & ) ),
+				this, TQ_SLOT( slotPropertyChanged( Kopete::Contact *, const TQString &, const TQVariant &, const TQVariant & ) ) ) ;
+			disconnect( c, TQ_SIGNAL( contactDestroyed( Kopete::Contact * ) ),
+				this, TQ_SLOT( slotContactDestroyed( Kopete::Contact * ) ) );
+			disconnect( c, TQ_SIGNAL( idleStateChanged( Kopete::Contact * ) ),
+				this, TQ_SIGNAL( contactIdleStateChanged( Kopete::Contact *) ) );
 
 			kdDebug( 14010 ) << k_funcinfo << "Contact disconnected" << endl;
 
@@ -1215,16 +1215,16 @@ bool MetaContact::fromXML( const TQDomElement& element )
 	}
 	
 	// If a plugin is loaded, load data cached
-	connect( Kopete::PluginManager::self(), TQT_SIGNAL( pluginLoaded(Kopete::Plugin*) ),
-		this, TQT_SLOT( slotPluginLoaded(Kopete::Plugin*) ) );
+	connect( Kopete::PluginManager::self(), TQ_SIGNAL( pluginLoaded(Kopete::Plugin*) ),
+		this, TQ_SLOT( slotPluginLoaded(Kopete::Plugin*) ) );
 
 	// All plugins are already loaded, call manually the contact setting slot.
 	if( Kopete::PluginManager::self()->isAllPluginsLoaded() )
 		slotAllPluginsLoaded();
 	else
 		// When all plugins are loaded, set the source contact.
-		connect( Kopete::PluginManager::self(), TQT_SIGNAL( allPluginsLoaded() ), 
-			this, TQT_SLOT( slotAllPluginsLoaded() ) );
+		connect( Kopete::PluginManager::self(), TQ_SIGNAL( allPluginsLoaded() ), 
+			this, TQ_SLOT( slotAllPluginsLoaded() ) );
 
 	// track changes only works if ONE Contact is inside the MetaContact
 //	if (d->contacts.count() > 1) // Does NOT work as intended
