@@ -18,7 +18,7 @@
 #define KOPETETASK_H
 
 #include <tqobject.h>
-#include <kdemacros.h>
+#include <tdemacros.h>
 
 namespace Kopete
 {
