@@ -28,8 +28,8 @@ KopeteContactAction::KopeteContactAction( Kopete::Contact *contact, const TQObje
 {
 	m_contact = contact;
 
-	connect( this, TQT_SIGNAL( activated() ), TQT_SLOT( slotContactActionActivated() ) );
-	connect( this, TQT_SIGNAL( activated( Kopete::Contact * ) ), receiver, slot );
+	connect( this, TQ_SIGNAL( activated() ), TQ_SLOT( slotContactActionActivated() ) );
+	connect( this, TQ_SIGNAL( activated( Kopete::Contact * ) ), receiver, slot );
 }
 
 KopeteContactAction::~KopeteContactAction()
