@@ -103,7 +103,7 @@ namespace KSettings
 
 class KOPETE_EXPORT KopetePreferencesAction : public TDEAction
 {
-	  Q_OBJECT
+	  TQ_OBJECT
   
 
 	  public:
