@@ -49,7 +49,7 @@ HistoryLogger::HistoryLogger( Kopete::MetaContact *m,  TQObject *parent, const c
 	m_oldSens=Default;
 
 	//the contact may be destroyed, for example, if the contact changes its metacontact
-	connect(m_metaContact , TQT_SIGNAL(destroyed(TQObject *)) , this , TQT_SLOT(slotMCDeleted()));
+	connect(m_metaContact , TQ_SIGNAL(destroyed(TQObject *)) , this , TQ_SLOT(slotMCDeleted()));
 
 	setPositionToLast();
 }
@@ -67,7 +67,7 @@ HistoryLogger::HistoryLogger( Kopete::Contact *c,  TQObject *parent, const char
 	m_oldSens=Default;
 
 	//the contact may be destroyed, for example, if the contact changes its metacontact
-	connect(m_metaContact , TQT_SIGNAL(destroyed(TQObject *)) , this , TQT_SLOT(slotMCDeleted()));
+	connect(m_metaContact , TQ_SIGNAL(destroyed(TQObject *)) , this , TQ_SLOT(slotMCDeleted()));
 
 	setPositionToLast();
 }
@@ -292,7 +292,7 @@ void HistoryLogger::appendMessage( const Kopete::Message &msg , const Kopete::Co
 	if(!m_saveTimer)
 	{
 		m_saveTimer=new TQTimer(this);
-		connect( m_saveTimer, TQT_SIGNAL( timeout() ) , this, TQT_SLOT(saveToDisk()) );
+		connect( m_saveTimer, TQ_SIGNAL( timeout() ) , this, TQ_SLOT(saveToDisk()) );
 	}
 	if(!m_saveTimer->isActive())
 		m_saveTimer->start( m_saveTimerTime, true /*singleshot*/ );
@@ -377,7 +377,7 @@ TQValueList<Kopete::Message> HistoryLogger::readMessages(TQDate date)
 
 					Kopete::Message msg(dt, from, to, msgElem2.text(), dir);
 					msg.setBody( TQString::fromLatin1("<span title=\"%1\">%2</span>")
-							.arg( dt.toString(Qt::LocalDate), msg.escapedBody() ),
+							.arg( dt.toString(TQt::LocalDate), msg.escapedBody() ),
 							Kopete::Message::RichText);
 				
 
@@ -595,7 +595,7 @@ TQValueList<Kopete::Message> HistoryLogger::readMessages(unsigned int lines,
 					if (colorize)
 					{
 						msg.setBody( TQString::fromLatin1("<span style=\"color:%1\" title=\"%2\">%3</span>")
-							.arg( fgColor.name(), timestamp.toString(Qt::LocalDate), msg.escapedBody() ),
+							.arg( fgColor.name(), timestamp.toString(TQt::LocalDate), msg.escapedBody() ),
 							Kopete::Message::RichText
 						);
 						msg.setFg( fgColor );
@@ -603,7 +603,7 @@ TQValueList<Kopete::Message> HistoryLogger::readMessages(unsigned int lines,
 					else
 					{
 						msg.setBody( TQString::fromLatin1("<span title=\"%1\">%2</span>")
-							.arg( timestamp.toString(Qt::LocalDate), msg.escapedBody() ),
+							.arg( timestamp.toString(TQt::LocalDate), msg.escapedBody() ),
 							Kopete::Message::RichText
 						);
 					}
