@@ -38,7 +38,7 @@ NetMeetingGUIClient::NetMeetingGUIClient( MSNChatSession *parent,  const char *n
 	setInstance(KGenericFactory<NetMeetingPlugin>::instance());
 	m_manager=parent;
 
-	new TDEAction( i18n( "Invite to Use NetMeeting" ), 0, this, TQT_SLOT( slotStartInvitation() ), actionCollection() , "netmeeting" ) ;
+	new TDEAction( i18n( "Invite to Use NetMeeting" ), 0, this, TQ_SLOT( slotStartInvitation() ), actionCollection() , "netmeeting" ) ;
 
 	setXMLFile("netmeetingchatui.rc");
 }
