@@ -33,7 +33,7 @@ class NetMeetingPlugin;
 
 class NetMeetingGUIClient : public TQObject , public KXMLGUIClient
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
