@@ -74,17 +74,17 @@ GroupWiseAccount::GroupWiseAccount( GroupWiseProtocol *parent, const TQString& a
 	myself()->setOnlineStatus( GroupWiseProtocol::protocol()->groupwiseOffline );
 
 	// Contact list management
-	TQObject::connect( Kopete::ContactList::self(), TQT_SIGNAL( groupRenamed( Kopete::Group *, const TQString & ) ),
-			TQT_SLOT( slotKopeteGroupRenamed( Kopete::Group * ) ) );
-	TQObject::connect( Kopete::ContactList::self(), TQT_SIGNAL( groupRemoved( Kopete::Group * ) ),
-			TQT_SLOT( slotKopeteGroupRemoved( Kopete::Group * ) ) );
+	TQObject::connect( Kopete::ContactList::self(), TQ_SIGNAL( groupRenamed( Kopete::Group *, const TQString & ) ),
+			TQ_SLOT( slotKopeteGroupRenamed( Kopete::Group * ) ) );
+	TQObject::connect( Kopete::ContactList::self(), TQ_SIGNAL( groupRemoved( Kopete::Group * ) ),
+			TQ_SLOT( slotKopeteGroupRemoved( Kopete::Group * ) ) );
 
 	m_actionAutoReply = new TDEAction ( i18n( "&Set Auto-Reply..." ), TQString(), 0, this,
-			TQT_SLOT( slotSetAutoReply() ), this, "actionSetAutoReply");
+			TQ_SLOT( slotSetAutoReply() ), this, "actionSetAutoReply");
 	m_actionJoinChatRoom = new TDEAction ( i18n( "&Join Channel..." ), TQString(), 0, this,
-										 TQT_SLOT( slotJoinChatRoom() ), this, "actionJoinChatRoom");
+										 TQ_SLOT( slotJoinChatRoom() ), this, "actionJoinChatRoom");
 	m_actionManagePrivacy = new TDEAction ( i18n( "&Manage Privacy..." ), TQString(), 0, this,
-			TQT_SLOT( slotPrivacy() ), this, "actionPrivacy");
+			TQ_SLOT( slotPrivacy() ), this, "actionPrivacy");
 			
 	m_connector = 0;
 	m_TQCATLS = 0;
@@ -113,7 +113,7 @@ TDEActionMenu* GroupWiseAccount::actionMenu()
 	/* Used for debugging */
 	/*
 	theActionMenu->insert( new TDEAction ( "Test rtfize()", TQString(), 0, this,
-		TQT_SLOT( slotTestRTFize() ), this,
+		TQ_SLOT( slotTestRTFize() ), this,
 		"actionTestRTFize") );
 	*/
 	return m_actionMenu;
@@ -178,8 +178,8 @@ GroupWiseChatSession * GroupWiseAccount::chatSession( Kopete::ContactPtrList oth
 			m_chatSessions.append( chatSession );
 			// listen for the message manager telling us that the user
 			//has left the conference so we remove it from our map
-			TQObject::connect( chatSession, TQT_SIGNAL( leavingConference( GroupWiseChatSession * ) ),
-							TQT_SLOT( slotLeavingConference( GroupWiseChatSession * ) ) );
+			TQObject::connect( chatSession, TQ_SIGNAL( leavingConference( GroupWiseChatSession * ) ),
+							TQ_SLOT( slotLeavingConference( GroupWiseChatSession * ) ) );
 			break;
 		}
 		//kdDebug( GROUPWISE_DEBUG_GLOBAL ) << k_funcinfo <<
@@ -268,80 +268,80 @@ void GroupWiseAccount::performConnectWithPassword( const TQString &password )
 	m_tlsHandler = new TQCATLSHandler( m_TQCATLS );
 	m_clientStream = new ClientStream( m_connector, m_tlsHandler, 0);
 
-	TQObject::connect( m_connector, TQT_SIGNAL( error() ), this, TQT_SLOT( slotConnError() ) );
-	TQObject::connect( m_connector, TQT_SIGNAL( connected() ), this, TQT_SLOT( slotConnConnected() ) );
+	TQObject::connect( m_connector, TQ_SIGNAL( error() ), this, TQ_SLOT( slotConnError() ) );
+	TQObject::connect( m_connector, TQ_SIGNAL( connected() ), this, TQ_SLOT( slotConnConnected() ) );
 
-	TQObject::connect (m_clientStream, TQT_SIGNAL (connectionClosed()),
-				this, TQT_SLOT (slotCSDisconnected()));
-	TQObject::connect (m_clientStream, TQT_SIGNAL (delayedCloseFinished()),
-				this, TQT_SLOT (slotCSDisconnected()));
+	TQObject::connect (m_clientStream, TQ_SIGNAL (connectionClosed()),
+				this, TQ_SLOT (slotCSDisconnected()));
+	TQObject::connect (m_clientStream, TQ_SIGNAL (delayedCloseFinished()),
+				this, TQ_SLOT (slotCSDisconnected()));
 	// Notify us when the transport layer is connected
-	TQObject::connect( m_clientStream, TQT_SIGNAL( connected() ), TQT_SLOT( slotCSConnected() ) );
+	TQObject::connect( m_clientStream, TQ_SIGNAL( connected() ), TQ_SLOT( slotCSConnected() ) );
 	// it's necessary to catch this signal and tell the TLS handler to proceed
 	// even if we don't check cert validity
-	TQObject::connect( m_tlsHandler, TQT_SIGNAL(tlsHandshaken()), TQT_SLOT( slotTLSHandshaken()) );
+	TQObject::connect( m_tlsHandler, TQ_SIGNAL(tlsHandshaken()), TQ_SLOT( slotTLSHandshaken()) );
 	// starts the client once the security layer is up, but see below
-	TQObject::connect( m_clientStream, TQT_SIGNAL( securityLayerActivated(int) ), TQT_SLOT( slotTLSReady(int) ) );
+	TQObject::connect( m_clientStream, TQ_SIGNAL( securityLayerActivated(int) ), TQ_SLOT( slotTLSReady(int) ) );
 	// we could handle login etc in start(), in which case we would emit this signal after that
-	//TQObject::connect (jabberClientStream, TQT_SIGNAL (authenticated()),
-	//			this, TQT_SLOT (slotCSAuthenticated ()));
+	//TQObject::connect (jabberClientStream, TQ_SIGNAL (authenticated()),
+	//			this, TQ_SLOT (slotCSAuthenticated ()));
 	// we could also get do the actual login in response to this..
-	//TQObject::connect (m_clientStream, TQT_SIGNAL (needAuthParams(bool, bool, bool)),
-	//			this, TQT_SLOT (slotCSNeedAuthParams (bool, bool, bool)));
+	//TQObject::connect (m_clientStream, TQ_SIGNAL (needAuthParams(bool, bool, bool)),
+	//			this, TQ_SLOT (slotCSNeedAuthParams (bool, bool, bool)));
 
 	// not implemented: warning
-	TQObject::connect( m_clientStream, TQT_SIGNAL( warning(int) ), TQT_SLOT( slotCSWarning(int) ) );
+	TQObject::connect( m_clientStream, TQ_SIGNAL( warning(int) ), TQ_SLOT( slotCSWarning(int) ) );
 	// not implemented: error
-	TQObject::connect( m_clientStream, TQT_SIGNAL( error(int) ), TQT_SLOT( slotCSError(int) ) );
+	TQObject::connect( m_clientStream, TQ_SIGNAL( error(int) ), TQ_SLOT( slotCSError(int) ) );
 
 	m_client = new Client( 0, CMSGPRES_GW_6_5 );
 
 	// NB these are prefixed with TQObject:: to avoid any chance of a clash with our connect() methods.
 	// we connected successfully
-	TQObject::connect( m_client, TQT_SIGNAL( loggedIn() ), TQT_SLOT( slotLoggedIn() ) );
+	TQObject::connect( m_client, TQ_SIGNAL( loggedIn() ), TQ_SLOT( slotLoggedIn() ) );
 	// or connection failed
-	TQObject::connect( m_client, TQT_SIGNAL( loginFailed() ), TQT_SLOT( slotLoginFailed() ) );
+	TQObject::connect( m_client, TQ_SIGNAL( loginFailed() ), TQ_SLOT( slotLoginFailed() ) );
 	// folder listed
-	TQObject::connect( m_client, TQT_SIGNAL( folderReceived( const FolderItem & ) ), TQT_SLOT( receiveFolder( const FolderItem & ) ) );
+	TQObject::connect( m_client, TQ_SIGNAL( folderReceived( const FolderItem & ) ), TQ_SLOT( receiveFolder( const FolderItem & ) ) );
 	// contact listed
-	TQObject::connect( m_client, TQT_SIGNAL( contactReceived( const ContactItem & ) ), TQT_SLOT( receiveContact( const ContactItem & ) ) );
+	TQObject::connect( m_client, TQ_SIGNAL( contactReceived( const ContactItem & ) ), TQ_SLOT( receiveContact( const ContactItem & ) ) );
 	// contact details listed
-	TQObject::connect( m_client, TQT_SIGNAL( contactUserDetailsReceived( const GroupWise::ContactDetails & ) ), TQT_SLOT( receiveContactUserDetails( const GroupWise::ContactDetails & ) ) );
+	TQObject::connect( m_client, TQ_SIGNAL( contactUserDetailsReceived( const GroupWise::ContactDetails & ) ), TQ_SLOT( receiveContactUserDetails( const GroupWise::ContactDetails & ) ) );
 	// contact status changed
-	TQObject::connect( m_client, TQT_SIGNAL( statusReceived( const TQString &, TQ_UINT16, const TQString & ) ), TQT_SLOT( receiveStatus( const TQString &, TQ_UINT16 , const TQString & ) ) );
+	TQObject::connect( m_client, TQ_SIGNAL( statusReceived( const TQString &, TQ_UINT16, const TQString & ) ), TQ_SLOT( receiveStatus( const TQString &, TQ_UINT16 , const TQString & ) ) );
 	// incoming message
-	TQObject::connect( m_client, TQT_SIGNAL( messageReceived( const ConferenceEvent & ) ), TQT_SLOT( handleIncomingMessage( const ConferenceEvent & ) ) );
+	TQObject::connect( m_client, TQ_SIGNAL( messageReceived( const ConferenceEvent & ) ), TQ_SLOT( handleIncomingMessage( const ConferenceEvent & ) ) );
 	// auto reply to one of our messages because the recipient is away
-	TQObject::connect( m_client, TQT_SIGNAL( autoReplyReceived( const ConferenceEvent & ) ), TQT_SLOT( handleIncomingMessage( const ConferenceEvent & ) ) );
+	TQObject::connect( m_client, TQ_SIGNAL( autoReplyReceived( const ConferenceEvent & ) ), TQ_SLOT( handleIncomingMessage( const ConferenceEvent & ) ) );
 
-	TQObject::connect( m_client, TQT_SIGNAL( ourStatusChanged( GroupWise::Status, const TQString &, const TQString & ) ), TQT_SLOT( changeOurStatus( GroupWise::Status, const TQString &, const TQString & ) ) );
+	TQObject::connect( m_client, TQ_SIGNAL( ourStatusChanged( GroupWise::Status, const TQString &, const TQString & ) ), TQ_SLOT( changeOurStatus( GroupWise::Status, const TQString &, const TQString & ) ) );
 	// conference events
 	TQObject::connect( m_client,
-		TQT_SIGNAL( conferenceCreated( const int, const GroupWise::ConferenceGuid & ) ),
-		TQT_SIGNAL( conferenceCreated( const int, const GroupWise::ConferenceGuid & ) ) );
-	TQObject::connect( m_client, TQT_SIGNAL( conferenceCreationFailed( const int,  const int ) ), TQT_SIGNAL( conferenceCreationFailed( const int,  const int ) ) );
-	TQObject::connect( m_client, TQT_SIGNAL( invitationReceived( const ConferenceEvent & ) ), TQT_SLOT( receiveInvitation( const ConferenceEvent & ) ) );
-	TQObject::connect( m_client, TQT_SIGNAL( conferenceLeft( const ConferenceEvent & ) ), TQT_SLOT( receiveConferenceLeft( const ConferenceEvent & ) ) );
-	TQObject::connect( m_client, TQT_SIGNAL( conferenceJoinNotifyReceived( const ConferenceEvent & ) ), TQT_SLOT( receiveConferenceJoinNotify( const ConferenceEvent & ) ) );
-	TQObject::connect( m_client, TQT_SIGNAL( inviteNotifyReceived( const ConferenceEvent & ) ), TQT_SLOT( receiveInviteNotify( const ConferenceEvent & ) ) );
-	TQObject::connect( m_client, TQT_SIGNAL( invitationDeclined( const ConferenceEvent & ) ), TQT_SLOT( receiveInviteDeclined( const ConferenceEvent & ) ) );
+		TQ_SIGNAL( conferenceCreated( const int, const GroupWise::ConferenceGuid & ) ),
+		TQ_SIGNAL( conferenceCreated( const int, const GroupWise::ConferenceGuid & ) ) );
+	TQObject::connect( m_client, TQ_SIGNAL( conferenceCreationFailed( const int,  const int ) ), TQ_SIGNAL( conferenceCreationFailed( const int,  const int ) ) );
+	TQObject::connect( m_client, TQ_SIGNAL( invitationReceived( const ConferenceEvent & ) ), TQ_SLOT( receiveInvitation( const ConferenceEvent & ) ) );
+	TQObject::connect( m_client, TQ_SIGNAL( conferenceLeft( const ConferenceEvent & ) ), TQ_SLOT( receiveConferenceLeft( const ConferenceEvent & ) ) );
+	TQObject::connect( m_client, TQ_SIGNAL( conferenceJoinNotifyReceived( const ConferenceEvent & ) ), TQ_SLOT( receiveConferenceJoinNotify( const ConferenceEvent & ) ) );
+	TQObject::connect( m_client, TQ_SIGNAL( inviteNotifyReceived( const ConferenceEvent & ) ), TQ_SLOT( receiveInviteNotify( const ConferenceEvent & ) ) );
+	TQObject::connect( m_client, TQ_SIGNAL( invitationDeclined( const ConferenceEvent & ) ), TQ_SLOT( receiveInviteDeclined( const ConferenceEvent & ) ) );
 
-	TQObject::connect( m_client, TQT_SIGNAL( conferenceJoined( const GroupWise::ConferenceGuid &, const TQStringList &, const TQStringList &  ) ), TQT_SLOT( receiveConferenceJoin( const GroupWise::ConferenceGuid &, const TQStringList & , const TQStringList & ) ) );
+	TQObject::connect( m_client, TQ_SIGNAL( conferenceJoined( const GroupWise::ConferenceGuid &, const TQStringList &, const TQStringList &  ) ), TQ_SLOT( receiveConferenceJoin( const GroupWise::ConferenceGuid &, const TQStringList & , const TQStringList & ) ) );
 
 	// typing events
-	TQObject::connect( m_client, TQT_SIGNAL( contactTyping( const ConferenceEvent & ) ),
-								TQT_SIGNAL( contactTyping( const ConferenceEvent & ) ) );
-	TQObject::connect( m_client, TQT_SIGNAL( contactNotTyping( const ConferenceEvent & ) ),
-								TQT_SIGNAL( contactNotTyping( const ConferenceEvent & ) ) );
+	TQObject::connect( m_client, TQ_SIGNAL( contactTyping( const ConferenceEvent & ) ),
+								TQ_SIGNAL( contactTyping( const ConferenceEvent & ) ) );
+	TQObject::connect( m_client, TQ_SIGNAL( contactNotTyping( const ConferenceEvent & ) ),
+								TQ_SIGNAL( contactNotTyping( const ConferenceEvent & ) ) );
 	// misc
-	TQObject::connect( m_client, TQT_SIGNAL( accountDetailsReceived( const GroupWise::ContactDetails &) ), TQT_SLOT( receiveAccountDetails( const GroupWise::ContactDetails & ) ) );
-	TQObject::connect( m_client, TQT_SIGNAL( connectedElsewhere() ), TQT_SLOT( slotConnectedElsewhere() ) );
+	TQObject::connect( m_client, TQ_SIGNAL( accountDetailsReceived( const GroupWise::ContactDetails &) ), TQ_SLOT( receiveAccountDetails( const GroupWise::ContactDetails & ) ) );
+	TQObject::connect( m_client, TQ_SIGNAL( connectedElsewhere() ), TQ_SLOT( slotConnectedElsewhere() ) );
 	// privacy - contacts can't connect directly to this signal because myself() is initialised before m_client
-	TQObject::connect( m_client->privacyManager(), TQT_SIGNAL( privacyChanged( const TQString &, bool ) ), TQT_SIGNAL( privacyChanged( const TQString &, bool ) ) );
+	TQObject::connect( m_client->privacyManager(), TQ_SIGNAL( privacyChanged( const TQString &, bool ) ), TQ_SIGNAL( privacyChanged( const TQString &, bool ) ) );
 
 	// GW7
-	TQObject::connect( m_client, TQT_SIGNAL( broadcastReceived( const ConferenceEvent & ) ), TQT_SLOT( handleIncomingMessage( const ConferenceEvent & ) ) );
-	TQObject::connect( m_client, TQT_SIGNAL( systemBroadcastReceived( const ConferenceEvent & ) ), TQT_SLOT( handleIncomingMessage( const ConferenceEvent & ) ) );
+	TQObject::connect( m_client, TQ_SIGNAL( broadcastReceived( const ConferenceEvent & ) ), TQ_SLOT( handleIncomingMessage( const ConferenceEvent & ) ) );
+	TQObject::connect( m_client, TQ_SIGNAL( systemBroadcastReceived( const ConferenceEvent & ) ), TQ_SLOT( handleIncomingMessage( const ConferenceEvent & ) ) );
 
 	struct utsname utsBuf;
 	uname (&utsBuf);
@@ -358,7 +358,7 @@ void GroupWiseAccount::performConnectWithPassword( const TQString &password )
 	myself()->setOnlineStatus( protocol()->groupwiseConnecting );
 	m_client->connectToServer( m_clientStream, dn, true );
 
-    TQObject::connect( m_client, TQT_SIGNAL( messageSendingFailed() ), TQT_SLOT( slotMessageSendingFailed() ) );
+    TQObject::connect( m_client, TQ_SIGNAL( messageSendingFailed() ), TQ_SLOT( slotMessageSendingFailed() ) );
 }
 
 void GroupWiseAccount::slotMessageSendingFailed()
@@ -533,7 +533,7 @@ void GroupWiseAccount::reconcileOfflineChanges()
 					else
 						continue;
 
-				GWFolder * folder = ::tqqt_cast<GWFolder*>( ( *instIt )->parent() );
+				GWFolder * folder = ::tqt_cast<GWFolder*>( ( *instIt )->parent() );
 				if ( folder->id == ( unsigned int )groupId.toInt() )
 				{
 					found = true;
@@ -940,7 +940,7 @@ void GroupWiseAccount::receiveContact( const ContactItem & contact )
 			kdDebug( GROUPWISE_DEBUG_GLOBAL ) << " - ERROR - contact's folder doesn't exist on server" << endl;
 			DeleteItemTask * dit = new DeleteItemTask( client()->rootTask() );
 			dit->item( contact.parentId, contact.id );
-//			TQObject::connect( dit, TQT_SIGNAL( gotContactDeleted( const ContactItem & ) ), TQT_SLOT( receiveContactDeleted( const ContactItem & ) ) );
+//			TQObject::connect( dit, TQ_SIGNAL( gotContactDeleted( const ContactItem & ) ), TQ_SLOT( receiveContactDeleted( const ContactItem & ) ) );
 			dit->go( true );
 			return;
 		}
@@ -1117,7 +1117,7 @@ bool GroupWiseAccount::createContact( const TQString& contactId, Kopete::MetaCon
 		{
 			kdDebug( GROUPWISE_DEBUG_GLOBAL ) << fld->displayName << endl;
 			//FIXME - get rid of FolderItem & co
-			fi.parentId = ::tqqt_cast<GWFolder*>( fld->parent() )->id;
+			fi.parentId = ::tqt_cast<GWFolder*>( fld->parent() )->id;
 			fi.id = fld->id;
 			fi.name = fld->displayName;
 		}
@@ -1165,7 +1165,7 @@ bool GroupWiseAccount::createContact( const TQString& contactId, Kopete::MetaCon
 	// get the contact's full name to use as the display name of the created contact
 	CreateContactTask * cct = new CreateContactTask( client()->rootTask() );
 	cct->contactFromUserId( contactId, parentContact->displayName(), highestFreeSequence, folders, topLevel );
-	TQObject::connect( cct, TQT_SIGNAL( finished() ), TQT_SLOT( receiveContactCreated() ) );
+	TQObject::connect( cct, TQ_SIGNAL( finished() ), TQ_SLOT( receiveContactCreated() ) );
 	cct->go( true );
 	return true;
 }
@@ -1227,8 +1227,8 @@ void GroupWiseAccount::deleteContact( GroupWiseContact * contact )
 		for ( ; it != instances.end(); ++it )
 		{
 			DeleteItemTask * dit = new DeleteItemTask( client()->rootTask() );
-			dit->item( ::tqqt_cast<GWFolder*>( (*it)->parent() )->id, (*it)->id );
-			TQObject::connect( dit, TQT_SIGNAL( gotContactDeleted( const ContactItem & ) ), TQT_SLOT( receiveContactDeleted( const ContactItem & ) ) );
+			dit->item( ::tqt_cast<GWFolder*>( (*it)->parent() )->id, (*it)->id );
+			TQObject::connect( dit, TQ_SIGNAL( gotContactDeleted( const ContactItem & ) ), TQ_SLOT( receiveContactDeleted( const ContactItem & ) ) );
 			dit->go( true );
 		}
 	}
@@ -1499,7 +1499,7 @@ void GroupWiseAccount::syncContact( GroupWiseContact * contact )
 			{
 				GWContactInstanceList::Iterator candidateInst = instIt;
 				++instIt;
-				GWFolder * folder = ::tqqt_cast<GWFolder *>( ( *candidateInst )->parent() );
+				GWFolder * folder = ::tqt_cast<GWFolder *>( ( *candidateInst )->parent() );
 				kdDebug( GROUPWISE_DEBUG_GLOBAL ) << "  - Looking for a match, MC grp '" 
 					<< ( *candidateGrp )->displayName() 
 					<< "', GWFolder '" << folder->displayName << "', objectId is " << folder->id << endl;
@@ -1525,7 +1525,7 @@ void GroupWiseAccount::syncContact( GroupWiseContact * contact )
 			candidateGrp = grpIt;
 			++grpIt;
 			GWContactInstanceList::Iterator instIt = instances.begin();
-			GWFolder * sourceFolder =::tqqt_cast<GWFolder*>( ( *instIt)->parent() );
+			GWFolder * sourceFolder =::tqt_cast<GWFolder*>( ( *instIt)->parent() );
 			kdDebug( GROUPWISE_DEBUG_GLOBAL ) << "  - moving contact instance from group '" << sourceFolder->displayName << "' to group '" << ( *candidateGrp )->displayName() << "'" << endl;
 
 			// create contactItem parameter
@@ -1541,21 +1541,21 @@ void GroupWiseAccount::syncContact( GroupWiseContact * contact )
 			{
 				MoveContactTask * mit = new MoveContactTask( client()->rootTask() );
 				mit->moveContact( instance, destinationFolder->id );
-				TQObject::connect( mit, TQT_SIGNAL( gotContactDeleted( const ContactItem & ) ), TQT_SLOT( receiveContactDeleted( const ContactItem & ) ) );
+				TQObject::connect( mit, TQ_SIGNAL( gotContactDeleted( const ContactItem & ) ), TQ_SLOT( receiveContactDeleted( const ContactItem & ) ) );
 				mit->go();
 			}
 			else if ( *candidateGrp == Kopete::Group::topLevel() )
 			{	
 				MoveContactTask * mit = new MoveContactTask( client()->rootTask() );
 				mit->moveContact( instance, 0 );
-				TQObject::connect( mit, TQT_SIGNAL( gotContactDeleted( const ContactItem & ) ), TQT_SLOT( receiveContactDeleted( const ContactItem & ) ) );
+				TQObject::connect( mit, TQ_SIGNAL( gotContactDeleted( const ContactItem & ) ), TQ_SLOT( receiveContactDeleted( const ContactItem & ) ) );
 				mit->go();
 			}
 			else
 			{
 				MoveContactTask * mit = new MoveContactTask( client()->rootTask() );
-				TQObject::connect( mit, TQT_SIGNAL( gotContactDeleted( const ContactItem & ) ), 
-								  TQT_SLOT( receiveContactDeleted( const ContactItem & ) ) );
+				TQObject::connect( mit, TQ_SIGNAL( gotContactDeleted( const ContactItem & ) ), 
+								  TQ_SLOT( receiveContactDeleted( const ContactItem & ) ) );
 				// discover the next free sequence number and add the group using that
 				mit->moveContactToNewFolder( instance, nextFreeSequence++,
 											 ( *candidateGrp )->displayName() );
@@ -1604,12 +1604,12 @@ void GroupWiseAccount::syncContact( GroupWiseContact * contact )
 		{
 			GWContactInstanceList::Iterator candidateInst = instIt;
 			++instIt;
-			GWFolder * folder =::tqqt_cast<GWFolder*>( ( *candidateInst )->parent() );
+			GWFolder * folder =::tqt_cast<GWFolder*>( ( *candidateInst )->parent() );
 			kdDebug( GROUPWISE_DEBUG_GLOBAL ) << "  - remove contact instance '"<< ( *candidateInst )->id << "' in group '" << folder->displayName << "'" << endl;
 
 			DeleteItemTask * dit = new DeleteItemTask( client()->rootTask() );
 			dit->item( folder->id, (*candidateInst)->id );
-			TQObject::connect( dit, TQT_SIGNAL( gotContactDeleted( const ContactItem & ) ), TQT_SLOT( receiveContactDeleted( const ContactItem & ) ) );
+			TQObject::connect( dit, TQ_SIGNAL( gotContactDeleted( const ContactItem & ) ), TQ_SLOT( receiveContactDeleted( const ContactItem & ) ) );
 			dit->go( true );
 
 			instances.remove( candidateInst );
@@ -1628,7 +1628,7 @@ void GroupWiseAccount::syncContact( GroupWiseContact * contact )
 				TQValueList< ContactItem > instancesToChange;
 				ContactItem instance;
 				instance.id = (*it)->id;
-				instance.parentId = ::tqqt_cast<GWFolder *>( (*it)->parent() )->id;
+				instance.parentId = ::tqt_cast<GWFolder *>( (*it)->parent() )->id;
 				instance.sequence = (*it)->sequence;
 				instance.dn = contact->dn();
 				instance.displayName = contact->nickName();
@@ -1636,7 +1636,7 @@ void GroupWiseAccount::syncContact( GroupWiseContact * contact )
 
 				UpdateContactTask * uct = new UpdateContactTask( client()->rootTask() );
 				uct->renameContact( contact->metaContact()->displayName(), instancesToChange );
-				TQObject::connect ( uct, TQT_SIGNAL( finished() ), contact, TQT_SLOT( renamedOnServer() ) );
+				TQObject::connect ( uct, TQ_SIGNAL( finished() ), contact, TQ_SLOT( renamedOnServer() ) );
 				uct->go( true );
 			}
  		}
