@@ -30,7 +30,7 @@
 */
 class TypingTask : public RequestTask
 {
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
