@@ -31,7 +31,7 @@
 
 class ClientStreamTest : public TQApplication
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
 	ClientStreamTest(int argc, char ** argv);
