@@ -50,8 +50,8 @@
 //!  Session::Session()
 //!  {
 //!    client = new Client;
-//!    connect(client, TQT_SIGNAL(handshaken()), TQT_SLOT(clientHandshaken()));
-//!    connect(client, TQT_SIGNAL(authFinished(bool, int, const TQString &)), TQT_SLOT(authFinished(bool, int, const TQString &)));
+//!    connect(client, TQ_SIGNAL(handshaken()), TQ_SLOT(clientHandshaken()));
+//!    connect(client, TQ_SIGNAL(authFinished(bool, int, const TQString &)), TQ_SLOT(authFinished(bool, int, const TQString &)));
 //!    client->connectToHost("jabber.org");
 //!  }
 //!
@@ -162,10 +162,10 @@ Client::Client(TQObject *par)
 	d->stream = 0;
 
 	d->s5bman = new S5BManager(this);
-	connect(d->s5bman, TQT_SIGNAL(incomingReady()), TQT_SLOT(s5b_incomingReady()));
+	connect(d->s5bman, TQ_SIGNAL(incomingReady()), TQ_SLOT(s5b_incomingReady()));
 
 	d->ibbman = new IBBManager(this);
-	connect(d->ibbman, TQT_SIGNAL(incomingReady()), TQT_SLOT(ibb_incomingReady()));
+	connect(d->ibbman, TQ_SIGNAL(incomingReady()), TQ_SLOT(ibb_incomingReady()));
 
 	d->jlman = new JidLinkManager(this);
 
@@ -188,14 +188,14 @@ Client::~Client()
 void Client::connectToServer(ClientStream *s, const Jid &j, bool auth)
 {
 	d->stream = s;
-	//connect(d->stream, TQT_SIGNAL(connected()), TQT_SLOT(streamConnected()));
-	//connect(d->stream, TQT_SIGNAL(handshaken()), TQT_SLOT(streamHandshaken()));
-	connect(d->stream, TQT_SIGNAL(error(int)), TQT_SLOT(streamError(int)));
-	//connect(d->stream, TQT_SIGNAL(sslCertificateReady(const TQSSLCert &)), TQT_SLOT(streamSSLCertificateReady(const TQSSLCert &)));
-	connect(d->stream, TQT_SIGNAL(readyRead()), TQT_SLOT(streamReadyRead()));
-	//connect(d->stream, TQT_SIGNAL(closeFinished()), TQT_SLOT(streamCloseFinished()));
-	connect(d->stream, TQT_SIGNAL(incomingXml(const TQString &)), TQT_SLOT(streamIncomingXml(const TQString &)));
-	connect(d->stream, TQT_SIGNAL(outgoingXml(const TQString &)), TQT_SLOT(streamOutgoingXml(const TQString &)));
+	//connect(d->stream, TQ_SIGNAL(connected()), TQ_SLOT(streamConnected()));
+	//connect(d->stream, TQ_SIGNAL(handshaken()), TQ_SLOT(streamHandshaken()));
+	connect(d->stream, TQ_SIGNAL(error(int)), TQ_SLOT(streamError(int)));
+	//connect(d->stream, TQ_SIGNAL(sslCertificateReady(const TQSSLCert &)), TQ_SLOT(streamSSLCertificateReady(const TQSSLCert &)));
+	connect(d->stream, TQ_SIGNAL(readyRead()), TQ_SLOT(streamReadyRead()));
+	//connect(d->stream, TQ_SIGNAL(closeFinished()), TQ_SLOT(streamCloseFinished()));
+	connect(d->stream, TQ_SIGNAL(incomingXml(const TQString &)), TQ_SLOT(streamIncomingXml(const TQString &)));
+	connect(d->stream, TQ_SIGNAL(outgoingXml(const TQString &)), TQ_SLOT(streamOutgoingXml(const TQString &)));
 
 	d->stream->connectToServer(j, auth);
 }
@@ -213,14 +213,14 @@ void Client::start(const TQString &host, const TQString &user, const TQString &p
 	d->resourceList += Resource(resource(), stat);
 
 	JT_PushPresence *pp = new JT_PushPresence(rootTask());
-	connect(pp, TQT_SIGNAL(subscription(const Jid &, const TQString &)), TQT_SLOT(ppSubscription(const Jid &, const TQString &)));
-	connect(pp, TQT_SIGNAL(presence(const Jid &, const Status &)), TQT_SLOT(ppPresence(const Jid &, const Status &)));
+	connect(pp, TQ_SIGNAL(subscription(const Jid &, const TQString &)), TQ_SLOT(ppSubscription(const Jid &, const TQString &)));
+	connect(pp, TQ_SIGNAL(presence(const Jid &, const Status &)), TQ_SLOT(ppPresence(const Jid &, const Status &)));
 
 	JT_PushMessage *pm = new JT_PushMessage(rootTask());
-	connect(pm, TQT_SIGNAL(message(const Message &)), TQT_SLOT(pmMessage(const Message &)));
+	connect(pm, TQ_SIGNAL(message(const Message &)), TQ_SLOT(pmMessage(const Message &)));
 
 	JT_PushRoster *pr = new JT_PushRoster(rootTask());
-	connect(pr, TQT_SIGNAL(roster(const Roster &)), TQT_SLOT(prRoster(const Roster &)));
+	connect(pr, TQ_SIGNAL(roster(const Roster &)), TQ_SLOT(prRoster(const Roster &)));
 
 	new JT_ServInfo(rootTask());
 	new PongServer(rootTask());
@@ -884,7 +884,7 @@ void Client::rosterRequest()
 		return;
 
 	JT_Roster *r = new JT_Roster(rootTask());
-	connect(r, TQT_SIGNAL(finished()), TQT_SLOT(slotRosterRequestFinished()));
+	connect(r, TQ_SIGNAL(finished()), TQ_SLOT(slotRosterRequestFinished()));
 	r->get();
 	d->roster.flagAllForDelete(); // mod_groups patch
 	r->go(true);
@@ -1163,7 +1163,7 @@ Task::Task(Task *parent)
 
 	d->client = parent->client();
 	d->id = client()->genUniqueId();
-	connect(d->client, TQT_SIGNAL(disconnected()), TQT_SLOT(clientDisconnected()));
+	connect(d->client, TQ_SIGNAL(disconnected()), TQ_SLOT(clientDisconnected()));
 }
 
 Task::Task(Client *parent, bool)
@@ -1172,7 +1172,7 @@ Task::Task(Client *parent, bool)
 	init();
 
 	d->client = parent;
-	connect(d->client, TQT_SIGNAL(disconnected()), TQT_SLOT(clientDisconnected()));
+	connect(d->client, TQ_SIGNAL(disconnected()), TQ_SLOT(clientDisconnected()));
 }
 
 Task::~Task()
@@ -1276,7 +1276,7 @@ void Task::onDisconnect()
 		d->statusString = tr("Disconnected");
 
 		// delay this so that tasks that react don't block the shutdown
-		TQTimer::singleShot(0, this, TQT_SLOT(done()));
+		TQTimer::singleShot(0, this, TQ_SLOT(done()));
 	}
 }
 
