@@ -46,12 +46,12 @@ JabberEditAccountWidget::JabberEditAccountWidget (JabberProtocol * proto, Jabber
 
 	m_protocol = proto;
 
-	connect (mID, TQT_SIGNAL (textChanged (const TQString &)), this, TQT_SLOT (updateServerField ()));
-	connect (cbCustomServer, TQT_SIGNAL (toggled (bool)), this, TQT_SLOT (updateServerField ()));
+	connect (mID, TQ_SIGNAL (textChanged (const TQString &)), this, TQ_SLOT (updateServerField ()));
+	connect (cbCustomServer, TQ_SIGNAL (toggled (bool)), this, TQ_SLOT (updateServerField ()));
 
-	connect (cbUseSSL, TQT_SIGNAL (toggled (bool)), this, TQT_SLOT (sslToggled (bool)));
+	connect (cbUseSSL, TQ_SIGNAL (toggled (bool)), this, TQ_SLOT (sslToggled (bool)));
 
-	connect (btnChangePassword, TQT_SIGNAL ( clicked() ), this, TQT_SLOT ( slotChangePasswordClicked () ));
+	connect (btnChangePassword, TQ_SIGNAL ( clicked() ), this, TQ_SLOT ( slotChangePasswordClicked () ));
 
 	if (account())
 	{
@@ -63,7 +63,7 @@ JabberEditAccountWidget::JabberEditAccountWidget (JabberProtocol * proto, Jabber
 	{
 		// this is a new account
 		btnChangePassword->setEnabled ( false );
-		connect (btnRegister, TQT_SIGNAL (clicked ()), this, TQT_SLOT (registerClicked ()));
+		connect (btnRegister, TQ_SIGNAL (clicked ()), this, TQ_SLOT (registerClicked ()));
 	}
 }
 
@@ -264,7 +264,7 @@ void JabberEditAccountWidget::slotChangePasswordClicked ()
 
 	DlgJabberChangePassword *passwordDlg = new DlgJabberChangePassword ( account (), this );
 
-	connect ( passwordDlg, TQT_SIGNAL ( destroyed () ), this, TQT_SLOT ( slotChangePasswordFinished () ) );
+	connect ( passwordDlg, TQ_SIGNAL ( destroyed () ), this, TQ_SLOT ( slotChangePasswordFinished () ) );
 
 	passwordDlg->show ();
 
