@@ -64,8 +64,8 @@ MSNNotifySocket::MSNNotifySocket( MSNAccount *account, const TQString& /*msnId*/
 
 	m_account = account;
 	m_password=password;
-	TQObject::connect( this, TQT_SIGNAL( blockRead( const TQByteArray & ) ),
-		this, TQT_SLOT( slotReadMessage( const TQByteArray & ) ) );
+	TQObject::connect( this, TQ_SIGNAL( blockRead( const TQByteArray & ) ),
+		this, TQ_SLOT( slotReadMessage( const TQByteArray & ) ) );
 	m_keepaliveTimer = 0L;
 	m_isLogged = false;
 }
@@ -288,9 +288,9 @@ void MSNNotifySocket::parseCommand( const TQString &cmd, uint id, const TQString
 		{
 			m_secureLoginHandler = new MSNSecureLoginHandler(m_account->accountId(), m_password, data.section( ' ' , 2 , 2 ));
 
-			TQObject::connect(m_secureLoginHandler, TQT_SIGNAL(loginFailed()), this, TQT_SLOT(sslLoginFailed()));
-			TQObject::connect(m_secureLoginHandler, TQT_SIGNAL(loginBadPassword()), this, TQT_SLOT(sslLoginIncorrect()));
-			TQObject::connect(m_secureLoginHandler, TQT_SIGNAL(loginSuccesful(TQString )), this, TQT_SLOT(sslLoginSucceeded(TQString )));
+			TQObject::connect(m_secureLoginHandler, TQ_SIGNAL(loginFailed()), this, TQ_SLOT(sslLoginFailed()));
+			TQObject::connect(m_secureLoginHandler, TQ_SIGNAL(loginBadPassword()), this, TQ_SLOT(sslLoginIncorrect()));
+			TQObject::connect(m_secureLoginHandler, TQ_SIGNAL(loginSuccesful(TQString )), this, TQ_SLOT(sslLoginSucceeded(TQString )));
 
 			m_secureLoginHandler->login();
 		}
@@ -724,7 +724,7 @@ bool MSNNotifySocket::setUseHttpMethod(bool useHttp)
 	else {
 		if( !m_keepaliveTimer ) {
 			m_keepaliveTimer = new TQTimer( this, "m_keepaliveTimer" );
-			TQObject::connect( m_keepaliveTimer, TQT_SIGNAL( timeout() ), TQT_SLOT( slotSendKeepAlive() ) );
+			TQObject::connect( m_keepaliveTimer, TQ_SIGNAL( timeout() ), TQ_SLOT( slotSendKeepAlive() ) );
 		}
 	}
 
@@ -755,7 +755,7 @@ void MSNNotifySocket::slotReadMessage( const TQByteArray &bytes )
 			// If there are new email message available, raise the unread email event.
 			TQObject::connect(KNotification::event( "msn_mail", i18n( "You have one unread message in your MSN inbox.",
 					"You have %n unread messages in your MSN inbox.", mailCount ), 0 , 0 , i18n( "Open Inbox..." ) ),
-				TQT_SIGNAL(activated(unsigned int ) ) , this, TQT_SLOT( slotOpenInbox() ) );
+				TQ_SIGNAL(activated(unsigned int ) ) , this, TQ_SLOT( slotOpenInbox() ) );
 		}
 	}
 	else if(msg.contains("text/x-msmsgsactivemailnotification"))
@@ -777,7 +777,7 @@ void MSNNotifySocket::slotReadMessage( const TQByteArray &bytes )
 		//TODO:  it is also possible to get the subject  (but warning about the encoding)
 		TQObject::connect(KNotification::event( "msn_mail",i18n( "You have one new email from %1 in your MSN inbox." ).arg(m),
 										0 , 0 , i18n( "Open Inbox..." ) ),
-				TQT_SIGNAL(activated(unsigned int ) ) , this, TQT_SLOT( slotOpenInbox() ) );
+				TQ_SIGNAL(activated(unsigned int ) ) , this, TQ_SLOT( slotOpenInbox() ) );
 	}
 	else if(msg.contains("text/x-msmsgsprofile"))
 	{
@@ -912,8 +912,8 @@ void MSNNotifySocket::slotReadMessage( const TQByteArray &bytes )
 			if( subscString != TQString::fromLatin1("s.htm") && actionString != TQString::fromLatin1("a.htm") )
 			{
 				KNotification* notification = KNotification::event("msn_alert", textString, 0L, 0L, actions);
-				TQObject::connect(notification, TQT_SIGNAL(activated(unsigned int)), this, TQT_SLOT(slotMSNAlertLink(unsigned int)));
-				TQObject::connect(notification, TQT_SIGNAL(closed()), this, TQT_SLOT(slotMSNAlertUnwanted()));
+				TQObject::connect(notification, TQ_SIGNAL(activated(unsigned int)), this, TQ_SLOT(slotMSNAlertLink(unsigned int)));
+				TQObject::connect(notification, TQ_SIGNAL(closed()), this, TQ_SLOT(slotMSNAlertUnwanted()));
 			}
 		} // end for each MSG tag
 	}
