@@ -41,7 +41,7 @@ class MSNChallengeHandler;
  */
 class MSNNotifySocket : public MSNSocket
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
