@@ -96,14 +96,14 @@ void MSNSwitchBoardSocket::connectToSwitchBoard(TQString ID, TQString address, T
 	TQString server = address.left( address.find( ":" ) );
 	uint port = address.right( address.length() - address.findRev( ":" ) - 1 ).toUInt();
 
-	TQObject::connect( this, TQT_SIGNAL( blockRead( const TQByteArray & ) ),
-		this, TQT_SLOT(slotReadMessage( const TQByteArray & ) ) );
+	TQObject::connect( this, TQ_SIGNAL( blockRead( const TQByteArray & ) ),
+		this, TQ_SLOT(slotReadMessage( const TQByteArray & ) ) );
 
-	TQObject::connect( this, TQT_SIGNAL( onlineStatusChanged( MSNSocket::OnlineStatus ) ),
-		this, TQT_SLOT( slotOnlineStatusChanged( MSNSocket::OnlineStatus ) ) );
+	TQObject::connect( this, TQ_SIGNAL( onlineStatusChanged( MSNSocket::OnlineStatus ) ),
+		this, TQ_SLOT( slotOnlineStatusChanged( MSNSocket::OnlineStatus ) ) );
 
-	TQObject::connect( this, TQT_SIGNAL( socketClosed( ) ),
-		this, TQT_SLOT( slotSocketClosed( ) ) );
+	TQObject::connect( this, TQ_SIGNAL( socketClosed( ) ),
+		this, TQ_SLOT( slotSocketClosed( ) ) );
 
 	connect( server, port );
 }
@@ -408,7 +408,7 @@ void MSNSwitchBoardSocket::slotReadMessage( const TQByteArray &bytes )
 			if(!m_emoticonTimer) //to be sure no message will be lost, we will appends message to
 			{                    // the queue in 15 secondes even if we have not received emoticons
 				m_emoticonTimer=new TQTimer(this);
-				TQObject::connect(m_emoticonTimer , TQT_SIGNAL(timeout()) , this, TQT_SLOT(cleanQueue()));
+				TQObject::connect(m_emoticonTimer , TQ_SIGNAL(timeout()) , this, TQ_SLOT(cleanQueue()));
 				m_emoticonTimer->start( 15000 , true );
 			}
 		}
@@ -434,7 +434,7 @@ void MSNSwitchBoardSocket::slotReadMessage( const TQByteArray &bytes )
 
 				if( !m_emoticons.contains(msnobj) || !m_emoticons[msnobj].second )
 				{
-					m_emoticons.insert(msnobj, tqMakePair(txt,(KTempFile*)0L));
+					m_emoticons.insert(msnobj, qMakePair(txt,(KTempFile*)0L));
 					MSNContact *c=static_cast<MSNContact*>(m_account->contacts()[m_msgHandle]);
 					if(!c)
 						return;
@@ -828,7 +828,7 @@ int MSNSwitchBoardSocket::sendMsg( const Kopete::Message &msg )
 	{
 		m_keepAliveNb=20;
 		m_keepAlive=new TQTimer(this);
-		TQObject::connect(m_keepAlive, TQT_SIGNAL(timeout()) , this , TQT_SLOT(slotKeepAliveTimer()));
+		TQObject::connect(m_keepAlive, TQ_SIGNAL(timeout()) , this , TQ_SLOT(slotKeepAliveTimer()));
 		m_keepAlive->start(50*1000);
 	}
 
@@ -878,7 +878,7 @@ void MSNSwitchBoardSocket::slotOnlineStatusChanged( MSNSocket::OnlineStatus stat
 		{
 			m_keepAliveNb=20;
 			m_keepAlive=new TQTimer(this);
-			TQObject::connect(m_keepAlive, TQT_SIGNAL(timeout()) , this , TQT_SLOT(slotKeepAliveTimer()));
+			TQObject::connect(m_keepAlive, TQ_SIGNAL(timeout()) , this , TQ_SLOT(slotKeepAliveTimer()));
 			m_keepAlive->start(50*1000);
 		}
 	}
@@ -1090,11 +1090,11 @@ Dispatcher* MSNSwitchBoardSocket::PeerDispatcher()
 		}
 		m_dispatcher = new Dispatcher(this, m_account->accountId(),ip );
 
-// 		TQObject::connect(this, TQT_SIGNAL(blockRead(const TQByteArray&)), m_dispatcher, TQT_SLOT(slotReadMessage(const TQByteArray&)));
-// 		TQObject::connect(m_dispatcher, TQT_SIGNAL(sendCommand(const TQString&, const TQString&, bool, const TQByteArray&, bool)), this, TQT_SLOT(sendCommand(const TQString&, const TQString&, bool, const TQByteArray&, bool)));
-		TQObject::connect(m_dispatcher, TQT_SIGNAL(incomingTransfer(const TQString&, const TQString&, TQ_INT64)), this, TQT_SLOT(slotIncomingFileTransfer(const TQString&, const TQString&, TQ_INT64)));
-		TQObject::connect(m_dispatcher, TQT_SIGNAL(displayIconReceived(KTempFile *, const TQString&)), this, TQT_SLOT(slotEmoticonReceived( KTempFile *, const TQString&)));
-		TQObject::connect(this, TQT_SIGNAL(msgAcknowledgement(unsigned int, bool)), m_dispatcher, TQT_SLOT(messageAcknowledged(unsigned int, bool)));
+// 		TQObject::connect(this, TQ_SIGNAL(blockRead(const TQByteArray&)), m_dispatcher, TQ_SLOT(slotReadMessage(const TQByteArray&)));
+// 		TQObject::connect(m_dispatcher, TQ_SIGNAL(sendCommand(const TQString&, const TQString&, bool, const TQByteArray&, bool)), this, TQ_SLOT(sendCommand(const TQString&, const TQString&, bool, const TQByteArray&, bool)));
+		TQObject::connect(m_dispatcher, TQ_SIGNAL(incomingTransfer(const TQString&, const TQString&, TQ_INT64)), this, TQ_SLOT(slotIncomingFileTransfer(const TQString&, const TQString&, TQ_INT64)));
+		TQObject::connect(m_dispatcher, TQ_SIGNAL(displayIconReceived(KTempFile *, const TQString&)), this, TQ_SLOT(slotEmoticonReceived( KTempFile *, const TQString&)));
+		TQObject::connect(this, TQ_SIGNAL(msgAcknowledgement(unsigned int, bool)), m_dispatcher, TQ_SLOT(messageAcknowledged(unsigned int, bool)));
 		m_dispatcher->m_pictureUrl = m_account->pictureUrl();
 	}
 	return m_dispatcher;
