@@ -165,10 +165,10 @@ Client::Client( TQObject* parent )
 	d->awayMsgRequestTimer = new TQTimer();
 	d->codecProvider = &defaultCodecProvider;
 
-	connect( this, TQT_SIGNAL( redirectionFinished( WORD ) ),
-	         this, TQT_SLOT( checkRedirectionQueue( WORD ) ) );
-	connect( d->awayMsgRequestTimer, TQT_SIGNAL( timeout() ),
-	         this, TQT_SLOT( nextICQAwayMessageRequest() ) );
+	connect( this, TQ_SIGNAL( redirectionFinished( WORD ) ),
+	         this, TQ_SLOT( checkRedirectionQueue( WORD ) ) );
+	connect( d->awayMsgRequestTimer, TQ_SIGNAL( timeout() ),
+	         this, TQ_SLOT( nextICQAwayMessageRequest() ) );
 }
 
 Client::~Client()
@@ -194,10 +194,10 @@ void Client::connectToServer( Connection *c, const TQString& server, bool auth )
 	if ( auth == true )
 	{
 		m_loginTask = new StageOneLoginTask( c->rootTask() );
-		connect( m_loginTask, TQT_SIGNAL( finished() ), this, TQT_SLOT( lt_loginFinished() ) );
+		connect( m_loginTask, TQ_SIGNAL( finished() ), this, TQ_SLOT( lt_loginFinished() ) );
 	}
 
-	connect( c, TQT_SIGNAL( socketError( int, const TQString& ) ), this, TQT_SLOT( determineDisconnection( int, const TQString& ) ) );
+	connect( c, TQ_SIGNAL( socketError( int, const TQString& ) ), this, TQ_SLOT( determineDisconnection( int, const TQString& ) ) );
 	c->connectToServer(server, auth);
 }
 
@@ -343,7 +343,7 @@ void Client::lt_loginFinished()
 		kdDebug(OSCAR_RAW_DEBUG) << k_funcinfo << "stage two done. setting up services" << endl;
 		initializeStaticTasks();
 		ServiceSetupTask* ssTask = new ServiceSetupTask( d->connections.defaultConnection()->rootTask() );
-		connect( ssTask, TQT_SIGNAL( finished() ), this, TQT_SLOT( serviceSetupFinished() ) );
+		connect( ssTask, TQ_SIGNAL( finished() ), this, TQ_SLOT( serviceSetupFinished() ) );
 		ssTask->go( true ); //fire and forget
 		m_loginTaskTwo->deleteLater();
 		m_loginTaskTwo = 0;
@@ -351,7 +351,7 @@ void Client::lt_loginFinished()
 	else if ( d->stage == ClientPrivate::StageOne )
 	{
 		kdDebug(OSCAR_RAW_DEBUG) << k_funcinfo << "stage one login done" << endl;
-		disconnect( m_loginTask, TQT_SIGNAL( finished() ), this, TQT_SLOT( lt_loginFinished() ) );
+		disconnect( m_loginTask, TQ_SIGNAL( finished() ), this, TQ_SLOT( lt_loginFinished() ) );
 
 		if ( m_loginTask->statusCode() == 0 ) //we can start stage two
 		{
@@ -362,7 +362,7 @@ void Client::lt_loginFinished()
 			d->port = m_loginTask->bosPort().toUInt();
 			d->cookie = m_loginTask->loginCookie();
 			close();
-			TQTimer::singleShot( 100, this, TQT_SLOT(startStageTwo() ) );
+			TQTimer::singleShot( 100, this, TQ_SLOT(startStageTwo() ) );
 		}
 		else
 		{
@@ -385,11 +385,11 @@ void Client::startStageTwo()
 	//create the new login task
 	m_loginTaskTwo = new StageTwoLoginTask( c->rootTask() );
 	m_loginTaskTwo->setCookie( d->cookie );
-	TQObject::connect( m_loginTaskTwo, TQT_SIGNAL( finished() ), this, TQT_SLOT( lt_loginFinished() ) );
+	TQObject::connect( m_loginTaskTwo, TQ_SIGNAL( finished() ), this, TQ_SLOT( lt_loginFinished() ) );
 
 
 	//connect
-	TQObject::connect( c, TQT_SIGNAL( connected() ), this, TQT_SLOT( streamConnected() ) );
+	TQObject::connect( c, TQ_SIGNAL( connected() ), this, TQ_SLOT( streamConnected() ) );
 	connectToServer( c, d->host, false ) ;
 
 }
@@ -412,8 +412,8 @@ void Client::serviceSetupFinished()
 		}
 
 		OfflineMessagesTask *offlineMsgTask = new OfflineMessagesTask( c->rootTask() );
-		connect( offlineMsgTask, TQT_SIGNAL( receivedOfflineMessage(const Oscar::Message& ) ),
-				this, TQT_SIGNAL( messageReceived(const Oscar::Message& ) ) );
+		connect( offlineMsgTask, TQ_SIGNAL( receivedOfflineMessage(const Oscar::Message& ) ),
+				this, TQ_SIGNAL( messageReceived(const Oscar::Message& ) ) );
 		offlineMsgTask->go( true );
 	}
 
@@ -628,34 +628,34 @@ void Client::initializeStaticTasks()
 	d->typingNotifyTask = new TypingNotifyTask( c->rootTask() );
 	d->ssiModifyTask = new SSIModifyTask( c->rootTask(), true );
 
-	connect( d->onlineNotifier, TQT_SIGNAL( userIsOnline( const TQString&, const UserDetails& ) ),
-	         this, TQT_SIGNAL( receivedUserInfo( const TQString&, const UserDetails& ) ) );
-	connect( d->onlineNotifier, TQT_SIGNAL( userIsOffline( const TQString&, const UserDetails& ) ),
-	         this, TQT_SLOT( offlineUser( const TQString&, const UserDetails & ) ) );
+	connect( d->onlineNotifier, TQ_SIGNAL( userIsOnline( const TQString&, const UserDetails& ) ),
+	         this, TQ_SIGNAL( receivedUserInfo( const TQString&, const UserDetails& ) ) );
+	connect( d->onlineNotifier, TQ_SIGNAL( userIsOffline( const TQString&, const UserDetails& ) ),
+	         this, TQ_SLOT( offlineUser( const TQString&, const UserDetails & ) ) );
 
-	connect( d->ownStatusTask, TQT_SIGNAL( gotInfo() ), this, TQT_SLOT( haveOwnUserInfo() ) );
-	connect( d->ownStatusTask, TQT_SIGNAL( buddyIconUploadRequested() ), this,
-	         TQT_SIGNAL( iconNeedsUploading() ) );
+	connect( d->ownStatusTask, TQ_SIGNAL( gotInfo() ), this, TQ_SLOT( haveOwnUserInfo() ) );
+	connect( d->ownStatusTask, TQ_SIGNAL( buddyIconUploadRequested() ), this,
+	         TQ_SIGNAL( iconNeedsUploading() ) );
 
-	connect( d->messageReceiverTask, TQT_SIGNAL( receivedMessage( const Oscar::Message& ) ),
-	         this, TQT_SLOT( receivedMessage( const Oscar::Message& ) ) );
+	connect( d->messageReceiverTask, TQ_SIGNAL( receivedMessage( const Oscar::Message& ) ),
+	         this, TQ_SLOT( receivedMessage( const Oscar::Message& ) ) );
 
-	connect( d->ssiAuthTask, TQT_SIGNAL( authRequested( const TQString&, const TQString& ) ),
-	         this, TQT_SIGNAL( authRequestReceived( const TQString&, const TQString& ) ) );
-	connect( d->ssiAuthTask, TQT_SIGNAL( authReplied( const TQString&, const TQString&, bool ) ),
-	         this, TQT_SIGNAL( authReplyReceived( const TQString&, const TQString&, bool ) ) );
+	connect( d->ssiAuthTask, TQ_SIGNAL( authRequested( const TQString&, const TQString& ) ),
+	         this, TQ_SIGNAL( authRequestReceived( const TQString&, const TQString& ) ) );
+	connect( d->ssiAuthTask, TQ_SIGNAL( authReplied( const TQString&, const TQString&, bool ) ),
+	         this, TQ_SIGNAL( authReplyReceived( const TQString&, const TQString&, bool ) ) );
 
-	connect( d->icqInfoTask, TQT_SIGNAL( receivedInfoFor( const TQString&, unsigned int ) ),
-	         this, TQT_SLOT( receivedIcqInfo( const TQString&, unsigned int ) ) );
+	connect( d->icqInfoTask, TQ_SIGNAL( receivedInfoFor( const TQString&, unsigned int ) ),
+	         this, TQ_SLOT( receivedIcqInfo( const TQString&, unsigned int ) ) );
 
-	connect( d->userInfoTask, TQT_SIGNAL( receivedProfile( const TQString&, const TQString& ) ),
-	         this, TQT_SIGNAL( receivedProfile( const TQString&, const TQString& ) ) );
-	connect( d->userInfoTask, TQT_SIGNAL( receivedAwayMessage( const TQString&, const TQString& ) ),
-	         this, TQT_SIGNAL( receivedAwayMessage( const TQString&, const TQString& ) ) );
-	connect( d->typingNotifyTask, TQT_SIGNAL( typingStarted( const TQString& ) ),
-	         this, TQT_SIGNAL( userStartedTyping( const TQString& ) ) );
-	connect( d->typingNotifyTask, TQT_SIGNAL( typingFinished( const TQString& ) ),
-	         this, TQT_SIGNAL( userStoppedTyping( const TQString& ) ) );
+	connect( d->userInfoTask, TQ_SIGNAL( receivedProfile( const TQString&, const TQString& ) ),
+	         this, TQ_SIGNAL( receivedProfile( const TQString&, const TQString& ) ) );
+	connect( d->userInfoTask, TQ_SIGNAL( receivedAwayMessage( const TQString&, const TQString& ) ),
+	         this, TQ_SIGNAL( receivedAwayMessage( const TQString&, const TQString& ) ) );
+	connect( d->typingNotifyTask, TQ_SIGNAL( typingStarted( const TQString& ) ),
+	         this, TQ_SIGNAL( userStartedTyping( const TQString& ) ) );
+	connect( d->typingNotifyTask, TQ_SIGNAL( typingFinished( const TQString& ) ),
+	         this, TQ_SIGNAL( userStoppedTyping( const TQString& ) ) );
 }
 
 void Client::removeGroup( const TQString& groupName )
@@ -808,8 +808,8 @@ void Client::sendWarning( const TQString& contact, bool anonymous )
 	WarningTask* warnTask = new WarningTask( c->rootTask() );
 	warnTask->setContact( contact );
 	warnTask->setAnonymous( anonymous );
-	TQObject::connect( warnTask, TQT_SIGNAL( userWarned( const TQString&, TQ_UINT16, TQ_UINT16 ) ),
-	                  this, TQT_SIGNAL( userWarned( const TQString&, TQ_UINT16, TQ_UINT16 ) ) );
+	TQObject::connect( warnTask, TQ_SIGNAL( userWarned( const TQString&, TQ_UINT16, TQ_UINT16 ) ),
+	                  this, TQ_SIGNAL( userWarned( const TQString&, TQ_UINT16, TQ_UINT16 ) ) );
 	warnTask->go( true );
 }
 
@@ -974,9 +974,9 @@ void Client::whitePagesSearch( const ICQWPSearchInfo& info )
 	if ( !c )
 		return;
 	UserSearchTask* ust = new UserSearchTask( c->rootTask() );
-	connect( ust, TQT_SIGNAL( foundUser( const ICQSearchResult& ) ),
-	         this, TQT_SIGNAL( gotSearchResults( const ICQSearchResult& ) ) );
-	connect( ust, TQT_SIGNAL( searchFinished( int ) ), this, TQT_SIGNAL( endOfSearch( int ) ) );
+	connect( ust, TQ_SIGNAL( foundUser( const ICQSearchResult& ) ),
+	         this, TQ_SIGNAL( gotSearchResults( const ICQSearchResult& ) ) );
+	connect( ust, TQ_SIGNAL( searchFinished( int ) ), this, TQ_SIGNAL( endOfSearch( int ) ) );
 	ust->go( true ); //onGo does nothing in this task. This is just here so autodelete works
 	ust->searchWhitePages( info );
 }
@@ -987,9 +987,9 @@ void Client::uinSearch( const TQString& uin )
 	if ( !c )
 		return;
 	UserSearchTask* ust = new UserSearchTask( c->rootTask() );
-	connect( ust, TQT_SIGNAL( foundUser( const ICQSearchResult& ) ),
-	         this, TQT_SIGNAL( gotSearchResults( const ICQSearchResult& ) ) );
-	connect( ust, TQT_SIGNAL( searchFinished( int ) ), this, TQT_SIGNAL( endOfSearch( int ) ) );
+	connect( ust, TQ_SIGNAL( foundUser( const ICQSearchResult& ) ),
+	         this, TQ_SIGNAL( gotSearchResults( const ICQSearchResult& ) ) );
+	connect( ust, TQ_SIGNAL( searchFinished( int ) ), this, TQ_SIGNAL( endOfSearch( int ) ) );
 	ust->go( true ); //onGo does nothing in this task. This is just here so autodelete works
 	ust->searchUserByUIN( uin );
 }
@@ -1079,8 +1079,8 @@ void Client::requestBuddyIcon( const TQString& user, const TQByteArray& hash, BY
 		return;
 
 	BuddyIconTask* bit = new BuddyIconTask( c->rootTask() );
-	connect( bit, TQT_SIGNAL( haveIcon( const TQString&, TQByteArray ) ),
-	         this, TQT_SIGNAL( haveIconForContact( const TQString&, TQByteArray ) ) );
+	connect( bit, TQ_SIGNAL( haveIcon( const TQString&, TQByteArray ) ),
+	         this, TQ_SIGNAL( haveIconForContact( const TQString&, TQByteArray ) ) );
 	bit->requestIconFor( user );
 	bit->setHashType( hashType );
 	bit->setHash( hash );
@@ -1118,8 +1118,8 @@ void Client::requestServerRedirect( WORD family, WORD exchange,
         srt->setChatRoom( room );
     }
 
-	connect( srt, TQT_SIGNAL( haveServer( const TQString&, const TQByteArray&, WORD ) ),
-	         this, TQT_SLOT( haveServerForRedirect( const TQString&, const TQByteArray&, WORD ) ) );
+	connect( srt, TQ_SIGNAL( haveServer( const TQString&, const TQByteArray&, WORD ) ),
+	         this, TQ_SLOT( haveServerForRedirect( const TQString&, const TQByteArray&, WORD ) ) );
 	srt->setService( family );
 	srt->go( true );
 }
@@ -1147,11 +1147,11 @@ void Client::haveServerForRedirect( const TQString& host, const TQByteArray& coo
 	//create the new login task
 	m_loginTaskTwo = new StageTwoLoginTask( c->rootTask() );
 	m_loginTaskTwo->setCookie( cookie );
-	TQObject::connect( m_loginTaskTwo, TQT_SIGNAL( finished() ), this, TQT_SLOT( serverRedirectFinished() ) );
+	TQObject::connect( m_loginTaskTwo, TQ_SIGNAL( finished() ), this, TQ_SLOT( serverRedirectFinished() ) );
 
 	//connect
 	connectToServer( c, d->host, false );
-  	TQObject::connect( c, TQT_SIGNAL( connected() ), this, TQT_SLOT( streamConnected() ) );
+  	TQObject::connect( c, TQ_SIGNAL( connected() ), this, TQ_SLOT( streamConnected() ) );
 
     if ( srt )
         d->connections.addChatInfoForConnection( c, srt->chatExchange(), srt->chatRoomName() );
@@ -1177,8 +1177,8 @@ void Client::serverRedirectFinished()
 
 	if ( d->currentRedirect == 0x000D )
 	{
-		connect( this, TQT_SIGNAL( chatNavigationConnected() ),
-				 this, TQT_SLOT( requestChatNavLimits() ) );
+		connect( this, TQ_SIGNAL( chatNavigationConnected() ),
+				 this, TQ_SLOT( requestChatNavLimits() ) );
 		emit chatNavigationConnected();
 	}
 
@@ -1199,12 +1199,12 @@ void Client::serverRedirectFinished()
         {
             kdDebug(OSCAR_RAW_DEBUG) << k_funcinfo << "setting up chat connection" << endl;
             ChatServiceTask* cst = new ChatServiceTask( c->rootTask(), exchange, roomName );
-            connect( cst, TQT_SIGNAL( userJoinedChat( Oscar::WORD, const TQString&, const TQString& ) ),
-                     this, TQT_SIGNAL( userJoinedChat( Oscar::WORD, const TQString&, const TQString& ) ) );
-            connect( cst, TQT_SIGNAL( userLeftChat( Oscar::WORD, const TQString&, const TQString& ) ),
-                     this, TQT_SIGNAL( userLeftChat( Oscar::WORD, const TQString&, const TQString& ) ) );
-            connect( cst, TQT_SIGNAL( newChatMessage( const Oscar::Message& ) ),
-                     this, TQT_SIGNAL( messageReceived( const Oscar::Message& ) ) );
+            connect( cst, TQ_SIGNAL( userJoinedChat( Oscar::WORD, const TQString&, const TQString& ) ),
+                     this, TQ_SIGNAL( userJoinedChat( Oscar::WORD, const TQString&, const TQString& ) ) );
+            connect( cst, TQ_SIGNAL( userLeftChat( Oscar::WORD, const TQString&, const TQString& ) ),
+                     this, TQ_SIGNAL( userLeftChat( Oscar::WORD, const TQString&, const TQString& ) ) );
+            connect( cst, TQ_SIGNAL( newChatMessage( const Oscar::Message& ) ),
+                     this, TQ_SIGNAL( messageReceived( const Oscar::Message& ) ) );
         }
         emit chatRoomConnected( exchange, roomName );
     }
@@ -1235,8 +1235,8 @@ void Client::requestChatNavLimits()
 	kdDebug(OSCAR_RAW_DEBUG) << k_funcinfo << "requesting chat nav service limits" << endl;
 	ChatNavServiceTask* cnst = new ChatNavServiceTask( c->rootTask() );
     cnst->setRequestType( ChatNavServiceTask::Limits );
-    TQObject::connect( cnst, TQT_SIGNAL( haveChatExchanges( const TQValueList<int>& ) ),
-                      this, TQT_SLOT( setChatExchangeList( const TQValueList<int>& ) ) );
+    TQObject::connect( cnst, TQ_SIGNAL( haveChatExchanges( const TQValueList<int>& ) ),
+                      this, TQ_SLOT( setChatExchangeList( const TQValueList<int>& ) ) );
 	cnst->go( true ); //autodelete
 
 }
@@ -1283,8 +1283,8 @@ void Client::joinChatRoom( const TQString& roomName, int exchange )
     kdDebug(OSCAR_RAW_DEBUG) << k_funcinfo << "joining the chat room '" << roomName
                              << "' on exchange " << exchange << endl;
     ChatNavServiceTask* cnst = new ChatNavServiceTask( c->rootTask() );
-    connect( cnst, TQT_SIGNAL( connectChat( WORD, TQByteArray, WORD, const TQString& ) ),
-             this, TQT_SLOT( setupChatConnection( WORD, TQByteArray, WORD, const TQString& ) ) );
+    connect( cnst, TQ_SIGNAL( connectChat( WORD, TQByteArray, WORD, const TQString& ) ),
+             this, TQ_SLOT( setupChatConnection( WORD, TQByteArray, WORD, const TQString& ) ) );
     cnst->createRoom( exchange, roomName );
 
 }
