@@ -29,7 +29,7 @@ using namespace Oscar;
 
 class IcqLoginTask : public Task
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
 	IcqLoginTask( Task* parent );
