@@ -36,7 +36,7 @@ class KResolverEntry;
 class KNetworkConnector : public Connector
 {
 
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
