@@ -23,7 +23,7 @@
 
 class ClientStreamTest : public TQApplication
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
 	ClientStreamTest(int argc, char ** argv);
