@@ -10,13 +10,13 @@ LoginTest::LoginTest(int argc, char ** argv) : TQApplication( argc, argv )
 	myTestObject = new ClientStream( myConnector, myConnector);
 	
 	// notify when the transport layer is connected
-	//connect( myTestObject, TQT_SIGNAL( connected() ), TQT_SLOT( slotConnected() ) );
+	//connect( myTestObject, TQ_SIGNAL( connected() ), TQ_SLOT( slotConnected() ) );
 	myClient = new Client();
 	
 	myConnection = new Connection( myConnector, myTestObject, "AUTHORIZER" );
 	myConnection->setClient( myClient );
 	// do test once the event loop is running
-	TQTimer::singleShot( 0, this, TQT_SLOT( slotDoTest() ) );
+	TQTimer::singleShot( 0, this, TQ_SLOT( slotDoTest() ) );
 	connected = false;
 }
 
@@ -36,8 +36,8 @@ void LoginTest::slotDoTest()
 	myClient->setIsIcq( true );
 	myClient->start( server, 5190, "userid", "password" );
 	myClient->connectToServer( myConnection, server, true );
-	//TQObject::connect( myClient, TQT_SIGNAL( userIsOnline( const TQString& ) ), this, TQT_SLOT( runUserInfoTest()));
-	//TQTimer::singleShot( 6000, this, TQT_SLOT(runUserInfoTest() ) );
+	//TQObject::connect( myClient, TQ_SIGNAL( userIsOnline( const TQString& ) ), this, TQ_SLOT( runUserInfoTest()));
+	//TQTimer::singleShot( 6000, this, TQ_SLOT(runUserInfoTest() ) );
 	connected = true;
 }
 
