@@ -11,7 +11,6 @@
 // * Created: 10.5.1999
 // *************************************************************************
 #include "config.h"
-#ifdef INCLUDE_SMSGSM
 
 #include <gsmlib/gsm_util.h>
 #include <termios.h>
@@ -88,7 +87,7 @@ static void stopTimer()
 
 // KopeteUnixSerialPort members
 
-void KopeteUnixSerialPort::throwModemException(string message) throw(GsmException)
+void KopeteUnixSerialPort::throwModemException(string message)
 {
   ostringstream os;
   os << message << " (errno: " << errno << "/" << strerror(errno) << ")";
@@ -101,7 +100,7 @@ void KopeteUnixSerialPort::putBack(unsigned char c)
   _oldChar = c;
 }
 
-int KopeteUnixSerialPort::readByte() throw(GsmException)
+int KopeteUnixSerialPort::readByte()
 {
   if (_oldChar != -1)
   {
@@ -166,8 +165,7 @@ int KopeteUnixSerialPort::readByte() throw(GsmException)
 }
 
 KopeteUnixSerialPort::KopeteUnixSerialPort(string device, speed_t lineSpeed,
-							   string initString, bool swHandshake)
-  throw(GsmException) :
+							   string initString, bool swHandshake) :
   _oldChar(-1), _timeoutVal(TIMEOUT_SECS)
 {
 	_readNotifier = NULL;
@@ -326,7 +324,7 @@ KopeteUnixSerialPort::KopeteUnixSerialPort(string device, speed_t lineSpeed,
   throwModemException("reset modem failed");
 }
 
-string KopeteUnixSerialPort::getLine() throw(GsmException)
+string KopeteUnixSerialPort::getLine()
 {
   string result;
   int c;
@@ -349,8 +347,7 @@ string KopeteUnixSerialPort::getLine() throw(GsmException)
   return result;
 }
 
-void KopeteUnixSerialPort::putLine(string line,
-							 bool carriageReturn) throw(GsmException)
+void KopeteUnixSerialPort::putLine(string line, bool carriageReturn)
 {
 #ifndef NDEBUG
   if (debugLevel() >= 1)
@@ -418,7 +415,7 @@ void KopeteUnixSerialPort::putLine(string line,
   // in order to properly handle unsolicited result codes from the ME/TA
 }
 
-bool KopeteUnixSerialPort::wait(GsmTime timeout) throw(GsmException)
+bool KopeteUnixSerialPort::wait(GsmTime timeout)
 {
   fd_set fds;
   FD_ZERO(&fds);
@@ -441,5 +438,3 @@ KopeteUnixSerialPort::~KopeteUnixSerialPort()
 }
 
 #include "kopete_unix_serial.moc"
-
-#endif
