@@ -51,7 +51,7 @@ WPContact::WPContact(Kopete::Account *account, const TQString &newHostName, cons
 	// Initialise and start the periodical checking for contact's status
 	setOnlineStatus(static_cast<WPProtocol *>(protocol())->WPOffline);
 
-	connect(&checkStatus, TQT_SIGNAL(timeout()), this, TQT_SLOT(slotCheckStatus()));
+	connect(&checkStatus, TQ_SIGNAL(timeout()), this, TQ_SLOT(slotCheckStatus()));
 	checkStatus.start(1000, false);
 }
 
@@ -77,9 +77,9 @@ Kopete::ChatSession* WPContact::manager( Kopete::Contact::CanCreateFlags /*canCr
 
 		m_manager = Kopete::ChatSessionManager::self()->create( account()->myself(), singleContact, protocol() );
 
-		connect(m_manager, TQT_SIGNAL(messageSent(Kopete::Message &, Kopete::ChatSession *)), this, TQT_SLOT(slotSendMessage(Kopete::Message &)));
-		connect(m_manager, TQT_SIGNAL(messageSent(Kopete::Message &, Kopete::ChatSession *)), m_manager, TQT_SLOT(appendMessage(Kopete::Message &)));
-		connect(m_manager, TQT_SIGNAL(destroyed()), this, TQT_SLOT(slotChatSessionDestroyed()));
+		connect(m_manager, TQ_SIGNAL(messageSent(Kopete::Message &, Kopete::ChatSession *)), this, TQ_SLOT(slotSendMessage(Kopete::Message &)));
+		connect(m_manager, TQ_SIGNAL(messageSent(Kopete::Message &, Kopete::ChatSession *)), m_manager, TQ_SLOT(appendMessage(Kopete::Message &)));
+		connect(m_manager, TQ_SIGNAL(destroyed()), this, TQ_SLOT(slotChatSessionDestroyed()));
 	}
 
 	return m_manager;
@@ -111,7 +111,7 @@ void WPContact::slotUserInfo()
 	if (!m_infoDialog) {
 		m_infoDialog = new WPUserInfo( this, static_cast<WPAccount*>( account() ) );
 		if (!m_infoDialog) return;
-		connect( m_infoDialog, TQT_SIGNAL( closing() ), this, TQT_SLOT( slotCloseUserInfoDialog() ) );
+		connect( m_infoDialog, TQ_SIGNAL( closing() ), this, TQ_SLOT( slotCloseUserInfoDialog() ) );
 		m_infoDialog->show();
 	} else {
 		m_infoDialog->raise();
