@@ -27,7 +27,7 @@ class YMSGTransfer;
 */
 class ListTask : public Task
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
 	ListTask(Task *parent);
