@@ -45,7 +45,7 @@ namespace KPF
   class WebServer : public TQObject, virtual public DCOPObject
   {
     K_DCOP
-    Q_OBJECT
+    TQ_OBJECT
 //    
 
     public:
