@@ -48,7 +48,7 @@
 class IPLineEdit;
 
 class DialWidget : public TQWidget {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   DialWidget( TQWidget *parent=0, bool isnewaccount = true, const char *name=0 );
@@ -91,7 +91,7 @@ private:
 //
 /////////////////////////////////////////////////////////////////////////////
 class ExecWidget : public TQWidget {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   ExecWidget(TQWidget *parent=0, bool isnewaccount=true, const char *name=0);
@@ -115,7 +115,7 @@ private:
 
 
 class IPWidget : public TQWidget {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   IPWidget( TQWidget *parent=0, bool isnewaccount = true, const char *name=0 );
@@ -146,7 +146,7 @@ private:
 
 
 class DNSWidget : public TQWidget {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   DNSWidget( TQWidget *parent=0, bool isnewaccount = true, const char *name=0 );
@@ -179,7 +179,7 @@ private:
 
 
 class GatewayWidget : public TQWidget {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   GatewayWidget( TQWidget *parent=0, bool isnewaccount = true, const char *name=0 );
@@ -204,7 +204,7 @@ private:
 
 
 class ScriptWidget : public TQWidget {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   ScriptWidget( TQWidget *parent=0, bool isnewaccount = true, const char *name=0 );
@@ -245,7 +245,7 @@ private:
 //
 /////////////////////////////////////////////////////////////////////////////
 class PhoneNumberDialog : public KDialogBase {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   PhoneNumberDialog(TQWidget *parent = 0);
