@@ -105,8 +105,8 @@ KPPPWidget::KPPPWidget( TQWidget *parent, const char *name )
   connectto_c = new TQComboBox(false, this);
   label1->setBuddy(connectto_c);
 
-  connect(connectto_c, TQT_SIGNAL(activated(int)),
-	  TQT_SLOT(newdefaultaccount(int)));
+  connect(connectto_c, TQ_SIGNAL(activated(int)),
+	  TQ_SLOT(newdefaultaccount(int)));
   l1->addWidget(connectto_c, 0, 2);
 
   label7 = new TQLabel(i18n("Use &modem: "), this);
@@ -115,8 +115,8 @@ KPPPWidget::KPPPWidget( TQWidget *parent, const char *name )
   label7->setBuddy(connectto_c);
   m_bModemCShown = false;
 
-  connect(modem_c, TQT_SIGNAL(activated(int)),
-	  TQT_SLOT(newdefaultmodem(int)));
+  connect(modem_c, TQ_SIGNAL(activated(int)),
+	  TQ_SLOT(newdefaultmodem(int)));
   // l1->addWidget(modem_c, 1, 2); (done in resetmodems())
 
   ID_Label = new TQLabel(i18n("&Login ID:"), this);
@@ -126,8 +126,8 @@ KPPPWidget::KPPPWidget( TQWidget *parent, const char *name )
   ID_Edit = new TQLineEdit(this);
   ID_Label->setBuddy(ID_Edit);
   l1->addWidget(ID_Edit, 2, 2);
-  connect(ID_Edit, TQT_SIGNAL(returnPressed()),
-	  this, TQT_SLOT(enterPressedInID()));
+  connect(ID_Edit, TQ_SIGNAL(returnPressed()),
+	  this, TQ_SLOT(enterPressedInID()));
   TQString tmp = i18n("<p>Type in the username that you got from your\n"
 		     "ISP. This is especially important for PAP\n"
 		     "and CHAP. You may omit this when you use\n"
@@ -146,8 +146,8 @@ KPPPWidget::KPPPWidget( TQWidget *parent, const char *name )
   PW_Label->setBuddy(PW_Edit);
   PW_Edit->setEchoMode(TQLineEdit::Password);
   l1->addWidget(PW_Edit, 3, 2);
-  connect(PW_Edit, TQT_SIGNAL(returnPressed()),
-	  this, TQT_SLOT(enterPressedInPW()));
+  connect(PW_Edit, TQ_SIGNAL(returnPressed()),
+	  this, TQ_SLOT(enterPressedInPW()));
 
   tmp = i18n("<p>Type in the password that you got from your\n"
 	     "ISP. This is especially important for PAP\n"
@@ -166,8 +166,8 @@ KPPPWidget::KPPPWidget( TQWidget *parent, const char *name )
    tl->addSpacing(5);
    l3->addSpacing(10);
    log = new TQCheckBox(i18n("Show lo&g window"), this);
-   connect(log, TQT_SIGNAL(toggled(bool)),
-  	  this, TQT_SLOT(log_window_toggled(bool)));
+   connect(log, TQ_SIGNAL(toggled(bool)),
+  	  this, TQ_SLOT(log_window_toggled(bool)));
    log->setChecked(gpppdata.get_show_log_window());
    l3->addWidget(log);
 
@@ -188,12 +188,12 @@ KPPPWidget::KPPPWidget( TQWidget *parent, const char *name )
 
   int minw = 0;
   quit_b = new KPushButton(KStdGuiItem::quit(), this);
-  connect( quit_b, TQT_SIGNAL(clicked()), TQT_SLOT(quitbutton()));
+  connect( quit_b, TQ_SIGNAL(clicked()), TQ_SLOT(quitbutton()));
   if(quit_b->sizeHint().width() > minw)
       minw = quit_b->sizeHint().width();
 
   setup_b = new KPushButton(KGuiItem(i18n("Co&nfigure..."), "configure"), this);
-  connect( setup_b, TQT_SIGNAL(clicked()), TQT_SLOT(expandbutton()));
+  connect( setup_b, TQ_SIGNAL(clicked()), TQ_SLOT(expandbutton()));
   if(setup_b->sizeHint().width() > minw)
       minw = setup_b->sizeHint().width();
 
@@ -201,7 +201,7 @@ KPPPWidget::KPPPWidget( TQWidget *parent, const char *name )
     setup_b->setEnabled(false);
 
   help_b = new KPushButton(KStdGuiItem::help(), this);
-  connect( help_b, TQT_SIGNAL(clicked()), TQT_SLOT(helpbutton()));
+  connect( help_b, TQ_SIGNAL(clicked()), TQ_SLOT(helpbutton()));
 
   KHelpMenu *helpMenu = new KHelpMenu(this, TDEGlobal::instance()->aboutData(), true);
   help_b->setPopup((TQPopupMenu*)helpMenu->menu());
@@ -212,7 +212,7 @@ KPPPWidget::KPPPWidget( TQWidget *parent, const char *name )
   connect_b = new TQPushButton(i18n("&Connect"), this);
   connect_b->setDefault(true);
   connect_b->setFocus();
-  connect(connect_b, TQT_SIGNAL(clicked()), TQT_SLOT(beginConnect()));
+  connect(connect_b, TQ_SIGNAL(clicked()), TQ_SLOT(beginConnect()));
   if(connect_b->sizeHint().width() > minw)
       minw = connect_b->sizeHint().width();
 
@@ -233,7 +233,7 @@ KPPPWidget::KPPPWidget( TQWidget *parent, const char *name )
 
   // we also connect cmld_start to the beginConnect so that I can run
   // the dialer through a command line argument
-  connect(this,TQT_SIGNAL(cmdl_start()),this,TQT_SLOT(beginConnect()));
+  connect(this,TQ_SIGNAL(cmdl_start()),this,TQ_SLOT(beginConnect()));
 
   stats = new PPPStats;
 
@@ -256,28 +256,28 @@ KPPPWidget::KPPPWidget( TQWidget *parent, const char *name )
   resetmodems();
   con = new ConnectWidget(0, "con", stats);
   KWin::setIcons(con->winId(), kapp->icon(), kapp->miniIcon() );
-  connect(this, TQT_SIGNAL(begin_connect()),con, TQT_SLOT(preinit()));
+  connect(this, TQ_SIGNAL(begin_connect()),con, TQ_SLOT(preinit()));
 
   TQRect desk = TDEGlobalSettings::desktopGeometry(topLevelWidget());
   con->setGeometry(desk.center().x()-175, desk.center().y()-55, 350,110);
 
   // connect the ConnectWidgets various signals
-  connect(con, TQT_SIGNAL(closeDebugWindow()),
-	  debugwindow, TQT_SLOT(hide()));
-  connect(con, TQT_SIGNAL(debugMessage(const TQString &)),
-	  debugwindow, TQT_SLOT(statusLabel(const TQString &)));
-  connect(con, TQT_SIGNAL(toggleDebugWindow()),
-	  debugwindow, TQT_SLOT(toggleVisibility()));
-  connect(con, TQT_SIGNAL(debugPutChar(unsigned char)),
-	  debugwindow, TQT_SLOT(addChar(unsigned char)));
-  connect(con, TQT_SIGNAL(startAccounting()),
-	  this, TQT_SLOT(startAccounting()));
-  connect(con, TQT_SIGNAL(stopAccounting()),
-	  this, TQT_SLOT(stopAccounting()));
-  connect(TDEApplication::kApplication(), TQT_SIGNAL(saveYourself()),
-	  this, TQT_SLOT(saveMyself()));
-  connect(TDEApplication::kApplication(), TQT_SIGNAL(shutDown()),
-	  this, TQT_SLOT(shutDown()));
+  connect(con, TQ_SIGNAL(closeDebugWindow()),
+	  debugwindow, TQ_SLOT(hide()));
+  connect(con, TQ_SIGNAL(debugMessage(const TQString &)),
+	  debugwindow, TQ_SLOT(statusLabel(const TQString &)));
+  connect(con, TQ_SIGNAL(toggleDebugWindow()),
+	  debugwindow, TQ_SLOT(toggleVisibility()));
+  connect(con, TQ_SIGNAL(debugPutChar(unsigned char)),
+	  debugwindow, TQ_SLOT(addChar(unsigned char)));
+  connect(con, TQ_SIGNAL(startAccounting()),
+	  this, TQ_SLOT(startAccounting()));
+  connect(con, TQ_SIGNAL(stopAccounting()),
+	  this, TQ_SLOT(stopAccounting()));
+  connect(TDEApplication::kApplication(), TQ_SIGNAL(saveYourself()),
+	  this, TQ_SLOT(saveMyself()));
+  connect(TDEApplication::kApplication(), TQ_SIGNAL(shutDown()),
+	  this, TQ_SLOT(shutDown()));
 
   debugwindow->setGeometry(desk.center().x()+190, desk.center().y()-55,
 			   debugwindow->width(),debugwindow->height());
@@ -342,7 +342,7 @@ KPPPWidget::KPPPWidget( TQWidget *parent, const char *name )
   // this timer will delay the actual disconnection DISCONNECTION_DELAY ms
   // to give applications time to shutdown, logout, whatever..
   disconnectTimer = new TQTimer(this);
-  connect(disconnectTimer, TQT_SIGNAL(timeout()), this, TQT_SLOT(delayedDisconnect()));
+  connect(disconnectTimer, TQ_SIGNAL(timeout()), this, TQ_SLOT(delayedDisconnect()));
 }
 
 KPPPWidget::~KPPPWidget()
@@ -391,16 +391,16 @@ void KPPPWidget::prepareSetupDialog() {
     //    tabWindow->setFixedSize( 365, 375 );
 
     accounts = new AccountWidget(tabWindow->addPage( i18n("&Accounts"), i18n("Account Setup") ) );
-    connect(accounts, TQT_SIGNAL(resetaccounts()),
-	    this, TQT_SLOT(resetaccounts()));
-    connect(accounts, TQT_SIGNAL(resetCosts(const TQString &)),
-	    this, TQT_SLOT(resetCosts(const TQString &)));
-    connect(accounts, TQT_SIGNAL(resetVolume(const TQString &)),
-	    this, TQT_SLOT(resetVolume(const TQString &)));
+    connect(accounts, TQ_SIGNAL(resetaccounts()),
+	    this, TQ_SLOT(resetaccounts()));
+    connect(accounts, TQ_SIGNAL(resetCosts(const TQString &)),
+	    this, TQ_SLOT(resetCosts(const TQString &)));
+    connect(accounts, TQ_SIGNAL(resetVolume(const TQString &)),
+	    this, TQ_SLOT(resetVolume(const TQString &)));
 
     modems = new ModemsWidget(tabWindow->addPage( i18n("&Modems"), i18n("Modems Setup") ) );
-    connect(modems, TQT_SIGNAL(resetmodems()),
-	    this, TQT_SLOT(resetmodems()));
+    connect(modems, TQ_SIGNAL(resetmodems()),
+	    this, TQ_SLOT(resetmodems()));
 
     graph = new GraphSetup( tabWindow->addPage( i18n("&Graph"), i18n("Throughput Graph" ) ) );
     general = new GeneralWidget( tabWindow->addPage( i18n("M&isc"), i18n("Miscellaneous Settings") ) );
@@ -476,11 +476,11 @@ void KPPPWidget::resetaccounts() {
 	PW_Edit->setText(gpppdata.storedPassword());
     }
 
-  connect(ID_Edit, TQT_SIGNAL(textChanged(const TQString &)),
- 	  this, TQT_SLOT(usernameChanged(const TQString &)));
+  connect(ID_Edit, TQ_SIGNAL(textChanged(const TQString &)),
+ 	  this, TQ_SLOT(usernameChanged(const TQString &)));
 
-  connect(PW_Edit, TQT_SIGNAL(textChanged(const TQString &)),
- 	  this, TQT_SLOT(passwordChanged(const TQString &)));
+  connect(PW_Edit, TQ_SIGNAL(textChanged(const TQString &)),
+ 	  this, TQ_SLOT(passwordChanged(const TQString &)));
 
   if (ID_Edit->text().isEmpty())
       ID_Edit->setFocus();
@@ -912,13 +912,13 @@ void KPPPWidget::startAccounting() {
 
   TQString d = AccountingBase::getAccountingFile(gpppdata.accountingFile());
   //  if(::access(d.data(), X_OK) != 0)
-    acct = new Accounting(TQT_TQOBJECT(this), stats);
+    acct = new Accounting(this, stats);
     //  else
     //    acct = new ExecutableAccounting(this);
 
   // connect to the accounting object
-  connect(acct, TQT_SIGNAL(changed(TQString, TQString)),
-	  con_win, TQT_SLOT(slotAccounting(TQString, TQString)));
+  connect(acct, TQ_SIGNAL(changed(TQString, TQString)),
+	  con_win, TQ_SLOT(slotAccounting(TQString, TQString)));
 
   if(!acct->loadRuleSet(gpppdata.accountingFile())) {
     TQString s= i18n("Can not load the accounting "
@@ -927,7 +927,7 @@ void KPPPWidget::startAccounting() {
     // starting the messagebox with a timer will prevent us
     // from blocking the calling function ConnectWidget::timerEvent
     ruleset_load_errmsg = s;
-    TQTimer::singleShot(0, this, TQT_SLOT(rulesetLoadError()));
+    TQTimer::singleShot(0, this, TQ_SLOT(rulesetLoadError()));
     return;
   } else
     acct->slotStart();
@@ -1043,8 +1043,8 @@ void KPPPWidget::showNews() {
     bbox->addStretch(1);
     TQPushButton *ok = bbox->addButton(KStdGuiItem::ok());
     ok->setDefault(true);
-    dlg.connect(ok, TQT_SIGNAL(clicked()),
-		&dlg, TQT_SLOT(accept()));
+    dlg.connect(ok, TQ_SIGNAL(clicked()),
+		&dlg, TQ_SLOT(accept()));
     bbox->addStretch(1);
     bbox->layout();
 
