@@ -8,7 +8,7 @@
 
 class LoginMultiLineEdit : public TQMultiLineEdit {
 
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
@@ -27,7 +27,7 @@ public slots:
 
 
 class LoginTerm : public TQDialog {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   LoginTerm(TQWidget *parent, const char *name);
