@@ -77,8 +77,8 @@ bool PortListener::acquirePort() {
 		delete m_socket;
 		m_socket = new TDEServerSocket(m_port, false);
 	}
-	connect(m_socket, TQT_SIGNAL(accepted(TDESocket*)),
-		TQT_SLOT(accepted(TDESocket*)));
+	connect(m_socket, TQ_SIGNAL(accepted(TDESocket*)),
+		TQ_SLOT(accepted(TDESocket*)));
 
 	bool s = m_registerService;
 	bool sd =m_dnssdRegister;
@@ -421,9 +421,9 @@ KInetD::KInetD(TQCString &n) :
 		m_srvreg = 0;
 	}
 	m_portListeners.setAutoDelete(true);
-	connect(&m_expirationTimer, TQT_SIGNAL(timeout()), TQT_SLOT(setExpirationTimer()));
-	connect(&m_portRetryTimer, TQT_SIGNAL(timeout()), TQT_SLOT(portRetryTimer()));
-	connect(&m_reregistrationTimer, TQT_SIGNAL(timeout()), TQT_SLOT(reregistrationTimer()));
+	connect(&m_expirationTimer, TQ_SIGNAL(timeout()), TQ_SLOT(setExpirationTimer()));
+	connect(&m_portRetryTimer, TQ_SIGNAL(timeout()), TQ_SLOT(portRetryTimer()));
+	connect(&m_reregistrationTimer, TQ_SIGNAL(timeout()), TQ_SLOT(reregistrationTimer()));
 	loadServiceList();
 }
 
@@ -650,7 +650,7 @@ KInetD::~KInetD() {
 }
 
 extern "C" {
-	KDE_EXPORT KDEDModule *create_kinetd(TQCString &name)
+	TDE_EXPORT KDEDModule *create_kinetd(TQCString &name)
 	{
         TDEGlobal::locale()->insertCatalogue("kinetd");
 		return new KInetD(name);
