@@ -6,7 +6,7 @@ PageFont::PageFont( TQWidget *parent, const char *name ) :
   layout = new TQHBoxLayout(this);
   fontchooser = new TDEFontChooser(this);
   layout->addWidget(fontchooser);
-  connect(fontchooser,TQT_SIGNAL(fontSelected ( const TQFont&)), this, TQT_SLOT(update())); 
+  connect(fontchooser,TQ_SIGNAL(fontSelected ( const TQFont&)), this, TQ_SLOT(update())); 
 }
 
 PageFont::~PageFont( )
