@@ -15,7 +15,7 @@
 
 class PageLooknFeel : public PageLooknFeelBase
 {
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
