@@ -14,7 +14,7 @@
 
 class KSProgress : public ksprogressData
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
