@@ -17,7 +17,7 @@ KSircIOLAG::KSircIOLAG(KSircProcess *_proc)
     KSircMessageReceiver(_proc)
 {
   proc = _proc;
-  setBroadcast(FALSE);
+  setBroadcast(false);
   startTimer(30000);
 //  startTimer(5000);
 //(proc->getWindowList())["!all"]->control_message(SET_LAG, "99");
