@@ -117,7 +117,7 @@ KSircIOController::KSircIOController(TDEProcess *_proc, KSircProcess *_ksircproc
                                               // Notify on sirc dying
   connect(proc, TQ_SIGNAL(wroteStdin(TDEProcess*)),
 	  this, TQ_SLOT(procCTS(TDEProcess*)));
-  proc_CTS = TRUE;
+  proc_CTS = true;
 #if 0
   showDebugTraffic(true);
 #endif
@@ -261,9 +261,9 @@ void KSircIOController::stdout_read(TDEProcess *, char *_buffer, int buflen)
         // Ignore ssfe control messages with `
         // we left channel, don't open a window for a control message
         bool noticeCreate = true;
-        if(ksopts->autoCreateWinForNotice == false && (line[0] == '-' || line[0] == '*'))
+        if(!ksopts->autoCreateWinForNotice && (line[0] == '-' || line[0] == '*'))
             noticeCreate = false;
-        if(ksopts->autoCreateWin == TRUE && line[0] != '`' && line[1] != '#' && line[1] != '&' && noticeCreate) {
+        if(ksopts->autoCreateWin && line[0] != '`' && line[1] != '#' && line[1] != '&' && noticeCreate) {
 	    //kdDebug(5008) << "Creating window for: " << qsname << " because of: " << line.data() << endl;
 	    ksircproc->new_toplevel(KSircChannel(ksircproc->serverName(), qsname));
         }
@@ -315,7 +315,7 @@ void KSircIOController::stdin_write(TQCString s)
   //fprintf(stderr, "Buffer output: ");
   //my_print(buffer);
 
-  if(proc_CTS == TRUE){
+  if(proc_CTS){
     int len = buffer.length();
     if(send_buf != 0x0){
       tqWarning("TDEProcess barfed in all clear signal again");
@@ -323,7 +323,7 @@ void KSircIOController::stdin_write(TQCString s)
     }
     send_buf = new char[len];
     memcpy(send_buf, buffer.data(), len);
-    if(proc->writeStdin(send_buf, len) == FALSE){
+    if(!proc->writeStdin(send_buf, len)){
       kdDebug(5008) << "Failed to write but CTS HIGH! Setting low!: " << s << endl;
     }
     else{
@@ -334,7 +334,7 @@ void KSircIOController::stdin_write(TQCString s)
 	}
 	buffer.truncate(0);
     }
-    proc_CTS = FALSE;
+    proc_CTS = false;
   }
 
   if(buffer.length() > 5000){
@@ -393,14 +393,14 @@ void KSircIOController::showContextMenuOnDebugWindow(TQListBoxItem *, const TQPo
 void KSircIOController::showDebugTraffic(bool show)
 {
     kdDebug(5008) << "Got show request: " << show << endl;
-    if(m_debugLB == 0 && show == true){
+    if(m_debugLB == 0 && show){
 	m_debugLB = new TQListBox(0x0, TQCString(this->name()) + "_debugWindow");
         m_debugLB->resize(600, 300);
         m_debugLB->show();
         connect(m_debugLB,TQ_SIGNAL(contextMenuRequested(TQListBoxItem *,const TQPoint &)),
                 this,TQ_SLOT(showContextMenuOnDebugWindow(TQListBoxItem *,const TQPoint &)));
     }
-    else if(m_debugLB != 0 && show == false){
+    else if(m_debugLB != 0 && !show){
 	delete m_debugLB;
         m_debugLB = 0x0;
     }
