@@ -251,7 +251,7 @@ void KSOptions::load( int sections )
         /*
          * do global first
          */
-        if(channel.contains("global") == FALSE){
+        if(!channel.contains("global")){
             KSOChannel global;
             ChannelOpMap coMap;
             channel.insert(TQString("global"), coMap);
@@ -315,7 +315,7 @@ void KSOptions::load( int sections )
 	/*
 	 * do global first
 	 */
-	if(server.contains("global") == FALSE){
+	if(!server.contains("global")){
 	    KSOServer global;
 	    server.insert(TQString("global"), global);
 	    server["global"].server = "global";
@@ -471,7 +471,7 @@ void KSOptions::save( int sections )
         for( ser = server.begin(); ser != server.end(); ++ser ){
 	    TQStringList channels;
 
-	    if(ser.data().globalCopy == true)
+	    if(ser.data().globalCopy)
                 continue;
 
             servers << ser.key();
@@ -490,11 +490,11 @@ void KSOptions::save( int sections )
 
 void KSOptions::channelSetup(TQString serv, TQString chan)
 {
-    if(channel.contains(serv) == FALSE){
+    if(!channel.contains(serv)){
         ChannelOpMap coMap;
         channel.insert(serv, coMap);
     }
-    if(channel[serv].contains(chan) == FALSE){
+    if(!channel[serv].contains(chan)){
         KSOChannel ksoc;
         ksoc = channel["global"]["global"];
         channel[serv].insert(chan, ksoc);
@@ -524,7 +524,7 @@ void KSOptions::applyChannelGlobal(void)
 
 void KSOptions::serverSetup(TQString serv)
 {
-    if(server.contains(serv) == FALSE){
+    if(!server.contains(serv)){
         KSOServer ksos;
         ksos = server["global"];
         server.insert(serv, ksos);
