@@ -1625,8 +1625,8 @@ TextView::TextView( TQWidget *parent, const char *name )
     viewport()->setBackgroundMode( PaletteBase );
     viewport()->setMouseTracking( true );
     m_autoScrollTimer = new TQTimer( this );
-    connect(verticalScrollBar(), TQT_SIGNAL(valueChanged( int ) ),
-            this, TQT_SLOT(scrolling( int )));
+    connect(verticalScrollBar(), TQ_SIGNAL(valueChanged( int ) ),
+            this, TQ_SLOT(scrolling( int )));
 
     setDragAutoScroll( false );
 
@@ -1827,18 +1827,18 @@ void TextView::clearSelectionInternal()
 
 void TextView::contentsMousePressEvent( TQMouseEvent *ev )
 {
-    if ( ev->button() & Qt::RightButton ) {
+    if ( ev->button() & TQt::RightButton ) {
         emitLinkClickedForMouseEvent( ev );
         return;
     }
 
-    if ( !( ev->button() & Qt::LeftButton ) && !(ev->button() & Qt::MidButton ) )
+    if ( !( ev->button() & TQt::LeftButton ) && !(ev->button() & TQt::MidButton ) )
         return;
 
     clearSelection( true );
     SelectionPoint p;
     Item *itemUnderMouse = itemAt( ev->pos(), &p, Item::SelectFuzzy );
-    if ( p.item && ( ev->button() & Qt::LeftButton ) ) {
+    if ( p.item && ( ev->button() & TQt::LeftButton ) ) {
         m_selectionMaybeStart = p;
         p.item->setSelectionStatus( Item::NoSelection );
     }
@@ -1847,7 +1847,7 @@ void TextView::contentsMousePressEvent( TQMouseEvent *ev )
         if ( !href.isNull() ) {
             m_dragStartPos = ev->pos();
             m_dragURL = href.toTQString();
-            if ( ev->button() & Qt::LeftButton )
+            if ( ev->button() & TQt::LeftButton )
                m_mousePressed = true;
             else 
                m_mmbPressed = true;
@@ -1857,7 +1857,7 @@ void TextView::contentsMousePressEvent( TQMouseEvent *ev )
 
 void TextView::contentsMouseMoveEvent( TQMouseEvent *ev )
 {
-    if ( m_mousePressed && ev->state() == Qt::NoButton )
+    if ( m_mousePressed && ev->state() == TQt::NoButton )
     {
         m_mousePressed = false;
         m_mmbPressed = false;
@@ -1881,8 +1881,8 @@ void TextView::contentsMouseMoveEvent( TQMouseEvent *ev )
     if ( !i && !p.item )
         return;
 
-    if ( (ev->state() & Qt::LeftButton && m_selectionStart.item && p.item) ||
-         (ev->state() & Qt::LeftButton && m_selectionMaybeStart.item && p.item))
+    if ( (ev->state() & TQt::LeftButton && m_selectionStart.item && p.item) ||
+         (ev->state() & TQt::LeftButton && m_selectionMaybeStart.item && p.item))
     {
 
         if(m_selectionMaybeStart.item != 0){
@@ -1952,7 +1952,7 @@ void TextView::contentsMouseReleaseEvent( TQMouseEvent *ev )
 
     m_selectionMaybeStart = SelectionPoint();
 
-    if ( (ev->button() & Qt::LeftButton) && !m_selectedText.isEmpty() )
+    if ( (ev->button() & TQt::LeftButton) && !m_selectedText.isEmpty() )
         TQApplication::clipboard()->setText( m_selectedText, TQClipboard::Selection );
 
     if ( clicked ) {
@@ -1960,7 +1960,7 @@ void TextView::contentsMouseReleaseEvent( TQMouseEvent *ev )
         return;
     }
 
-    if (ev->button() & Qt::MidButton)
+    if (ev->button() & TQt::MidButton)
     {
         emit pasteReq( TDEApplication::clipboard()->text( TQClipboard::Selection ) );
         return;
@@ -2028,16 +2028,16 @@ void TextView::emitLinkClickedForMouseEvent( TQMouseEvent *ev )
 void TextView::startAutoScroll()
 {
     if(m_autoScrollTimer->isActive() == false){
-	connect( m_autoScrollTimer, TQT_SIGNAL( timeout() ),
-		 this, TQT_SLOT( autoScroll() ) );
+	connect( m_autoScrollTimer, TQ_SIGNAL( timeout() ),
+		 this, TQ_SLOT( autoScroll() ) );
 	m_autoScrollTimer->start( 75, false );
     }
 }
 
 void TextView::stopAutoScroll()
 {
-    disconnect( m_autoScrollTimer, TQT_SIGNAL( timeout() ),
-                this, TQT_SLOT( autoScroll() ) );
+    disconnect( m_autoScrollTimer, TQ_SIGNAL( timeout() ),
+                this, TQ_SLOT( autoScroll() ) );
     m_autoScrollTimer->stop();
 }
 
@@ -2263,7 +2263,3 @@ TQString TextParagIterator::plainText() const
 }
 
 #include "kstextview.moc"
-
-/*
- * vim: et sw=4
- */
