@@ -57,7 +57,7 @@ TQObject *objFinder::find(const char *name, const char *inherits){
     if(len == strlen(it.current()->name()) &&
        strcmp(it.current()->name(), name) == 0)
       return it.current();
-    TQObjectList *qobl = it.current()->queryList(inherits, name, FALSE);
+    TQObjectList *qobl = it.current()->queryList(inherits, name, false);
     TQObjectListIt itql( *qobl );
     if(itql.current() != 0x0){
       found = itql.current();
@@ -72,7 +72,7 @@ TQObject *objFinder::find(const char *name, const char *inherits){
   while(itW.current()){
     if(len == strlen(itW.current()->name()) &&
        strcmp(itW.current()->name(), name) == 0){
-      if(inherits != 0x0 && itW.current()->inherits(inherits) == FALSE){
+      if(inherits != 0x0 && !itW.current()->inherits(inherits)){
         ++itW;
         continue;
       }
