@@ -10,11 +10,11 @@ PLabel::createWidget(CreateArgs &ca)
 {
   PLabel *pw = new PLabel(ca.parent);
   TQLabel *le;
-  if(ca.fetchedObj != 0 && ca.fetchedObj->inherits("TQLabel") == TRUE){
+  if(ca.fetchedObj != 0 && ca.fetchedObj->inherits("TQLabel")){
     le = (TQLabel *) ca.fetchedObj;
-    pw->setDeleteAble(FALSE);
+    pw->setDeleteAble(false);
   }
-  else if(ca.parent != 0 && ca.parent->widget()->isWidgetType() == TRUE)
+  else if(ca.parent != 0 && ca.parent->widget()->isWidgetType())
     le = new TQLabel((TQWidget *) ca.parent->widget());
   else
     le = new TQLabel((TQWidget *)0L);
@@ -97,7 +97,7 @@ void PLabel::messageHandler(int fd, PukeMessage *pm)
 
 void PLabel::setWidget(TQObject *_l)
 {
-  if(_l != 0 && _l->inherits("TQLabel") == FALSE)
+  if(_l != 0 && !_l->inherits("TQLabel"))
   {
      errorInvalidSet(_l);
      return;
@@ -117,9 +117,9 @@ TQLabel *PLabel::widget()
 bool PLabel::checkWidget(){
   if(widget() == 0){
     kdDebug(5008) << "PLabel: No Widget set" << endl;
-    return FALSE;
+    return false;
   }
-  return TRUE;
+  return true;
 }
 
 
