@@ -10,7 +10,7 @@ PLineEdit::createWidget(CreateArgs &ca)
 {
   PLineEdit *pw = new PLineEdit(ca.parent);
   TQLineEdit *le;
-  if(ca.parent != 0 && ca.parent->widget()->isWidgetType() == TRUE)
+  if(ca.parent != 0 && ca.parent->widget()->isWidgetType())
     le = new TQLineEdit((TQWidget *) ca.parent->widget());
   else
     le = new TQLineEdit(0L);
@@ -103,7 +103,7 @@ void PLineEdit::messageHandler(int fd, PukeMessage *pm)
 
 void PLineEdit::setWidget(TQObject *_le)
 {
-  if(_le != 0 && _le->inherits("TQLineEdit") == FALSE)
+  if(_le != 0 && !_le->inherits("TQLineEdit"))
   {
      errorInvalidSet(_le);
      return;
@@ -111,10 +111,10 @@ void PLineEdit::setWidget(TQObject *_le)
 
   lineedit = (TQLineEdit *) _le;
   if(lineedit != 0){
-    connect(lineedit, TQT_SIGNAL(textChanged(const char *)),
-	    this, TQT_SLOT(updateText(const char *)));
-    connect(lineedit, TQT_SIGNAL(returnPressed()),
-	    this, TQT_SLOT(returnPress()));
+    connect(lineedit, TQ_SIGNAL(textChanged(const char *)),
+	    this, TQ_SLOT(updateText(const char *)));
+    connect(lineedit, TQ_SIGNAL(returnPressed()),
+	    this, TQ_SLOT(returnPress()));
   }
   PWidget::setWidget(_le);
 
