@@ -99,12 +99,12 @@ void KSircTopic::contentsMouseReleaseEvent( TQMouseEvent *e )
 
         m_editor = new KSircTopicEditor( this );
 
-        connect( m_editor, TQT_SIGNAL( returnPressed() ),
-                 this, TQT_SLOT( setNewTopic() ) );
-        connect( m_editor, TQT_SIGNAL( resized() ),
-                 this, TQT_SLOT( slotEditResized() ) );
-        connect( m_editor, TQT_SIGNAL( destroyed() ),
-                 this, TQT_SLOT( doResize() ) );
+        connect( m_editor, TQ_SIGNAL( returnPressed() ),
+                 this, TQ_SLOT( setNewTopic() ) );
+        connect( m_editor, TQ_SIGNAL( resized() ),
+                 this, TQ_SLOT( slotEditResized() ) );
+        connect( m_editor, TQ_SIGNAL( destroyed() ),
+                 this, TQ_SLOT( doResize() ) );
 
         /*
          * If you don't do this order
@@ -132,9 +132,9 @@ void KSircTopic::setNewTopic()
      * from the server.  If we can't set the topic
      * don't make it look like it was set
      */
-    TQTimer::singleShot( 0, m_editor, TQT_SLOT( close() ) );
-    disconnect( m_editor, TQT_SIGNAL( resized() ),
-             this, TQT_SLOT( slotEditResized() ) );
+    TQTimer::singleShot( 0, m_editor, TQ_SLOT( close() ) );
+    disconnect( m_editor, TQ_SIGNAL( resized() ),
+             this, TQ_SLOT( slotEditResized() ) );
     doResize();
     emit topicChange( topic );
 }
@@ -185,7 +185,7 @@ KSircTopicEditor::KSircTopicEditor( TQWidget *parent, const char *name )
 {
     setWFlags( WDestructiveClose );
     setFocusPolicy( TQWidget::ClickFocus );
-    connect( this, TQT_SIGNAL( textChanged () ), this, TQT_SLOT( slotMaybeResize() ) );
+    connect( this, TQ_SIGNAL( textChanged () ), this, TQ_SLOT( slotMaybeResize() ) );
 }
 
 void KSircTopicEditor::keyPressEvent( TQKeyEvent *ev )
@@ -193,7 +193,7 @@ void KSircTopicEditor::keyPressEvent( TQKeyEvent *ev )
     if ( ev->key() == Key_Escape )
     {
         ev->accept();
-        TQTimer::singleShot( 0, this, TQT_SLOT( close() ) );
+        TQTimer::singleShot( 0, this, TQ_SLOT( close() ) );
         return;
     }
     else if ( ev->key() == Key_Return )
@@ -216,7 +216,7 @@ void KSircTopicEditor::focusOutEvent( TQFocusEvent * fe )
             return;
     }
 
-    TQTimer::singleShot( 0, this, TQT_SLOT( close() ) );
+    TQTimer::singleShot( 0, this, TQ_SLOT( close() ) );
 }
 
 TQPopupMenu *KSircTopicEditor::createPopupMenu( const TQPoint &pos )
