@@ -21,9 +21,15 @@ class ControlPipeHandlerObject : public TQObject
 
 	public slots:
 		void run();
+		void requestExit() { d.requestExit = true; }
 
 	public:
-		rfbScreenInfoPtr d;
+		struct Data
+		{
+		  rfbScreenInfoPtr rfbData;
+		  bool requestExit;
+		};
+		Data d;
 };
 
 class OnHoldClientHandlerObject : public TQObject
@@ -36,9 +42,15 @@ class OnHoldClientHandlerObject : public TQObject
 
 	public slots:
 		void run();
+		void requestExit() { d.requestExit = true; }
 
 	public:
-		rfbClientPtr d;
+		struct Data
+		{
+		  rfbClientPtr rfbData;
+		  bool requestExit;
+		};
+		Data d;
 };
 
 class ClientOutputHandlerObject : public TQObject
@@ -51,9 +63,15 @@ class ClientOutputHandlerObject : public TQObject
 
 	public slots:
 		void run();
+		void requestExit() { d.requestExit = true; }
 
 	public:
-		rfbClientPtr d;
+		struct Data
+		{
+		  rfbClientPtr rfbData;
+		  bool requestExit;
+		};
+		Data d;
 };
 
 #endif // _MAIN_H
