@@ -103,13 +103,13 @@ DCOPObject("dcop_interface"), TDEMainWindow (0, name), device(0), m_shuttingDown
 #endif
 
   counter = new TQTimer (this);
-  connect (counter, TQT_SIGNAL (timeout ()), device, TQT_SLOT (poll_device_info()));
+  connect (counter, TQ_SIGNAL (timeout ()), device, TQ_SLOT (poll_device_info()));
   counter->start (1000);
 
   tricorder_trigger = new TQTimer ();
-  connect (tricorder_trigger, TQT_SIGNAL (timeout ()), this,
-	   TQT_SLOT (tricorder_beep ()));
-  connect (trayicon, TQT_SIGNAL (quitSelected ()), this, TQT_SLOT (slotFileQuit ()));
+  connect (tricorder_trigger, TQ_SIGNAL (timeout ()), this,
+	   TQ_SLOT (tricorder_beep ()));
+  connect (trayicon, TQ_SIGNAL (quitSelected ()), this, TQ_SLOT (slotFileQuit ()));
   slotToggleTric(); //set to value saved by TDEConfig
 
   setAutoSaveSettings();
@@ -304,44 +304,44 @@ KWiFiManagerApp::initActions ()
   TDEConfig* config = kapp->config();
   if (config->hasGroup("General"))
 	config->setGroup("General");
-  fileDisableRadio = new TDEToggleAction (i18n ("&Disable Radio"), 0, TQT_TQOBJECT(this),
-		     TQT_SLOT (slotDisableRadio ()), actionCollection (), "disable_radio");
+  fileDisableRadio = new TDEToggleAction (i18n ("&Disable Radio"), 0, this,
+		     TQ_SLOT (slotDisableRadio ()), actionCollection (), "disable_radio");
   fileDisableRadio->setChecked( false );
 
   settingsUseAlternateCalc =
-    new TDEToggleAction (i18n ("&Use Alternate Strength Calculation"), 0, TQT_TQOBJECT(this),
-		       TQT_SLOT (slotToggleStrengthCalc ()), actionCollection (), "use_alt_calculation");
+    new TDEToggleAction (i18n ("&Use Alternate Strength Calculation"), 0, this,
+		       TQ_SLOT (slotToggleStrengthCalc ()), actionCollection (), "use_alt_calculation");
 
   settingsUseAlternateCalc->setChecked( config->readBoolEntry("useAlternateStrengthCalculation") );
   slotToggleStrengthCalc();  //set to value saved by TDEConfig
 
   settingsShowStatsNoise =
-    new TDEToggleAction (i18n ("Show &Noise Graph in Statistics Window"), 0, TQT_TQOBJECT(this),
-		       TQT_SLOT (slotShowStatsNoise ()), actionCollection (), "show_stats_noise");
+    new TDEToggleAction (i18n ("Show &Noise Graph in Statistics Window"), 0, this,
+		       TQ_SLOT (slotShowStatsNoise ()), actionCollection (), "show_stats_noise");
 
   settingsShowStatsNoise->setChecked( config->readBoolEntry("showStatsNoise") );
   slotShowStatsNoise();  //set to value saved by TDEConfig
 
-  settingsShowStrengthNumber = new TDEToggleAction (i18n ("&Show Strength Number in System Tray"), 0, TQT_TQOBJECT(this),
-                       TQT_SLOT (slotToggleShowStrengthNumber ()), actionCollection (), "show_strength_number_in_tray");
+  settingsShowStrengthNumber = new TDEToggleAction (i18n ("&Show Strength Number in System Tray"), 0, this,
+                       TQ_SLOT (slotToggleShowStrengthNumber ()), actionCollection (), "show_strength_number_in_tray");
   settingsShowStrengthNumber->setChecked( config->readBoolEntry("showStrengthNumberInTray") );
   slotToggleShowStrengthNumber (); //set to value saved by TDEConfig
 
-  KStdAction::quit (TQT_TQOBJECT(this), TQT_SLOT (slotFileQuit ()), actionCollection ());
+  KStdAction::quit (this, TQ_SLOT (slotFileQuit ()), actionCollection ());
 
-  new TDEAction (i18n ("Configuration &Editor..."), 0, TQT_TQOBJECT(this),
-	       TQT_SLOT (slotStartConfigEditor ()), actionCollection (), "configuration_editor");
-  new TDEAction (i18n ("Connection &Statistics"), 0, TQT_TQOBJECT(this),
-			       TQT_SLOT (slotStartStatViewer ()), actionCollection (), "connection_statistics");
-  settingsAcousticScanning = new TDEToggleAction (i18n ("&Acoustic Scanning"), 0, TQT_TQOBJECT(this),
-			    TQT_SLOT (slotToggleTric ()),
+  new TDEAction (i18n ("Configuration &Editor..."), 0, this,
+	       TQ_SLOT (slotStartConfigEditor ()), actionCollection (), "configuration_editor");
+  new TDEAction (i18n ("Connection &Statistics"), 0, this,
+			       TQ_SLOT (slotStartStatViewer ()), actionCollection (), "connection_statistics");
+  settingsAcousticScanning = new TDEToggleAction (i18n ("&Acoustic Scanning"), 0, this,
+			    TQ_SLOT (slotToggleTric ()),
 			    actionCollection (), "acoustic_scanning");
   settingsAcousticScanning->setChecked( config->readBoolEntry("acousticScanning") );
 #ifdef WITHOUT_ARTS
   settingsAcousticScanning->setEnabled( false);
 #endif
-  settingsStayInSystrayOnClose = new TDEToggleAction (i18n ("Stay in System &Tray on Close"), 0, TQT_TQOBJECT(this),
-						    TQT_SLOT (slotToggleStayInSystray()),
+  settingsStayInSystrayOnClose = new TDEToggleAction (i18n ("Stay in System &Tray on Close"), 0, this,
+						    TQ_SLOT (slotToggleStayInSystray()),
 						    actionCollection (), "stay_in_systray_on_close");
   settingsStayInSystrayOnClose->setChecked( config->readBoolEntry("stayInSystrayOnClose") );
   createGUI();
@@ -383,20 +383,20 @@ KWiFiManagerApp::initView ()
   zentrallayout->addMultiCellWidget (status, 1, 2, 1, 1);
   zentrallayout->addWidget (scan, 2, 0);
   zentrallayout->addMultiCellWidget (location, 3, 3, 0, 1, TQt::AlignLeft);
-  connect (device, TQT_SIGNAL (interfaceChanged ()), this, TQT_SLOT (slotChangeWindowCaption ()));
-  connect (device, TQT_SIGNAL (strengthChanged ()), this, TQT_SLOT (slotChangeTrayIcon ()));
-  connect (device, TQT_SIGNAL (strengthChanged ()), strength, TQT_SLOT (repaint ()));
-  connect (device, TQT_SIGNAL (statusChanged ()), status, TQT_SLOT (repaint ()));
-  connect (device, TQT_SIGNAL (speedChanged ()), speedmeter, TQT_SLOT (repaint ()));
-  connect (device, TQT_SIGNAL (modeChanged ()), pictogram, TQT_SLOT (repaint ()));
-  connect (device, TQT_SIGNAL (essidChanged (TQString)), this, TQT_SLOT (slotLogESSID (TQString)));
-  connect (device, TQT_SIGNAL (essidChanged (TQString)), location, TQT_SLOT (repaint ()));
-  connect (device, TQT_SIGNAL (statusChanged ()), location, TQT_SLOT (repaint ()));
-  connect (device, TQT_SIGNAL (txPowerChanged ()), this, TQT_SLOT (slotTXPowerChanged ()));
-  connect (device, TQT_SIGNAL (txPowerChanged ()), this, TQT_SLOT (slotChangeTrayIcon ()));
-  connect (device, TQT_SIGNAL (txPowerChanged ()), pictogram, TQT_SLOT (repaint ()));
-  connect (device, TQT_SIGNAL (txPowerChanged ()), strength, TQT_SLOT (repaint ()));
-  connect (scan,  TQT_SIGNAL (clicked()), this, TQT_SLOT (slotNetworkScan()));
+  connect (device, TQ_SIGNAL (interfaceChanged ()), this, TQ_SLOT (slotChangeWindowCaption ()));
+  connect (device, TQ_SIGNAL (strengthChanged ()), this, TQ_SLOT (slotChangeTrayIcon ()));
+  connect (device, TQ_SIGNAL (strengthChanged ()), strength, TQ_SLOT (repaint ()));
+  connect (device, TQ_SIGNAL (statusChanged ()), status, TQ_SLOT (repaint ()));
+  connect (device, TQ_SIGNAL (speedChanged ()), speedmeter, TQ_SLOT (repaint ()));
+  connect (device, TQ_SIGNAL (modeChanged ()), pictogram, TQ_SLOT (repaint ()));
+  connect (device, TQ_SIGNAL (essidChanged (TQString)), this, TQ_SLOT (slotLogESSID (TQString)));
+  connect (device, TQ_SIGNAL (essidChanged (TQString)), location, TQ_SLOT (repaint ()));
+  connect (device, TQ_SIGNAL (statusChanged ()), location, TQ_SLOT (repaint ()));
+  connect (device, TQ_SIGNAL (txPowerChanged ()), this, TQ_SLOT (slotTXPowerChanged ()));
+  connect (device, TQ_SIGNAL (txPowerChanged ()), this, TQ_SLOT (slotChangeTrayIcon ()));
+  connect (device, TQ_SIGNAL (txPowerChanged ()), pictogram, TQ_SLOT (repaint ()));
+  connect (device, TQ_SIGNAL (txPowerChanged ()), strength, TQ_SLOT (repaint ()));
+  connect (scan,  TQ_SIGNAL (clicked()), this, TQ_SLOT (slotNetworkScan()));
 }
 
 void
@@ -427,7 +427,7 @@ KWiFiManagerApp::slotStartStatViewer ()
   delete statistik;
   statistik = new Statistics (device, showStatsNoise);
   statistik->setFixedSize (590, 300);
-  connect(device,TQT_SIGNAL(statsUpdated()),statistik,TQT_SLOT(repaint()));
+  connect(device,TQ_SIGNAL(statsUpdated()),statistik,TQ_SLOT(repaint()));
   statistik->show ();
 }
 
@@ -460,7 +460,7 @@ KWiFiManagerApp::slotDisableRadio ()
   //*disablePower << "tdesu" << "iwconfig" << "eth1" << "txpower" << onOrOff;
 
   *disablePower << "tdesu" << "iwconfig" << interface << "txpower" << onOrOff;
-  connect( disablePower, TQT_SIGNAL(processExited(TDEProcess*)), this, TQT_SLOT(slotDisablePowerProcessExited()) );
+  connect( disablePower, TQ_SIGNAL(processExited(TDEProcess*)), this, TQ_SLOT(slotDisablePowerProcessExited()) );
   disablePower->start(TDEProcess::NotifyOnExit);
 }
 
@@ -612,7 +612,7 @@ TQStringList usedInterfacesList()
   client->registerAs( "kwifimanager" );
   client->setDefaultObject( "dcop_interface" );
 
-  // shamelessly stolen from tdelibs/tdeio/booksmarks/kbookmarkimporter_crash.cc
+  // shamelessly stolen from tdelibs/tdeio/booksmarks/kbookmarkimporter_crash.cpp
   TQStringList ignoreInterfaces;
   QCStringList apps = client->registeredApplications();
   for ( QCStringList::Iterator it = apps.begin(); it != apps.end(); ++it )
